@@ -90,7 +90,7 @@ module Stable = struct
         ; anons : Anons.V2.t
         ; flags : Flag_info.V1.t list
         }
-      [@@deriving compare, fields, sexp, stable_witness]
+      [@@deriving compare, sexp, stable_witness]
     end
 
     module V1 = struct
@@ -372,7 +372,7 @@ module Num_occurrences = struct
     { at_least_once : bool
     ; at_most_once : bool
     }
-  [@@deriving compare, enumerate, fields, sexp_of]
+  [@@deriving compare, enumerate, sexp_of]
 
   let maybe_missing_prefix = "["
   let maybe_missing_suffix = "]"
@@ -415,10 +415,11 @@ module Num_occurrences = struct
       assert ([%compare.equal: string] flag_name flag_name'));
     [%expect
       {|
-        (((at_least_once false) (at_most_once false)) "[name] ...")
-        (((at_least_once true) (at_most_once false)) "name ...")
-        (((at_least_once false) (at_most_once true)) [name])
-        (((at_least_once true) (at_most_once true)) name) |}]
+      (((at_least_once false) (at_most_once false)) "[name] ...")
+      (((at_least_once true) (at_most_once false)) "name ...")
+      (((at_least_once false) (at_most_once true)) [name])
+      (((at_least_once true) (at_most_once true)) name)
+      |}]
   ;;
 end
 
@@ -428,7 +429,7 @@ module Flag_info = struct
     ; doc : string
     ; aliases : string list
     }
-  [@@deriving compare, fields, sexp]
+  [@@deriving compare, fields ~getters, sexp]
 
   let parse_name t =
     let num_occurrences, flag_name = Num_occurrences.of_help_string t.name in
@@ -449,13 +450,13 @@ module Flag_info = struct
   let num_occurrences t =
     parse_name t
     |> Or_error.map ~f:(fun (num_occurrences, (_ : bool), (_ : string)) ->
-      num_occurrences)
+         num_occurrences)
   ;;
 
   let requires_arg t =
     parse_name t
     |> Or_error.map ~f:(fun ((_ : Num_occurrences.t), requires_arg, (_ : string)) ->
-      requires_arg)
+         requires_arg)
   ;;
 
   let help_screen_compare a b =
@@ -519,11 +520,7 @@ module Flag_help_display = struct
     let indentation = "  "
     let indent_and_newline x = List.concat [ [ indentation ]; x; [ "\n" ] ]
     let spacing_dot = ". "
-
-    let dot_indentation_offset =
-      27
-    ;;
-
+    let dot_indentation_offset = 27
     let documentation_start_column = dot_indentation_offset + String.length indentation
     let lhs_width = documentation_start_column
     let lhs_pad_width = dot_indentation_offset + String.length indentation
@@ -631,7 +628,7 @@ module Base_info = struct
     ; anons : Anons.t
     ; flags : Flag_info.t list
     }
-  [@@deriving compare, fields, sexp]
+  [@@deriving compare, fields ~getters, sexp]
 
   let find_flag t prefix =
     match String.is_prefix prefix ~prefix:"-" with
@@ -663,7 +660,7 @@ module Group_info = struct
     ; readme : string option [@sexp.option]
     ; subcommands : (string * 'a) List.t Lazy.t
     }
-  [@@deriving compare, fields, sexp]
+  [@@deriving compare, fields ~getters, sexp]
 
   let find_subcommand t prefix =
     match String.is_prefix prefix ~prefix:"-" with
@@ -689,7 +686,7 @@ module Exec_info = struct
     ; path_to_exe : string
     ; child_subcommand : string list
     }
-  [@@deriving compare, fields, sexp]
+  [@@deriving compare, sexp]
 end
 
 module Fully_forced = struct
