@@ -44,31 +44,15 @@ module Header : sig
      For the same reason we make sure not to call [Result.try_with (fun () -> ...)]
      inside [with_iteration] and do an explicit match statement instead. *)
 
-  val with_iteration_2l
-    :  t
-    -> 'a
-    -> ('b[@local])
-    -> (('a -> ('b[@local]) -> 'c)[@local])
-    -> 'c
-
-  val with_iteration_3 : t -> 'a -> 'b -> 'c -> ('a -> 'b -> 'c -> 'd) -> 'd
+  val with_iteration_2l : t -> 'a -> 'b -> ('a -> 'b -> 'c) -> 'c
+  val with_iteration_3l : t -> 'a -> 'b -> 'c -> ('a -> 'b -> 'c -> 'd) -> 'd
   val with_iteration_4 : t -> 'a -> 'b -> 'c -> 'd -> ('a -> 'b -> 'c -> 'd -> 'e) -> 'e
-
-  val with_iteration_4l
-    :  t
-    -> ('a[@local])
-    -> ('b[@local])
-    -> 'c
-    -> 'd
-    -> ((('a[@local]) -> ('b[@local]) -> 'c -> 'd -> 'e)[@local])
-    -> 'e
-
+  val with_iteration_4l : t -> 'a -> 'b -> 'c -> 'd -> ('a -> 'b -> 'c -> 'd -> 'e) -> 'e
   val merge : t -> t -> [ `Same_already | `Merged ]
 end = struct
   type s =
     { mutable length : int
-    ;
-      mutable pending_iterations : int
+    ; mutable pending_iterations : int
     }
 
   type t = s Union_find.t
@@ -97,7 +81,7 @@ end = struct
   let incr_pending_iters s = s.pending_iterations <- s.pending_iterations + 1
   let decr_pending_iters s = s.pending_iterations <- s.pending_iterations - 1
 
-  let with_iteration_2l t a (b [@local]) f =
+  let with_iteration_2l t a b f =
     let s = Union_find.get t in
     incr_pending_iters s;
     match f a b with
@@ -109,7 +93,7 @@ end = struct
       r
   ;;
 
-  let with_iteration_3 t a b c f =
+  let with_iteration_3l t a b c f =
     let s = Union_find.get t in
     incr_pending_iters s;
     match f a b c with
@@ -133,7 +117,7 @@ end = struct
       r
   ;;
 
-  let with_iteration_4l t (a [@local]) (b [@local]) c d f =
+  let with_iteration_4l t a b c d f =
     let s = Union_find.get t in
     incr_pending_iters s;
     match f a b c d with
@@ -346,7 +330,12 @@ let map t ~f =
   | None -> create ()
   | Some first ->
     let new_first = Elt.create (f (Elt.value first)) in
-    Header.with_iteration_3 (Elt.header first) f new_first first (fun f new_first first ->
+    Header.with_iteration_3l
+      (Elt.header first)
+      f
+      new_first
+      first
+      (fun f new_first first ->
       let rec loop f acc first elt =
         let acc = Elt.insert_after acc (f (Elt.value elt)) in
         let next = Elt.next elt in
@@ -363,7 +352,12 @@ let mapi t ~f =
   | None -> create ()
   | Some first ->
     let new_first = Elt.create (f 0 (Elt.value first)) in
-    Header.with_iteration_3 (Elt.header first) f new_first first (fun f new_first first ->
+    Header.with_iteration_3l
+      (Elt.header first)
+      f
+      new_first
+      first
+      (fun f new_first first ->
       let rec loop f i acc first elt =
         let acc = Elt.insert_after acc (f i (Elt.value elt)) in
         let next = Elt.next elt in
@@ -379,7 +373,7 @@ let fold_elt t ~init ~f =
   match !t with
   | None -> init
   | Some first ->
-    Header.with_iteration_3 (Elt.header first) f init first (fun f init first ->
+    Header.with_iteration_3l (Elt.header first) f init first (fun f init first ->
       let rec loop f acc first elt =
         let acc = f acc elt in
         let next = Elt.next elt in
@@ -392,7 +386,7 @@ let foldi_elt t ~init ~f =
   match !t with
   | None -> init
   | Some first ->
-    Header.with_iteration_3 (Elt.header first) f init first (fun f init first ->
+    Header.with_iteration_3l (Elt.header first) f init first (fun f init first ->
       let rec loop f i acc first elt =
         let acc = f i acc elt in
         let next = Elt.next elt in
@@ -487,16 +481,16 @@ let foldi t ~init ~f =
 ;;
 
 module C = Container.Make (struct
-    type nonrec 'a t = 'a t
+  type nonrec 'a t = 'a t
 
-    let fold t ~init ~f =
-      let r = fold_elt_1 t ~init f ~f:(fun f acc elt -> f acc (Elt.value elt)) in
-      r
-    ;;
+  let fold t ~init ~f =
+    let r = fold_elt_1 t ~init f ~f:(fun f acc elt -> f acc (Elt.value elt)) in
+    r
+  ;;
 
-    let iter = `Custom iter
-    let length = `Custom length
-  end)
+  let iter = `Custom iter
+  let length = `Custom length
+end)
 
 let count = C.count
 let sum = C.sum
@@ -535,7 +529,7 @@ let fold_right t ~init ~f =
   match !t with
   | None -> init
   | Some first ->
-    Header.with_iteration_3 (Elt.header first) f init first (fun f init first ->
+    Header.with_iteration_3l (Elt.header first) f init first (fun f init first ->
       let rec loop f acc elt =
         let prev = Elt.prev elt in
         let acc = f (Elt.value prev) acc in
@@ -548,7 +542,7 @@ let fold_right_elt t ~init ~f =
   match !t with
   | None -> init
   | Some first ->
-    Header.with_iteration_3 (Elt.header first) f init first (fun f init first ->
+    Header.with_iteration_3l (Elt.header first) f init first (fun f init first ->
       let rec loop f acc elt =
         let prev = Elt.prev elt in
         let acc = f prev acc in
@@ -574,8 +568,8 @@ let compare compare_elt t1 t2 =
   | None, _ -> -1
   | _, None -> 1
   | Some f1, Some f2 ->
-    Header.with_iteration_3 (Elt.header f1) compare_elt f1 f2 (fun compare_elt f1 f2 ->
-      Header.with_iteration_3 (Elt.header f2) compare_elt f1 f2 (fun compare_elt f1 f2 ->
+    Header.with_iteration_3l (Elt.header f1) compare_elt f1 f2 (fun compare_elt f1 f2 ->
+      Header.with_iteration_3l (Elt.header f2) compare_elt f1 f2 (fun compare_elt f1 f2 ->
         let rec loop compare_elt elt1 f1 elt2 f2 =
           let compare_result = compare_elt (Elt.value elt1) (Elt.value elt2) in
           if compare_result <> 0
@@ -807,7 +801,7 @@ let filter t ~f =
   (match !t with
    | None -> ()
    | Some first ->
-     Header.with_iteration_3 (Elt.header first) f new_t first (fun f new_t first ->
+     Header.with_iteration_3l (Elt.header first) f new_t first (fun f new_t first ->
        let rec loop f new_t first elt =
          if f (Elt.value elt)
          then insert_last new_t (Elt.value elt) |> (ignore : _ Elt.t -> unit);
@@ -823,7 +817,7 @@ let filteri t ~f =
   (match !t with
    | None -> ()
    | Some first ->
-     Header.with_iteration_3 (Elt.header first) f new_t first (fun f new_t first ->
+     Header.with_iteration_3l (Elt.header first) f new_t first (fun f new_t first ->
        let rec loop f i new_t first elt =
          if f i (Elt.value elt)
          then insert_last new_t (Elt.value elt) |> (ignore : _ Elt.t -> unit);
@@ -839,7 +833,7 @@ let filter_map t ~f =
   (match !t with
    | None -> ()
    | Some first ->
-     Header.with_iteration_3 (Elt.header first) f new_t first (fun f new_t first ->
+     Header.with_iteration_3l (Elt.header first) f new_t first (fun f new_t first ->
        let rec loop f new_t first elt =
          (match f (Elt.value elt) with
           | None -> ()
@@ -856,7 +850,7 @@ let filter_mapi t ~f =
   (match !t with
    | None -> ()
    | Some first ->
-     Header.with_iteration_3 (Elt.header first) f new_t first (fun f new_t first ->
+     Header.with_iteration_3l (Elt.header first) f new_t first (fun f new_t first ->
        let rec loop f i new_t first elt =
          (match f i (Elt.value elt) with
           | None -> ()
