@@ -3,7 +3,7 @@ module Stable = struct
     type ('f, 's) t = ('f, 's) Base.Either.t =
       | First of 'f
       | Second of 's
-    [@@deriving bin_io, compare, hash, sexp, typerep, stable_witness]
+    [@@deriving bin_io ~localize, compare, equal, hash, sexp, typerep, stable_witness]
 
     let map x ~f1 ~f2 =
       match x with
@@ -17,8 +17,8 @@ include Stable.V1
 include Base.Either
 
 include Comparator.Derived2 (struct
-    type nonrec ('a, 'b) t = ('a, 'b) t [@@deriving sexp_of, compare]
-  end)
+  type nonrec ('a, 'b) t = ('a, 'b) t [@@deriving sexp_of, compare]
+end)
 
 let quickcheck_generator = Base_quickcheck.Generator.either
 let quickcheck_observer = Base_quickcheck.Observer.either
