@@ -180,7 +180,7 @@ module Stat = struct
       ; top_heap_words : int
       ; stack_size : int
       }
-    [@@deriving compare, hash, bin_io, sexp, fields]
+    [@@deriving compare, hash, bin_io, sexp]
 
     [%%else]
 
@@ -203,7 +203,16 @@ module Stat = struct
       ; stack_size : int
       ; forced_major_collections : int
       }
-    [@@deriving compare, hash, sexp_of, fields]
+    [@@deriving
+      compare
+      , hash
+      , sexp_of
+      , fields
+          ~getters
+          ~setters
+          ~fields
+          ~iterators:(create, fold, iter, map, to_list)
+          ~direct_iterators:to_list]
 
     [%%endif]
   end
@@ -282,7 +291,8 @@ module Control = struct
       ; custom_minor_ratio : int
       ; custom_minor_max_size : int
       }
-    [@@deriving compare, sexp_of, fields]
+    [@@deriving
+      compare, sexp_of, fields ~getters ~setters ~fields ~iterators:(map, to_list)]
   end
 
   [%%else]
@@ -303,7 +313,8 @@ module Control = struct
       ; custom_minor_ratio : int
       ; custom_minor_max_size : int
       }
-    [@@deriving compare, sexp_of, fields]
+    [@@deriving
+      compare, sexp_of, fields ~getters ~setters ~fields ~iterators:(map, to_list)]
   end
 
   [%%endif]
@@ -327,19 +338,19 @@ module Allocation_policy = struct
 end
 
 let tune
-      ?logger
-      ?minor_heap_size
-      ?major_heap_increment
-      ?space_overhead
-      ?verbose
-      ?max_overhead
-      ?stack_limit
-      ?allocation_policy
-      ?window_size
-      ?custom_major_ratio
-      ?custom_minor_ratio
-      ?custom_minor_max_size
-      ()
+  ?logger
+  ?minor_heap_size
+  ?major_heap_increment
+  ?space_overhead
+  ?verbose
+  ?max_overhead
+  ?stack_limit
+  ?allocation_policy
+  ?window_size
+  ?custom_major_ratio
+  ?custom_minor_ratio
+  ?custom_minor_max_size
+  ()
   =
   let old_control_params = get () in
   let f opt to_string field =
@@ -392,17 +403,51 @@ external major_words : unit -> int = "core_gc_major_words" [@@noalloc]
 external promoted_words : unit -> int = "core_gc_promoted_words" [@@noalloc]
 external minor_collections : unit -> int = "core_gc_minor_collections" [@@noalloc]
 external major_collections : unit -> int = "core_gc_major_collections" [@@noalloc]
-external compactions : unit -> int = "core_gc_compactions" [@@noalloc]
 external major_plus_minor_words : unit -> int = "core_gc_major_plus_minor_words"
 external allocated_words : unit -> int = "core_gc_allocated_words"
 external run_memprof_callbacks : unit -> unit = "core_gc_run_memprof_callbacks"
 
+module Runtime4 = struct
+  external heap_words : unit -> int = "core_gc_heap_words" [@@noalloc]
+  external heap_chunks : unit -> int = "core_gc_heap_chunks" [@@noalloc]
+  external top_heap_words : unit -> int = "core_gc_top_heap_words" [@@noalloc]
+end
+
+[%%import "gc_stubs.h"]
 [%%if ocaml_version < (5, 0, 0)]
 
-external heap_words : unit -> int = "core_gc_heap_words" [@@noalloc]
-external heap_chunks : unit -> int = "core_gc_heap_chunks" [@@noalloc]
-external top_heap_words : unit -> int = "core_gc_top_heap_words" [@@noalloc]
+external compactions : unit -> int = "core_gc_compactions" [@@noalloc]
 
+let heap_words = Runtime4.heap_words
+let heap_chunks = Runtime4.heap_chunks
+let top_heap_words = Runtime4.top_heap_words
+
+[%%else]
+
+module Runtime5 = struct
+  let heap_words () = (quick_stat ()).heap_words
+  let heap_chunks () = (quick_stat ()).heap_chunks
+  let top_heap_words () = (quick_stat ()).top_heap_words
+end
+
+[%%if OCAML_5_MINUS]
+
+external runtime5 : unit -> bool = "%runtime5"
+external compactions : unit -> int = "core_gc_compactions" [@@noalloc]
+
+let runtime5 = runtime5 ()
+let heap_words = if runtime5 then Runtime5.heap_words else Runtime4.heap_words
+let heap_chunks = if runtime5 then Runtime5.heap_chunks else Runtime4.heap_chunks
+let top_heap_words = if runtime5 then Runtime5.top_heap_words else Runtime4.top_heap_words
+
+[%%else]
+
+let compactions () = (quick_stat ()).compactions
+let heap_words = Runtime5.heap_words
+let heap_chunks = Runtime5.heap_chunks
+let top_heap_words = Runtime5.top_heap_words
+
+[%%endif]
 [%%endif]
 
 let stat_size_lazy =
@@ -417,9 +462,11 @@ let zero = Sys.opaque_identity (int_of_string "0")
 let rec keep_alive o = if zero <> 0 then keep_alive (Sys.opaque_identity o)
 
 module For_testing = struct
+  type 'a globl = { g : 'a } [@@unboxed]
+
   (* We disable inlining for this function so the GC stats and the call to [f] are never
      rearranged. *)
-  let[@cold] measure_internal ~on_result f =
+  let[@cold] measure_internal ~on_result (f : unit -> 'a) =
     let minor_words_before = minor_words () in
     let major_words_before = major_words () in
     (* We wrap [f ()] with [Sys.opaque_identity] to prevent the return value from being
@@ -432,46 +479,72 @@ module For_testing = struct
     on_result ~major_words_allocated ~minor_words_allocated x
   ;;
 
-  let is_zero_alloc (type a) (f : unit -> a) =
+  let is_zero_alloc_local (type a) (f : unit -> a) =
     (* Instead of using [Allocation_report.measure], and matching on the result, we use
        this construction, in order to have [is_zero_alloc] not allocate itself. This
        enables [is_zero_alloc] to be used in a nested way. *)
     measure_internal
       f
       ~on_result:(fun ~major_words_allocated ~minor_words_allocated value ->
-        ignore (Sys.opaque_identity value : a);
-        major_words_allocated == 0 && minor_words_allocated == 0)
+      ignore (Sys.opaque_identity value : a);
+      major_words_allocated == 0 && minor_words_allocated == 0) [@nontail]
   ;;
 
+  let is_zero_alloc f = is_zero_alloc_local (fun () -> { g = f () }) [@nontail]
+
   module Allocation_report = struct
     type t =
-      { major_words_allocated : int
-      ; minor_words_allocated : int
+      { major_words_allocated : int [@globalized]
+      ; minor_words_allocated : int [@globalized]
       }
-    [@@deriving sexp_of]
+    [@@deriving sexp_of, globalize]
 
     let create ~major_words_allocated ~minor_words_allocated =
       { major_words_allocated; minor_words_allocated }
     ;;
   end
 
-  let measure_allocation f =
+  let measure_allocation_local f =
     measure_internal f ~on_result:(fun ~major_words_allocated ~minor_words_allocated x ->
       x, Allocation_report.create ~major_words_allocated ~minor_words_allocated)
   ;;
 
+  let measure_allocation_for_runtime5_local f =
+    let minor_words_before = minor_words () in
+    let promoted_words_before = promoted_words () in
+    let major_words_before = major_words () in
+    let x = Sys.opaque_identity (f ()) in
+    let minor_words_after = minor_words () in
+    let promoted_words_after = promoted_words () in
+    let major_words_after = major_words () in
+    let major_words_allocated =
+      major_words_after
+      - promoted_words_after
+      - (major_words_before - promoted_words_before)
+    in
+    let minor_words_allocated = minor_words_after - minor_words_before in
+    x, Allocation_report.create ~major_words_allocated ~minor_words_allocated
+  ;;
+
+  let measure_allocation f =
+    let%tydi { g }, allocation_report =
+      measure_allocation_local (fun () -> { g = f () })
+    in
+    g, [%globalize: Allocation_report.t] allocation_report
+  ;;
+
   module Allocation_log = struct
     type t =
-      { size_in_words : int
-      ; is_major : bool
+      { size_in_words : int [@globalized]
+      ; is_major : bool [@globalized]
       ; backtrace : string
       }
-    [@@deriving sexp_of]
+    [@@deriving sexp_of, globalize]
   end
 
   [%%if ocaml_version >= (4, 11, 0)]
 
-  let measure_and_log_allocation f =
+  let measure_and_log_allocation_local (f : unit -> 'a) =
     let log : Allocation_log.t list ref = ref []
     and major_allocs = ref 0
     and minor_allocs = ref 0 in
@@ -489,8 +562,8 @@ module For_testing = struct
         | Some p ->
           String.sub ~pos:0 ~len:p backtrace
           |> String.rstrip ~drop:(function
-            | '\n' -> false
-            | _ -> true)
+               | '\n' -> false
+               | _ -> true)
       in
       let info : Allocation_log.t =
         { size_in_words = info.n_samples; is_major; backtrace }
@@ -504,27 +577,43 @@ module For_testing = struct
       ; alloc_major = on_alloc ~is_major:true
       }
     in
-    Stdlib.Gc.Memprof.start ~sampling_rate:1.0 tracker;
-    (* Exn.protect, manually inlined to guarantee no allocations *)
-    let result =
-      match f () with
-      | x ->
-        (* Memprof.stop does not guarantee that all memprof callbacks are run (some may be
-           delayed if they happened during C code and there has been no allocation since),
-           so we explictly flush them *)
-        run_memprof_callbacks ();
-        Stdlib.Gc.Memprof.stop ();
-        x
-      | exception e ->
-        run_memprof_callbacks ();
-        Stdlib.Gc.Memprof.stop ();
-        raise e
+    match Stdlib.Gc.Memprof.start ~sampling_rate:1.0 tracker with
+    | _ ->
+      (* Exn.protect, manually inlined to guarantee no allocations *)
+      let result =
+        match f () with
+        | x ->
+          (* Memprof.stop does not guarantee that all memprof callbacks are run (some may be
+             delayed if they happened during C code and there has been no allocation since),
+             so we explictly flush them *)
+          run_memprof_callbacks ();
+          Stdlib.Gc.Memprof.stop ();
+          x
+        | exception e ->
+          run_memprof_callbacks ();
+          Stdlib.Gc.Memprof.stop ();
+          raise e
+      in
+      ( result
+      , Allocation_report.create
+          ~major_words_allocated:!major_allocs
+          ~minor_words_allocated:!minor_allocs
+      , List.rev !log )
+    | exception Failure msg ->
+      if String.equal msg "Gc.memprof.start: not implemented in multicore"
+      then (
+        let a, b = measure_allocation_for_runtime5_local f in
+        a, b, [])
+      else failwith msg
+  ;;
+
+  let measure_and_log_allocation f =
+    let { g }, allocation_report, log =
+      measure_and_log_allocation_local (fun () -> { g = f () })
     in
-    ( result
-    , Allocation_report.create
-        ~major_words_allocated:!major_allocs
-        ~minor_words_allocated:!minor_allocs
-    , List.rev !log )
+    ( g
+    , [%globalize: Allocation_report.t] allocation_report
+    , [%globalize: Allocation_log.t list] log )
   ;;
 
   [%%else]
@@ -534,7 +623,32 @@ module For_testing = struct
     x, report, []
   ;;
 
+  let measure_and_log_allocation_local = measure_and_log_allocation
+
   [%%endif]
+
+  let[@cold] require_no_allocation_local_failed here allocation_report allocation_log =
+    let allocation_report = [%globalize: Allocation_report.t] allocation_report in
+    let allocation_log = [%globalize: Allocation_log.t list] allocation_log in
+    raise_s
+      [%message
+        "allocation detected"
+          (here : Source_code_position.t)
+          (allocation_report : Allocation_report.t)
+          (allocation_log : Allocation_log.t list)]
+  ;;
+
+  let assert_no_allocation_local here f =
+    let result, allocation_report, allocation_log = measure_and_log_allocation_local f in
+    if allocation_report.major_words_allocated > 0
+       || allocation_report.minor_words_allocated > 0
+    then require_no_allocation_local_failed here allocation_report allocation_log;
+    result
+  ;;
+
+  let assert_no_allocation here f =
+    (assert_no_allocation_local here (fun () -> { g = f () })).g
+  ;;
 end
 
 module Expert = struct
