@@ -24,89 +24,116 @@ module Stat : sig
 
   type t =
     { minor_words : float
-    (** Number of words allocated in the minor heap since
+        (** Number of words allocated in the minor heap since
         the program was started.  This number is accurate in
         byte-code programs, but only an approximation in programs
         compiled to native code. *)
     ; promoted_words : float
-    (** Number of words allocated in the minor heap that
+        (** Number of words allocated in the minor heap that
         survived a minor collection and were moved to the major heap
         since the program was started. *)
     ; major_words : float
-    (** Number of words allocated in the major heap, including
+        (** Number of words allocated in the major heap, including
         the promoted words, since the program was started. *)
     ; minor_collections : int
-    (** Number of minor collections since the program was started. *)
+        (** Number of minor collections since the program was started. *)
     ; major_collections : int
-    (** Number of major collection cycles completed since the program
+        (** Number of major collection cycles completed since the program
         was started. *)
-    ; heap_words : int (** Total size of the major heap, in words. *)
+    ; heap_words : int
+        (** Total size of the major heap, in words.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
     ; heap_chunks : int
-    (** Number of contiguous pieces of memory that make up the major heap. *)
+        (** Number of contiguous pieces of memory that make up the major heap.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
     ; live_words : int
-    (** Number of words of live data in the major heap, including the header
+        (** Number of words of live data in the major heap, including the header
         words. *)
     ; live_blocks : int (** Number of live blocks in the major heap. *)
     ; free_words : int (** Number of words in the free list. *)
-    ; free_blocks : int (** Number of blocks in the free list. *)
-    ; largest_free : int (** Size (in words) of the largest block in the free list. *)
+    ; free_blocks : int
+        (** Number of blocks in the free list.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
+    ; largest_free : int
+        (** Size (in words) of the largest block in the free list.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
     ; fragments : int
-    (** Number of wasted words due to fragmentation.  These are
+        (** Number of wasted words due to fragmentation.  These are
         1-words free blocks placed between two live blocks.  They
         are not available for allocation. *)
     ; compactions : int (** Number of heap compactions since the program was started. *)
-    ; top_heap_words : int (** Maximum size reached by the major heap, in words. *)
-    ; stack_size : int (** Current size of the stack, in words. *)
+    ; top_heap_words : int
+        (** Maximum size reached by the major heap, in words.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
+    ; stack_size : int
+        (** Current size of the stack, in words.
+        This metric is currently not available when using the OCaml 5 runtime: the field
+        value is always [0]. *)
     }
-  [@@deriving bin_io, sexp, fields]
+  [@@deriving bin_io, sexp]
 
   [%%else]
 
   type t =
     { minor_words : float
-    (** Number of words allocated in the minor heap since
+        (** Number of words allocated in the minor heap since
         the program was started.  This number is accurate in
         byte-code programs, but only an approximation in programs
         compiled to native code. *)
     ; promoted_words : float
-    (** Number of words allocated in the minor heap that
+        (** Number of words allocated in the minor heap that
         survived a minor collection and were moved to the major heap
         since the program was started. *)
     ; major_words : float
-    (** Number of words allocated in the major heap, including
+        (** Number of words allocated in the major heap, including
         the promoted words, since the program was started. *)
     ; minor_collections : int
-    (** Number of minor collections since the program was started. *)
+        (** Number of minor collections since the program was started. *)
     ; major_collections : int
-    (** Number of major collection cycles completed since the program
+        (** Number of major collection cycles completed since the program
         was started. *)
     ; heap_words : int (** Total size of the major heap, in words. *)
     ; heap_chunks : int
-    (** Number of contiguous pieces of memory that make up the major heap. *)
+        (** Number of contiguous pieces of memory that make up the major heap. *)
     ; live_words : int
-    (** Number of words of live data in the major heap, including the header
+        (** Number of words of live data in the major heap, including the header
         words. *)
     ; live_blocks : int (** Number of live blocks in the major heap. *)
     ; free_words : int (** Number of words in the free list. *)
     ; free_blocks : int (** Number of blocks in the free list. *)
     ; largest_free : int (** Size (in words) of the largest block in the free list. *)
     ; fragments : int
-    (** Number of wasted words due to fragmentation.  These are
+        (** Number of wasted words due to fragmentation.  These are
         1-words free blocks placed between two live blocks.  They
         are not available for allocation. *)
     ; compactions : int (** Number of heap compactions since the program was started. *)
     ; top_heap_words : int (** Maximum size reached by the major heap, in words. *)
     ; stack_size : int (** Current size of the stack, in words. *)
     ; forced_major_collections : int
-    (** Number of forced full major collection cycles completed since the program
+        (** Number of forced full major collection cycles completed since the program
         was started. *)
     }
-  [@@deriving sexp_of, fields]
+  [@@deriving
+    sexp_of
+    , fields
+        ~getters
+        ~fields
+        ~iterators:(create, fold, iter, map, to_list)
+        ~direct_iterators:to_list]
 
   [%%endif]
 
   include Comparable.S_plain with type t := t
 
+  (** [add first second] computes [first+second] pointwise across each field; this helps
+      in aggregating statistics across processes. *)
+  val add : t -> t -> t
+
   (** [diff after before] computes [after-before] pointwise across each field; this helps
       show the effect (on all stats) of some code block. *)
   val diff : t -> t -> t
@@ -127,13 +154,13 @@ module Control : sig
 
   type t =
     { mutable minor_heap_size : int
-    (** The size (in words) of the minor heap.  Changing this parameter will
+        (** The size (in words) of the minor heap.  Changing this parameter will
         trigger a minor collection.
 
         Default: 262144 words / 1MB (32bit) / 2MB (64bit).
     *)
     ; mutable major_heap_increment : int
-    (** How much to add to the major heap when increasing it. If this
+        (** How much to add to the major heap when increasing it. If this
         number is less than or equal to 1000, it is a percentage of
         the current heap size (i.e. setting it to 100 will double the heap
         size at each increase). If it is more than 1000, it is a fixed
@@ -142,7 +169,7 @@ module Control : sig
         Default: 15%.
     *)
     ; mutable space_overhead : int
-    (** The major GC speed is computed from this parameter.
+        (** The major GC speed is computed from this parameter.
         This is the memory that will be "wasted" because the GC does not
         immediately collect unreachable blocks.  It is expressed as a
         percentage of the memory used for live data.
@@ -151,7 +178,7 @@ module Control : sig
 
         Default: 80. *)
     ; mutable verbose : int
-    (** This value controls the GC messages on standard error output.
+        (** This value controls the GC messages on standard error output.
         It is a sum of some of the following flags, to print messages
         on the corresponding events:
         - [0x001] Start of major GC cycle.
@@ -167,7 +194,7 @@ module Control : sig
 
         Default: 0. *)
     ; mutable max_overhead : int
-    (** Heap compaction is triggered when the estimated amount
+        (** Heap compaction is triggered when the estimated amount
         of "wasted" memory is more than [max_overhead] percent of the
         amount of live data.  If [max_overhead] is set to 0, heap
         compaction is triggered at the end of each major GC cycle
@@ -176,13 +203,13 @@ module Control : sig
 
         Default: 500. *)
     ; mutable stack_limit : int
-    (** The maximum size of the stack (in words).  This is only
+        (** The maximum size of the stack (in words).  This is only
         relevant to the byte-code runtime, as the native code runtime
         uses the operating system's stack.
 
         Default: 1048576 words / 4MB (32bit) / 8MB (64bit). *)
     ; mutable allocation_policy : int
-    (** The policy used for allocating in the heap.  Possible
+        (** The policy used for allocating in the heap.  Possible
         values are 0 and 1.  0 is the next-fit policy, which is
         quite fast but can result in fragmentation.  1 is the
         first-fit policy, which can be slower in some cases but
@@ -190,13 +217,13 @@ module Control : sig
 
         Default: 0. *)
     ; window_size : int
-    (** The size of the window used by the major GC for smoothing
+        (** The size of the window used by the major GC for smoothing
         out variations in its workload. This is an integer between
         1 and 50.
 
         Default: 1. @since 4.03.0 *)
     ; custom_major_ratio : int
-    (** Target ratio of floating garbage to major heap size for
+        (** Target ratio of floating garbage to major heap size for
         out-of-heap memory held by custom values located in the major
         heap. The GC speed is adjusted to try to use this much memory
         for dead values that are not yet collected. Expressed as a
@@ -208,7 +235,7 @@ module Control : sig
         Default: 44.
         @since 4.08.0 *)
     ; custom_minor_ratio : int
-    (** Bound on floating garbage for out-of-heap memory held by
+        (** Bound on floating garbage for out-of-heap memory held by
         custom values in the minor heap. A minor GC is triggered when
         this much memory is held by custom values located in the minor
         heap. Expressed as a percentage of minor heap size.
@@ -217,7 +244,7 @@ module Control : sig
         Default: 100.
         @since 4.08.0 *)
     ; custom_minor_max_size : int
-    (** Maximum amount of out-of-heap memory for each custom value
+        (** Maximum amount of out-of-heap memory for each custom value
         allocated in the minor heap. When a custom value is allocated
         on the minor heap and holds more than this many bytes, only
         this value is counted against [custom_minor_ratio] and the
@@ -227,38 +254,39 @@ module Control : sig
         Default: 8192 bytes.
         @since 4.08.0 *)
     }
-  [@@deriving sexp_of, fields]
-
-  [%% else]
+  [@@deriving sexp_of, fields ~iterators:to_list]
 
+  [%%else]
 
   type t =
     { minor_heap_size : int
-    (** The size (in words) of the minor heap.  Changing this parameter will
-        trigger a minor collection.
+        (** The size (in words) of the minor heap.  Changing
+        this parameter will trigger a minor collection.
+
+        Under the OCaml 5 runtime: the total size of the minor heap used by the program
+        can be obtained by summing the the heap sizes of the active domains.
 
         Default: 262144 words / 1MB (32bit) / 2MB (64bit).
     *)
     ; major_heap_increment : int
-    (** How much to add to the major heap when increasing it. If this
+        (** How much to add to the major heap when increasing it. If this
         number is less than or equal to 1000, it is a percentage of
         the current heap size (i.e. setting it to 100 will double the heap
         size at each increase). If it is more than 1000, it is a fixed
         number of words that will be added to the heap.
-
         Default: 15%.
     *)
     ; space_overhead : int
-    (** The major GC speed is computed from this parameter.
+        (** The major GC speed is computed from this parameter.
         This is the memory that will be "wasted" because the GC does not
         immediately collect unreachable blocks.  It is expressed as a
         percentage of the memory used for live data.
         The GC will work more (use more CPU time and collect
         blocks more eagerly) if [space_overhead] is smaller.
-
-        Default: 80. *)
+        Default: 80 for the OCaml 4 runtime, 120 for the OCaml 5 runtime
+        (the latter subject to change). *)
     ; verbose : int
-    (** This value controls the GC messages on standard error output.
+        (** This value controls the GC messages on standard error output.
         It is a sum of some of the following flags, to print messages
         on the corresponding events:
         - [0x001] Start of major GC cycle.
@@ -271,39 +299,35 @@ module Control : sig
         - [0x080] Calling of finalisation functions.
         - [0x100] Bytecode executable search at start-up.
         - [0x200] Computation of compaction triggering condition.
-
-        Default: 0. *)
+        - [0x400] Output GC statistics at program exit (OCaml 5 runtime only).
+          Default: 0. *)
     ; max_overhead : int
-    (** Heap compaction is triggered when the estimated amount
+        (** Heap compaction is triggered when the estimated amount
         of "wasted" memory is more than [max_overhead] percent of the
         amount of live data.  If [max_overhead] is set to 0, heap
         compaction is triggered at the end of each major GC cycle
         (this setting is intended for testing purposes only).
         If [max_overhead >= 1000000], compaction is never triggered.
-
         Default: 500. *)
     ; stack_limit : int
-    (** The maximum size of the stack (in words).  This is only
+        (** The maximum size of the stack (in words).  This is only
         relevant to the byte-code runtime, as the native code runtime
         uses the operating system's stack.
-
         Default: 1048576 words / 4MB (32bit) / 8MB (64bit). *)
     ; allocation_policy : int
-    (** The policy used for allocating in the heap.  Possible
+        (** The policy used for allocating in the heap.  Possible
         values are 0 and 1.  0 is the next-fit policy, which is
         quite fast but can result in fragmentation.  1 is the
         first-fit policy, which can be slower in some cases but
         can be better for programs with fragmentation problems.
-
         Default: 0. *)
     ; window_size : int
-    (** The size of the window used by the major GC for smoothing
+        (** The size of the window used by the major GC for smoothing
         out variations in its workload. This is an integer between
         1 and 50.
-
         Default: 1. @since 4.03.0 *)
     ; custom_major_ratio : int
-    (** Target ratio of floating garbage to major heap size for
+        (** Target ratio of floating garbage to major heap size for
         out-of-heap memory held by custom values located in the major
         heap. The GC speed is adjusted to try to use this much memory
         for dead values that are not yet collected. Expressed as a
@@ -315,7 +339,7 @@ module Control : sig
         Default: 44.
         @since 4.08.0 *)
     ; custom_minor_ratio : int
-    (** Bound on floating garbage for out-of-heap memory held by
+        (** Bound on floating garbage for out-of-heap memory held by
         custom values in the minor heap. A minor GC is triggered when
         this much memory is held by custom values located in the minor
         heap. Expressed as a percentage of minor heap size.
@@ -324,7 +348,7 @@ module Control : sig
         Default: 100.
         @since 4.08.0 *)
     ; custom_minor_max_size : int
-    (** Maximum amount of out-of-heap memory for each custom value
+        (** Maximum amount of out-of-heap memory for each custom value
         allocated in the minor heap. When a custom value is allocated
         on the minor heap and holds more than this many bytes, only
         this value is counted against [custom_minor_ratio] and the
@@ -334,9 +358,9 @@ module Control : sig
         Default: 8192 bytes.
         @since 4.08.0 *)
     }
-  [@@deriving sexp_of, fields]
+  [@@deriving sexp_of, fields ~iterators:to_list]
 
-  [%% endif]
+  [%%endif]
 
   include Comparable.S_plain with type t := t
 end
@@ -349,23 +373,48 @@ type control = Control.t
     See the documentation of ocamlrun. *)
 
 (** Return the current values of the memory management counters in a
-    [stat] record.  This function examines every heap block to get the
-    statistics. *)
+    [stat] record that represent the program's total memory stats.
+
+    OCaml 4 runtime: This function examines every heap block to get the
+    statistics.
+
+    OCaml 5 runtime: This function causes a full major collection. *)
 external stat : unit -> stat = "caml_gc_stat"
 
+(** Creating a [Stat.t] can allocate on the minor heap. Return the expected number of
+    words allocated. **)
+val stat_size : unit -> int
+
 (** Same as [stat] except that [live_words], [live_blocks], [free_words],
-    [free_blocks], [largest_free], and [fragments] are set to 0.  This
-    function is much faster than [stat] because it does not need to go
-    through the heap. *)
+    [free_blocks], [largest_free], and [fragments] are set to 0.
+
+    OCaml 4 runtime: This function is much faster than [stat] because it does not need to
+    go through the heap.
+
+    OCaml 5 runtime: Due to per-domain buffers it may only represent the state of the
+    program's total memory usage since the last minor collection. As a result returned
+    values are representing an approximation of the gc statistics.
+
+    This function is much
+    faster than [stat] because it does not need to trigger a full major collection. *)
 external quick_stat : unit -> stat = "caml_gc_quick_stat"
 
-(** Return [(minor_words, promoted_words, major_words)].  This function
-    is as fast at [quick_stat]. *)
+(** Return [(minor_words, promoted_words, major_words)] (on the OCaml 5 runtime, for the
+    current domain or potentially previous domains).  This function is as fast as
+    [quick_stat].
+
+    Note: on the OCaml 5 runtime, [quick_stat] and [counters] might not return the same
+    value, even if there's only a single domain.
+    If there's only one domain running then [counters] returns the exact number of minor
+    words, promoted words and major words allocated so far.
+*)
 external counters : unit -> float * float * float = "caml_gc_counters"
 
-(** The following functions return the same as [(Gc.quick_stat ()).Stat.f], avoiding any
-    allocation (of the [stat] record or a float).  On 32-bit machines the [int] may
-    overflow.
+(** On 32-bit machines the [int]s returned by the following functions may overflow. *)
+
+(** Number of words allocated in the minor heap by this domain (or, on the OCaml
+    5 runtime, potentially previous domains). This number is accurate in byte-code
+    programs, but only an approximation in programs compiled to native code.
 
     Note that [minor_words] does not allocate, but we do not annotate it as [noalloc]
     because we want the compiler to save the value of the allocation pointer register
@@ -373,12 +422,14 @@ external counters : unit -> float * float * float = "caml_gc_counters"
     read its value. *)
 external minor_words : unit -> int = "core_gc_minor_words"
 
-
 external major_words : unit -> int = "core_gc_major_words" [@@noalloc]
 external promoted_words : unit -> int = "core_gc_promoted_words" [@@noalloc]
 external minor_collections : unit -> int = "core_gc_minor_collections" [@@noalloc]
 external major_collections : unit -> int = "core_gc_major_collections" [@@noalloc]
-external compactions : unit -> int = "core_gc_compactions" [@@noalloc]
+val compactions : unit -> int
+val heap_words : unit -> int
+val heap_chunks : unit -> int
+val top_heap_words : unit -> int
 
 (** This function returns [major_words () + minor_words ()].  It exists purely for speed
     (one call into C rather than two).  Like [major_words] and [minor_words],
@@ -420,7 +471,6 @@ external major : unit -> unit = "caml_gc_major"
     unreachable blocks. *)
 external full_major : unit -> unit = "caml_gc_full_major"
 
-
 (** Perform a full major collection and compact the heap.  Note that heap
     compaction is a lengthy operation. *)
 external compact : unit -> unit = "caml_gc_compaction"
@@ -434,7 +484,6 @@ val print_stat : out_channel -> unit
     with [int] on 32-bit machines. *)
 val allocated_bytes : unit -> float
 
-
 (** [keep_alive a] ensures that [a] is live at the point where [keep_alive a] is called.
     It is like [ignore a], except that the compiler won't be able to simplify it and
     potentially collect [a] too soon. *)
@@ -494,13 +543,16 @@ module For_testing : sig
   (** [measure_allocation f] measures the words allocated by running [f ()] *)
   val measure_allocation : (unit -> 'a) -> 'a * Allocation_report.t
 
+  (** Same as [measure_allocation], but for functions that return a local value. *)
+  val measure_allocation_local : (unit -> 'a) -> 'a * Allocation_report.t
+
   module Allocation_log : sig
     type t =
       { size_in_words : int
       ; is_major : bool
       ; backtrace : string
       }
-    [@@deriving sexp_of]
+    [@@deriving sexp_of, globalize]
   end
 
   (** [measure_and_log_allocation f] logs each allocation that [f ()] performs, as well as
@@ -512,23 +564,24 @@ module For_testing : sig
     :  (unit -> 'a)
     -> 'a * Allocation_report.t * Allocation_log.t list
 
+  (** Same as [measure_and_log_allocation], but for functions that return a local
+      value. *)
+  val measure_and_log_allocation_local
+    :  (unit -> 'a)
+    -> 'a * Allocation_report.t * Allocation_log.t list
+
   (** [is_zero_alloc f] runs [f ()] and returns [true] if it does not allocate, or [false]
       otherwise. [is_zero_alloc] does not allocate. *)
   val is_zero_alloc : (unit -> _) -> bool
 
-  (** [prepare_heap_to_count_minor_allocation] sets up the heap so that one can
-      subsequently measure minor allocation via:
+  (** Same as [is_zero_alloc], but for functions that return a local value. *)
+  val is_zero_alloc_local : (unit -> _) -> bool
 
-      {[
-        let minor_words_before = Gc.minor_words () in
-        (* ... do stuff ... *)
-        let minor_words_after = Gc.minor_words () in
-        let minor_words_allocated = minor_words_after - minor_words_before in
-      ]}
+  (** [assert_no_allocation [%here] f] raises if [f] allocates. *)
+  val assert_no_allocation : Source_code_position.t -> (unit -> 'a) -> 'a
 
-      Without calling [prepare_heap_to_count_minor_allocation], the resulting count may be
-      inaccurate. *)
-  val prepare_heap_to_count_minor_allocation : unit -> unit
+  (** Same as [assert_no_allocation], but for functions that return a local value. *)
+  val assert_no_allocation_local : Source_code_position.t -> (unit -> 'a) -> 'a
 end
 
 (** The [Expert] module contains functions that novice users should not use, due to their
@@ -594,7 +647,7 @@ module Expert : sig
 
   (** Same as {!add_finalizer} except that the function is not called until the value has
       become unreachable for the last time.  This means that the finalization function
-      does not recieve the value as an argument.  Every weak pointer and ephemeron that
+      does not receive the value as an argument.  Every weak pointer and ephemeron that
       contained this value as key or data is unset before running the finalization
       function. *)
   val add_finalizer_last : 'a Heap_block.t -> (unit -> unit) -> unit
@@ -638,21 +691,23 @@ module Stable : sig
     [%%if ocaml_version < (4, 12, 0)]
 
     module V1 : sig
-      type nonrec t = Stat.t [@@deriving bin_io, compare, equal, hash, sexp]
+      type nonrec t = Stat.t
+      [@@deriving bin_io, compare, equal, hash, sexp, stable_witness]
     end
 
     module V2 : sig
-      type nonrec t [@@deriving bin_io, compare, equal, hash, sexp]
+      type nonrec t [@@deriving bin_io, compare, equal, hash, sexp, stable_witness]
     end
 
     [%%else]
 
     module V1 : sig
-      type nonrec t [@@deriving bin_io, compare, equal, hash, sexp]
+      type nonrec t [@@deriving bin_io, compare, equal, hash, sexp, stable_witness]
     end
 
     module V2 : sig
-      type nonrec t = Stat.t [@@deriving bin_io, compare, equal, hash, sexp]
+      type nonrec t = Stat.t
+      [@@deriving bin_io, compare, equal, hash, sexp, stable_witness]
     end
 
     [%%endif]
@@ -660,14 +715,14 @@ module Stable : sig
 
   module Allocation_policy : sig
     module V1 : sig
-      type nonrec t = Allocation_policy.t [@@deriving bin_io, compare, equal, hash, sexp]
+      type nonrec t = Allocation_policy.t
+      [@@deriving bin_io, compare, equal, hash, sexp, stable_witness]
     end
   end
 
   module Control : sig
     module V1 : sig
-      type nonrec t = Control.t [@@deriving bin_io, compare, equal, sexp]
+      type nonrec t = Control.t [@@deriving bin_io, compare, equal, sexp, stable_witness]
     end
   end
 end
-
