@@ -12,3 +12,7 @@ end
 (** @inline *)
 include
   Int_intf.Extension with type t := t and type comparator_witness := comparator_witness
+
+include sig
+  type nonrec t = t [@@deriving bin_io ~localize]
+end
