@@ -2,12 +2,12 @@ open! Import
 open! Typerep_lib.Std
 include Base.List
 
-type 'a t = 'a list [@@deriving bin_io, typerep, stable_witness]
+type 'a t = 'a list [@@deriving bin_io ~localize, typerep, stable_witness]
 
 module Assoc = struct
   include Assoc
 
-  type ('a, 'b) t = ('a * 'b) list [@@deriving bin_io]
+  type ('a, 'b) t = ('a * 'b) list [@@deriving bin_io ~localize]
 
   let compare (type a b) compare_a compare_b = [%compare: (a * b) list]
 end
@@ -17,8 +17,8 @@ let to_string ~f t =
 ;;
 
 include Comparator.Derived (struct
-    type nonrec 'a t = 'a t [@@deriving sexp_of, compare]
-  end)
+  type nonrec 'a t = 'a t [@@deriving sexp_of, compare]
+end)
 
 let quickcheck_generator = Base_quickcheck.Generator.list
 let gen_non_empty = Base_quickcheck.Generator.list_non_empty
