@@ -41,40 +41,36 @@
 open! Import
 open Map_intf
 
-type ('key, +'value, 'cmp) t = ('key, 'value, 'cmp) Base.Map.t
-
-type ('k, 'cmp) comparator =
-  (module Comparator.S with type t = 'k and type comparator_witness = 'cmp)
+type (!'key, +!'value, !'cmp) t = ('key, 'value, 'cmp) Base.Map.t
 
 (** Test if invariants of internal AVL search tree hold. *)
 val invariants : (_, _, _) t -> bool
 
 val comparator : ('a, _, 'cmp) t -> ('a, 'cmp) Comparator.t
-val comparator_s : ('a, _, 'cmp) t -> ('a, 'cmp) comparator
+val comparator_s : ('a, _, 'cmp) t -> ('a, 'cmp) Comparator.Module.t
 
 (** The empty map. *)
-val empty : ('a, 'cmp) comparator -> ('a, 'b, 'cmp) t
+val empty : ('a, 'cmp) Comparator.Module.t -> ('a, 'b, 'cmp) t
 
 (** Map with one (key, data) pair. *)
-val singleton : ('a, 'cmp) comparator -> 'a -> 'b -> ('a, 'b, 'cmp) t
-
+val singleton : ('a, 'cmp) Comparator.Module.t -> 'a -> 'b -> ('a, 'b, 'cmp) t
 
 (** Creates map from an association list with unique keys. *)
 val of_alist
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) list
   -> [ `Ok of ('a, 'b, 'cmp) t | `Duplicate_key of 'a ]
 
 (** Creates map from an association list with unique keys. Returns an error if duplicate
     ['a] keys are found. *)
 val of_alist_or_error
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) list
   -> ('a, 'b, 'cmp) t Or_error.t
 
 (** Creates map from an association list with unique keys. Raises an exception if
     duplicate ['a] keys are found. *)
-val of_alist_exn : ('a, 'cmp) comparator -> ('a * 'b) list -> ('a, 'b, 'cmp) t
+val of_alist_exn : ('a, 'cmp) Comparator.Module.t -> ('a * 'b) list -> ('a, 'b, 'cmp) t
 
 (** [of_hashtbl_exn] creates a map from bindings present in a hash table.
     [of_hashtbl_exn] raises if there are distinct keys [a1] and [a2] in the table with
@@ -82,15 +78,21 @@ val of_alist_exn : ('a, 'cmp) comparator -> ('a * 'b) list -> ('a, 'b, 'cmp) t
     function is different than [comparator.compare]. In the common case, the comparison
     is the same, in which case [of_hashtbl_exn] does not raise, regardless of the keys
     present in the table. *)
-val of_hashtbl_exn : ('a, 'cmp) comparator -> ('a, 'b) Hashtbl.t -> ('a, 'b, 'cmp) t
+val of_hashtbl_exn
+  :  ('a, 'cmp) Comparator.Module.t
+  -> ('a, 'b) Hashtbl.t
+  -> ('a, 'b, 'cmp) t
 
 (** Creates map from an association list with possibly repeated keys. *)
-val of_alist_multi : ('a, 'cmp) comparator -> ('a * 'b) list -> ('a, 'b list, 'cmp) t
+val of_alist_multi
+  :  ('a, 'cmp) Comparator.Module.t
+  -> ('a * 'b) list
+  -> ('a, 'b list, 'cmp) t
 
 (** Combines an association list into a map, folding together bound values with common
     keys. *)
 val of_alist_fold
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) list
   -> init:'c
   -> f:('c -> 'b -> 'c)
@@ -99,7 +101,7 @@ val of_alist_fold
 (** Combines an association list into a map, reducing together bound values with common
     keys. *)
 val of_alist_reduce
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) list
   -> f:('b -> 'b -> 'b)
   -> ('a, 'b, 'cmp) t
@@ -109,25 +111,24 @@ val of_alist_reduce
     into a map: [of_iteri (module String) ~iteri:(Hashtbl.iteri table)]. It is faster than
     adding the elements one by one. *)
 val of_iteri
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> iteri:(f:(key:'a -> data:'b -> unit) -> unit)
   -> [ `Ok of ('a, 'b, 'cmp) t | `Duplicate_key of 'a ]
 
 (** Like [of_iteri] except that it raises an exception if duplicate ['a] keys are found. *)
 val of_iteri_exn
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> iteri:(f:(key:'a -> data:'b -> unit) -> unit)
   -> ('a, 'b, 'cmp) t
 
 (**
    {2 Trees}
 
-   Parallel to the three kinds of map modules [Map], [Map.Poly], and [Key.Map], there are
-   also tree modules [Map.Tree], [Map.Poly.Tree], and [Key.Map.Tree]. A tree is a bare
-   representation of a map, without the comparator. Thus tree operations need to obtain
-   the comparator from somewhere. For [Map.Poly.Tree] and [Key.Map.Tree], the comparator
-   is implicit in the module name. For [Map.Tree], the comparator must be passed to each
-   operation.
+   Parallel to the map modules [Map] and [Map.Poly], there are also tree modules
+   [Map.Tree] and [Map.Poly.Tree]. A tree is a bare representation of a map, without the
+   comparator. Thus tree operations need to obtain the comparator from somewhere. For
+   [Map.Poly.Tree], the comparator is implicit in the module name. For [Map.Tree], the
+   comparator must be passed to each operation.
 
    The main advantages of trees over maps are slightly improved space usage
    (there is no outer container holding the comparator) and the ability to marshal trees,
@@ -143,16 +144,20 @@ module Tree : sig
   type ('k, +'v, 'cmp) t = ('k, 'v, 'cmp) Tree.t [@@deriving sexp_of]
 
   include
-    Creators_and_accessors3_with_comparator
-    with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
-    with type ('a, 'b, 'c) tree := ('a, 'b, 'c) t
+    Creators_and_accessors_generic
+      with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
+      with type ('a, 'b, 'c) tree := ('a, 'b, 'c) t
+      with type 'cmp cmp := 'cmp
+      with type 'key key := 'key
+      with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) With_comparator.t
+      with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) With_comparator.t
 end
 
 val to_tree : ('k, 'v, 'cmp) t -> ('k, 'v, 'cmp) Tree.t
 
 (** Creates a [t] from a [Tree.t] and a [Comparator.t].  This is an O(n) operation as it
     must discover the length of the [Tree.t]. *)
-val of_tree : ('k, 'cmp) comparator -> ('k, 'v, 'cmp) Tree.t -> ('k, 'v, 'cmp) t
+val of_tree : ('k, 'cmp) Comparator.Module.t -> ('k, 'v, 'cmp) Tree.t -> ('k, 'v, 'cmp) t
 
 (** {2 More interface} *)
 
@@ -161,14 +166,14 @@ val of_tree : ('k, 'cmp) comparator -> ('k, 'v, 'cmp) Tree.t -> ('k, 'v, 'cmp) t
     not contain any duplicate keys.  If either of these conditions does not hold, an error
     is returned.  *)
 val of_sorted_array
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) array
   -> ('a, 'b, 'cmp) t Or_error.t
 
 (** Like [of_sorted_array] except it returns a map with broken invariants when an [Error]
     would have been returned. *)
 val of_sorted_array_unchecked
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) array
   -> ('a, 'b, 'cmp) t
 
@@ -178,7 +183,7 @@ val of_sorted_array_unchecked
     you to allocate an intermediate array. [f] will be called with 0, 1, ... [len - 1],
     in order. *)
 val of_increasing_iterator_unchecked
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> len:int
   -> f:(int -> 'a * 'b)
   -> ('a, 'b, 'cmp) t
@@ -189,7 +194,7 @@ val of_increasing_iterator_unchecked
     The sequence will be folded over once, and the additional time complexity is O(n).
 *)
 val of_increasing_sequence
-  :  ('k, 'cmp) comparator
+  :  ('k, 'cmp) Comparator.Module.t
   -> ('k * 'v) Sequence.t
   -> ('k, 'v, 'cmp) t Or_error.t
 
@@ -201,7 +206,7 @@ val of_increasing_sequence
     If your sequence is increasing, use {!of_increasing_sequence} for better performance.
 *)
 val of_sequence
-  :  ('k, 'cmp) comparator
+  :  ('k, 'cmp) Comparator.Module.t
   -> ('k * 'v) Sequence.t
   -> [ `Ok of ('k, 'v, 'cmp) t | `Duplicate_key of 'k ]
 
@@ -212,7 +217,7 @@ val of_sequence
     but does not allocate the intermediate list.
 *)
 val of_sequence_or_error
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) Sequence.t
   -> ('a, 'b, 'cmp) t Or_error.t
 
@@ -222,7 +227,10 @@ val of_sequence_or_error
     [of_sequence_exn c seq] behaves like [of_alist_exn c (Sequence.to_list seq)] but
     does not allocate the intermediate list.
 *)
-val of_sequence_exn : ('a, 'cmp) comparator -> ('a * 'b) Sequence.t -> ('a, 'b, 'cmp) t
+val of_sequence_exn
+  :  ('a, 'cmp) Comparator.Module.t
+  -> ('a * 'b) Sequence.t
+  -> ('a, 'b, 'cmp) t
 
 (** Creates a map from an association sequence with possibly repeated keys. The values in
     the map for a given key appear in the same order as they did in the association
@@ -232,7 +240,7 @@ val of_sequence_exn : ('a, 'cmp) comparator -> ('a * 'b) Sequence.t -> ('a, 'b,
     does not allocate the intermediate list.
 *)
 val of_sequence_multi
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) Sequence.t
   -> ('a, 'b list, 'cmp) t
 
@@ -243,7 +251,7 @@ val of_sequence_multi
     but does not allocate the intermediate list.
 *)
 val of_sequence_fold
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) Sequence.t
   -> init:'c
   -> f:('c -> 'b -> 'c)
@@ -256,11 +264,57 @@ val of_sequence_fold
     but does not allocate the intermediate list.
 *)
 val of_sequence_reduce
-  :  ('a, 'cmp) comparator
+  :  ('a, 'cmp) Comparator.Module.t
   -> ('a * 'b) Sequence.t
   -> f:('b -> 'b -> 'b)
   -> ('a, 'b, 'cmp) t
 
+(** Constructs a map from a list of values, where [get_key] extracts a key from a value.
+*)
+val of_list_with_key
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> [ `Ok of ('k, 'v, 'cmp) t | `Duplicate_key of 'k ]
+
+(** Like [of_list_with_key]; returns [Error] on duplicate key. *)
+val of_list_with_key_or_error
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> ('k, 'v, 'cmp) t Or_error.t
+
+(** Like [of_list_with_key]; raises on duplicate key. *)
+val of_list_with_key_exn
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> ('k, 'v, 'cmp) t
+
+(** Like [of_list_with_key]; produces lists of all values associated with each key. *)
+val of_list_with_key_multi
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> ('k, 'v list, 'cmp) t
+
+(** Like [of_list_with_key]; resolves duplicate keys the same way [of_alist_fold] does. *)
+val of_list_with_key_fold
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> init:'acc
+  -> f:('acc -> 'v -> 'acc)
+  -> ('k, 'acc, 'cmp) t
+
+(** Like [of_list_with_key]; resolves duplicate keys the same way [of_alist_fold] does. *)
+val of_list_with_key_reduce
+  :  ('k, 'cmp) Comparator.Module.t
+  -> 'v list
+  -> get_key:('v -> 'k)
+  -> f:('v -> 'v -> 'v)
+  -> ('k, 'v, 'cmp) t
+
 (** Tests whether a map is empty or not. *)
 val is_empty : (_, _, _) t -> bool
 
@@ -388,14 +442,14 @@ val mapi : ('k, 'v1, 'cmp) t -> f:(key:'k -> data:'v1 -> 'v2) -> ('k, 'v2, 'cmp)
 
 (** Convert map with keys of type ['k1] to a map with keys of type ['k2] using [f]. *)
 val map_keys
-  :  ('k2, 'cmp2) comparator
+  :  ('k2, 'cmp2) Comparator.Module.t
   -> ('k1, 'v, 'cmp1) t
   -> f:('k1 -> 'k2)
   -> [ `Ok of ('k2, 'v, 'cmp2) t | `Duplicate_key of 'k2 ]
 
 (** Like [map_keys], but raises on duplicate key. *)
 val map_keys_exn
-  :  ('k2, 'cmp2) comparator
+  :  ('k2, 'cmp2) Comparator.Module.t
   -> ('k1, 'v, 'cmp1) t
   -> f:('k1 -> 'k2)
   -> ('k2, 'v, 'cmp2) t
@@ -480,6 +534,10 @@ val partition_tf
     including all errors otherwise. *)
 val combine_errors : ('k, 'v Or_error.t, 'cmp) t -> ('k, 'v, 'cmp) t Or_error.t
 
+(** Given a map of tuples, produces a tuple of maps. Equivalent to:
+    [map t ~f:fst, map t ~f:snd] *)
+val unzip : ('k, 'v1 * 'v2, 'cmp) t -> ('k, 'v1, 'cmp) t * ('k, 'v2, 'cmp) t
+
 (** Total ordering between maps.  The first argument is a total ordering used to compare
     data associated with equal keys in the two maps. *)
 val compare_direct : ('v -> 'v -> int) -> ('k, 'v, 'cmp) t -> ('k, 'v, 'cmp) t -> int
@@ -518,13 +576,17 @@ val validatei
 
 (** Merges two maps. The runtime is O(length(t1) + length(t2)). In particular,
     you shouldn't use this function to merge a list of maps. Consider using
-    [merge_skewed] instead. *)
+    [merge_disjoint_exn] or [merge_skewed] instead. *)
 val merge
   :  ('k, 'v1, 'cmp) t
   -> ('k, 'v2, 'cmp) t
   -> f:(key:'k -> ('v1, 'v2) Merge_element.t -> 'v3 option)
   -> ('k, 'v3, 'cmp) t
 
+(** Merges two dictionaries with the same type of data and disjoint sets of keys.
+    Raises if any keys overlap. *)
+val merge_disjoint_exn : ('k, 'v, 'cmp) t -> ('k, 'v, 'cmp) t -> ('k, 'v, 'cmp) t
+
 (** A special case of [merge], [merge_skewed t1 t2] is a map containing all the
     bindings of [t1] and [t2]. Bindings that appear in both [t1] and [t2] are
     merged using the [combine] function. In a call [combine ~key v1 v2] the
@@ -592,16 +654,35 @@ val max_elt : ('k, 'v, _) t -> ('k * 'v) option
 
 val max_elt_exn : ('k, 'v, _) t -> 'k * 'v
 
+(** Swap the inner and outer keys of nested maps. If [transpose_keys m a = b], then
+    [find_exn (find_exn a i) j = find_exn (find_exn b j) i]. *)
+val transpose_keys
+  :  ('k2, 'cmp2) Comparator.Module.t
+  -> ('k1, ('k2, 'v, 'cmp2) t, 'cmp1) t
+  -> ('k2, ('k1, 'v, 'cmp1) t, 'cmp2) t
+
 (** The following functions have the same semantics as similar functions in
     {!Core.List}. *)
 
-val for_all : ('k, 'v, _) t -> f:('v -> bool) -> bool
+val for_all : (_, 'v, _) t -> f:('v -> bool) -> bool
 val for_alli : ('k, 'v, _) t -> f:(key:'k -> data:'v -> bool) -> bool
-val exists : ('k, 'v, _) t -> f:('v -> bool) -> bool
+val exists : (_, 'v, _) t -> f:('v -> bool) -> bool
 val existsi : ('k, 'v, _) t -> f:(key:'k -> data:'v -> bool) -> bool
-val count : ('k, 'v, _) t -> f:('v -> bool) -> int
+val count : (_, 'v, _) t -> f:('v -> bool) -> int
 val counti : ('k, 'v, _) t -> f:(key:'k -> data:'v -> bool) -> int
 
+val sum
+  :  (module Container.Summable with type t = 'a)
+  -> (_, 'v, _) t
+  -> f:('v -> 'a)
+  -> 'a
+
+val sumi
+  :  (module Container.Summable with type t = 'a)
+  -> ('k, 'v, _) t
+  -> f:(key:'k -> data:'v -> 'a)
+  -> 'a
+
 (** [split t key] returns a map of keys strictly less than [key], the mapping of [key] if
     any, and a map of keys strictly greater than [key].
 
@@ -613,6 +694,22 @@ val split
   -> 'k
   -> ('k, 'v, 'cmp) t * ('k * 'v) option * ('k, 'v, 'cmp) t
 
+(** [split_le_gt t key] returns a map of keys that are less or equal to [key] and a
+    map of keys strictly greater than [key].
+
+    Runtime is O(m + log n), where n is the size of the input map and m is the size of
+    the smaller of the two output maps.  The O(m) term is due to the need to calculate
+    the length of the output maps. *)
+val split_le_gt : ('k, 'v, 'cmp) t -> 'k -> ('k, 'v, 'cmp) t * ('k, 'v, 'cmp) t
+
+(** [split_lt_ge t key] returns a map of keys strictly less than [key] and a map of
+    keys that are greater or equal to [key].
+
+    Runtime is O(m + log n), where n is the size of the input map and m is the size of
+    the smaller of the two output maps.  The O(m) term is due to the need to calculate
+    the length of the output maps. *)
+val split_lt_ge : ('k, 'v, 'cmp) t -> 'k -> ('k, 'v, 'cmp) t * ('k, 'v, 'cmp) t
+
 (** [append ~lower_part ~upper_part] returns [`Ok map] where [map] contains all the [(key,
     value)] pairs from the two input maps if all the keys from [lower_part] are less than
     all the keys from [upper_part]. Otherwise it returns [`Overlapping_key_ranges].
@@ -774,6 +871,20 @@ val binary_search_subrange
   -> upper_bound:'bound Maybe_bound.t
   -> ('k, 'v, 'cmp) t
 
+(** Creates traversals to reconstruct a map within an applicative. Uses
+    [Lazy_applicative] so that the map can be traversed within the applicative, rather
+    than needing to be traversed all at once, outside the applicative. *)
+module Make_applicative_traversals (A : Applicative.Lazy_applicative) : sig
+  val mapi
+    :  ('k, 'v1, 'cmp) t
+    -> f:(key:'k -> data:'v1 -> 'v2 A.t)
+    -> ('k, 'v2, 'cmp) t A.t
+
+  val filter_mapi
+    :  ('k, 'v1, 'cmp) t
+    -> f:(key:'k -> data:'v1 -> 'v2 option A.t)
+    -> ('k, 'v2, 'cmp) t A.t
+end
 
 (** Convert a set to a map. Runs in [O(length t)] time plus a call to [f] for each key to
     compute the associated data. *)
@@ -782,9 +893,8 @@ val of_key_set : ('key, 'cmp) Base.Set.t -> f:('key -> 'data) -> ('key, 'data, '
 (** Converts a map to a set of its keys. Runs in [O(length t)] time. *)
 val key_set : ('key, _, 'cmp) t -> ('key, 'cmp) Base.Set.t
 
-
 val quickcheck_generator
-  :  ('k, 'cmp) comparator
+  :  ('k, 'cmp) Comparator.Module.t
   -> 'k Quickcheck.Generator.t
   -> 'v Quickcheck.Generator.t
   -> ('k, 'v, 'cmp) t Quickcheck.Generator.t
@@ -868,31 +978,45 @@ val quickcheck_shrinker
 
 module Using_comparator : sig
   include
-    Creators3_with_comparator
-    with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
-    with type ('a, 'b, 'c) tree := ('a, 'b, 'c) Tree.t
+    Creators_generic
+      with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
+      with type ('a, 'b, 'c) tree := ('a, 'b, 'c) Tree.t
+      with type 'k key := 'k
+      with type 'c cmp := 'c
+      with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) With_comparator.t
+      with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) Without_comparator.t
 end
 
 module Poly : sig
   type ('a, +'b, 'c) map
 
   module Tree : sig
-    type ('k, +'v) t = ('k, 'v, Comparator.Poly.comparator_witness) Tree.t
-    [@@deriving sexp, sexp_grammar]
+    type comparator_witness = Comparator.Poly.comparator_witness
+    type ('k, +'v) t = ('k, 'v, comparator_witness) Tree.t [@@deriving sexp, sexp_grammar]
 
     include
-      Creators_and_accessors2
-      with type ('a, 'b) t := ('a, 'b) t
-      with type ('a, 'b) tree := ('a, 'b) t
+      Creators_and_accessors_generic
+        with type ('a, 'b, 'c) t := ('a, 'b) t
+        with type ('a, 'b, 'c) tree := ('a, 'b) t
+        with type 'k key := 'k
+        with type 'c cmp := comparator_witness
+        with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) Without_comparator.t
+        with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) Without_comparator.t
   end
 
-  type ('a, +'b) t = ('a, 'b, Comparator.Poly.comparator_witness) map
+  type comparator_witness = Comparator.Poly.comparator_witness
+
+  type ('a, +'b) t = ('a, 'b, comparator_witness) map
   [@@deriving bin_io, sexp, sexp_grammar, compare]
 
   include
-    Creators_and_accessors2
-    with type ('a, 'b) t := ('a, 'b) t
-    with type ('a, 'b) tree := ('a, 'b) Tree.t
+    Creators_and_accessors_generic
+      with type ('a, 'b, 'c) t := ('a, 'b) t
+      with type ('a, 'b, 'c) tree := ('a, 'b) Tree.t
+      with type 'k key := 'k
+      with type 'c cmp := comparator_witness
+      with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) Without_comparator.t
+      with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) Without_comparator.t
 end
 with type ('a, 'b, 'c) map = ('a, 'b, 'c) t
 
@@ -906,47 +1030,47 @@ module type S_binable = S_binable
 module Make_plain (Key : Key_plain) : S_plain with type Key.t = Key.t
 
 module Make_plain_using_comparator (Key : sig
-    type t [@@deriving sexp_of]
+  type t [@@deriving sexp_of]
 
-    include Comparator.S with type t := t
-  end) :
+  include Comparator.S with type t := t
+end) :
   S_plain
-  with type Key.t = Key.t
-  with type Key.comparator_witness = Key.comparator_witness
+    with type Key.t = Key.t
+    with type Key.comparator_witness = Key.comparator_witness
 
 module Make (Key : Key) : S with type Key.t = Key.t
 
 module Make_using_comparator (Key : sig
-    type t [@@deriving sexp]
+  type t [@@deriving sexp]
 
-    include Comparator.S with type t := t
-  end) : S with type Key.t = Key.t with type Key.comparator_witness = Key.comparator_witness
+  include Comparator.S with type t := t
+end) : S with type Key.t = Key.t with type Key.comparator_witness = Key.comparator_witness
 
 module Make_binable (Key : Key_binable) : S_binable with type Key.t = Key.t
 
 module Make_binable_using_comparator (Key : sig
-    type t [@@deriving bin_io, sexp]
+  type t [@@deriving bin_io, sexp]
 
-    include Comparator.S with type t := t
-  end) :
+  include Comparator.S with type t := t
+end) :
   S_binable
-  with type Key.t = Key.t
-  with type Key.comparator_witness = Key.comparator_witness
+    with type Key.t = Key.t
+    with type Key.comparator_witness = Key.comparator_witness
 
 module Key_bin_io = Key_bin_io
 include For_deriving with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
 
 module Make_tree_plain (Key : sig
-    type t [@@deriving sexp_of]
+  type t [@@deriving sexp_of]
 
-    include Comparator.S with type t := t
-  end) : Make_S_plain_tree(Key).S
+  include Comparator.S with type t := t
+end) : Make_S_plain_tree(Key).S
 
 module Make_tree (Key : sig
-    type t [@@deriving sexp]
+  type t [@@deriving sexp]
 
-    include Comparator.S with type t := t
-  end) : sig
+  include Comparator.S with type t := t
+end) : sig
   include Make_S_plain_tree(Key).S
   include Sexpable.S1 with type 'a t := 'a t
 end
@@ -962,17 +1086,35 @@ module Stable : sig
       type nonrec 'a t = (key, 'a, comparator_witness) t
 
       include Stable_module_types.S1 with type 'a t := 'a t
+
+      include
+        Diffable.S1
+          with type 'a t := 'a t
+           and type ('a, 'a_diff) Diff.t =
+            (key, 'a, 'a_diff) Diffable.Map_diff.Stable.V1.t
     end
 
     include For_deriving with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
+    include For_deriving_stable with type ('a, 'b, 'c) t := ('a, 'b, 'c) t
 
     module Make (Key : Stable_module_types.S0) :
       S with type key := Key.t with type comparator_witness := Key.comparator_witness
+
+    module With_stable_witness : sig
+      module type S = sig
+        include S
+
+        val stable_witness : 'a Stable_witness.t -> 'a t Stable_witness.t
+      end
+
+      module Make (Key : Stable_module_types.With_stable_witness.S0) :
+        S with type key := Key.t with type comparator_witness := Key.comparator_witness
+    end
   end
 
   module Symmetric_diff_element : sig
     module V1 :
-      Stable_module_types.S2 with type ('a, 'b) t = ('a, 'b) Symmetric_diff_element.t
+      Stable_module_types.With_stable_witness.S2
+        with type ('a, 'b) t = ('a, 'b) Symmetric_diff_element.t
   end
 end
-
