@@ -2,7 +2,7 @@ open! Import
 
 module Stable = struct
   module V1 = struct
-    type t = Base.Nothing.t = |
+    type t = Base.Nothing.t = | [@@deriving sexp_grammar]
 
     module Shape = struct
       type t [@@deriving bin_shape]
@@ -15,6 +15,7 @@ module Stable = struct
     let hash_fold_t _ t = unreachable_code t
     let hash = unreachable_code
     let compare a _ = unreachable_code a
+    let equal a _ = unreachable_code a
     let bin_size_t = unreachable_code
     let bin_write_t _buf ~pos:_ t = unreachable_code t
     let bin_writer_t = { Bin_prot.Type_class.size = bin_size_t; write = bin_write_t }
