@@ -1,14 +1,15 @@
 open! Import
 open Std_internal
 open! Int63.O
+module Rounding_direction = Time_ns_intf.Rounding_direction
 
 let module_name = "Core.Time_ns.Span"
 
 type underlying = Int63.t
 
 let arch_sixtyfour = Int.equal Sys.word_size_in_bits 64
-let round_nearest = Float.int63_round_nearest_exn
-let float x = Int63.to_float x
+let round_nearest_ns = Float.int63_round_nearest_exn
+let[@inline] float x = Int63.to_float x
 
 (* [Span] is basically a [Int63].  It even silently ignores overflow. *)
 module T = struct
@@ -44,6 +45,18 @@ let second = Int63.(of_int 1000 * millisecond)
 let minute = Int63.(of_int 60 * second)
 let hour = Int63.(of_int 60 * minute)
 let day = Int63.(of_int 24 * hour)
+let float_microsecond = float microsecond
+let float_millisecond = float millisecond
+let float_second = float second
+let float_minute = float minute
+let float_hour = float hour
+let float_day = float day
+let ns_per_us = 1. /. float_microsecond
+let ns_per_ms = 1. /. float_millisecond
+let ns_per_sec = 1. /. float_second
+let ns_per_min = 1. /. float_minute
+let ns_per_hr = 1. /. float_hour
+let ns_per_day = 1. /. float_day
 
 (* Beyond [min_value_for_1us_rounding..max_value_for_1us_rounding], not every microsecond
    can be represented as a [float] number of seconds. (In fact, it is around 135y, but we
@@ -55,15 +68,15 @@ let max_value_for_1us_rounding = Int63.(of_int 135 * of_int 365 * day)
 let min_value_for_1us_rounding = Int63.neg max_value_for_1us_rounding
 
 let create
-      ?sign:(sign_ = Sign.Pos (* rebind so not shadowed by [open Int63] below *))
-      ?day:(days = 0)
-      ?(hr = 0)
-      ?min:(minutes = 0)
-      ?(sec = 0)
-      ?(ms = 0)
-      ?(us = 0)
-      ?(ns = 0)
-      ()
+  ?sign:(sign_ = Sign.Pos (* rebind so not shadowed by [open Int63] below *))
+  ?day:(days = 0)
+  ?(hr = 0)
+  ?min:(minutes = 0)
+  ?(sec = 0)
+  ?(ms = 0)
+  ?(us = 0)
+  ?(ns = 0)
+  ()
   =
   let open Int63 in
   let t =
@@ -97,7 +110,7 @@ let of_parts { Parts.sign; hr; min; sec; ms; us; ns } =
   create ~sign ~hr ~min ~sec ~ms ~us ~ns ()
 ;;
 
-let of_ns f = round_nearest f
+let of_ns f = round_nearest_ns f
 let of_int63_ns i = i
 let of_int_us i = Int63.(of_int i * microsecond)
 let of_int_ms i = Int63.(of_int i * millisecond)
@@ -105,29 +118,34 @@ let of_int_sec i = Int63.(of_int i * second)
 let of_int_min i = Int63.(of_int i * minute)
 let of_int_hr i = Int63.(of_int i * hour)
 let of_int_day i = Int63.(of_int i * day)
-let of_us f = round_nearest (f *. float microsecond)
-let of_ms f = round_nearest (f *. float millisecond)
-let of_sec f = round_nearest (f *. float second)
-let of_min f = round_nearest (f *. float minute)
-let of_hr f = round_nearest (f *. float hour)
-let of_day f = round_nearest (f *. float day)
+let of_us f = round_nearest_ns (f *. float_microsecond)
+let of_ms f = round_nearest_ns (f *. float_millisecond)
+let[@inline] of_sec f = round_nearest_ns (f *. float_second)
+let of_min f = round_nearest_ns (f *. float_minute)
+let of_hr f = round_nearest_ns (f *. float_hour)
+let of_day f = round_nearest_ns (f *. float_day)
 
 let of_sec_with_microsecond_precision sec =
-  let us = round_nearest (sec *. 1e6) in
+  let us = round_nearest_ns (sec *. 1e6) in
   of_int63_ns Int63.(us * of_int 1000)
 ;;
 
 let of_int63_seconds x = x * second
 let of_int32_seconds x = of_int63_seconds (Int63.of_int32 x)
-
 let to_ns t = float t
 let to_int63_ns t = t
-let to_us t = float t /. float microsecond
-let to_ms t = float t /. float millisecond
-let to_sec t = float t /. float second
-let to_min t = float t /. float minute
-let to_hr t = float t /. float hour
-let to_day t = float t /. float day
+let[@inline] to_us t = float t /. float_microsecond
+let[@inline] to_ms t = float t /. float_millisecond
+let[@inline] to_sec t = float t /. float_second
+let[@inline] to_min t = float t /. float_minute
+let[@inline] to_hr t = float t /. float_hour
+let[@inline] to_day t = float t /. float_day
+let[@inline] to_us_approx t = float t *. ns_per_us
+let[@inline] to_ms_approx t = float t *. ns_per_ms
+let[@inline] to_sec_approx t = float t *. ns_per_sec
+let[@inline] to_min_approx t = float t *. ns_per_min
+let[@inline] to_hr_approx t = float t *. ns_per_hr
+let[@inline] to_day_approx t = float t *. ns_per_day
 let to_int_us t = Int63.(to_int_exn (t / microsecond))
 let to_int_ms t = Int63.(to_int_exn (t / millisecond))
 let to_int_sec t = Int63.(to_int_exn (t / second))
@@ -144,11 +162,11 @@ let ( + ) t u = Int63.( + ) t u
 let ( - ) t u = Int63.( - ) t u
 let abs = Int63.abs
 let neg = Int63.neg
-let scale t f = round_nearest (float t *. f)
+let scale t f = round_nearest_ns (float t *. f)
 let scale_int63 t i = Int63.( * ) t i
 let scale_int t i = scale_int63 t (Int63.of_int i)
 let div = Int63.( /% )
-let ( / ) t f = round_nearest (float t /. f)
+let ( / ) t f = round_nearest_ns (float t /. f)
 let ( // ) = Int63.( // )
 let to_proportional_float t = Int63.to_float t
 
@@ -181,7 +199,19 @@ let to_unit_of_time t : Unit_of_time.t =
 ;;
 
 let to_span_float_round_nearest t = Span_float.of_sec (to_sec t)
-let of_span_float_round_nearest s = of_sec (Span_float.to_sec s)
+let[@inline] of_span_float_round_nearest s = of_sec (Span_float.to_sec s)
+let round_up t ~to_multiple_of = Int63.round_up ~to_multiple_of t
+let round_down t ~to_multiple_of = Int63.round_down ~to_multiple_of t
+let round_nearest t ~to_multiple_of = Int63.round_nearest ~to_multiple_of t
+let round_towards_zero t ~to_multiple_of = Int63.round_towards_zero ~to_multiple_of t
+
+let round t ~dir ~to_multiple_of =
+  match (dir : Rounding_direction.t) with
+  | Nearest -> round_nearest t ~to_multiple_of
+  | Down -> round_down t ~to_multiple_of
+  | Up -> round_up t ~to_multiple_of
+  | Zero -> round_towards_zero t ~to_multiple_of
+;;
 
 module Stable0 = struct
   module V1 = struct
@@ -198,12 +228,17 @@ module Stable0 = struct
         of_span_float_round_nearest (Time_float.Stable.Span.V1.t_of_sexp s)
       ;;
 
+      let t_sexp_grammar : t Sexplib0.Sexp_grammar.t =
+        Sexplib0.Sexp_grammar.coerce Time_float.Stable.Span.V1.t_sexp_grammar
+      ;;
+
       let of_int63_exn t = of_int63_ns t
       let to_int63 t = to_int63_ns t
     end
 
     include T
     include Comparator.Stable.V1.Make (T)
+    include Diffable.Atomic.Make (T)
   end
 
   module V2 = struct
@@ -509,12 +544,12 @@ module Stable0 = struct
           ;;
 
           let negative_part
-                string
-                ~neg_integer
-                ~decimal_pos
-                ~end_pos
-                ~unit_of_time
-                ~round_ties_before_negating
+            string
+            ~neg_integer
+            ~decimal_pos
+            ~end_pos
+            ~unit_of_time
+            ~round_ties_before_negating
             =
             let open Int.O in
             let scale = to_int63_ns (of_unit_of_time unit_of_time) in
@@ -675,6 +710,7 @@ module Stable0 = struct
 
     include T
     include Comparable.Stable.V1.With_stable_witness.Make (T)
+    include Diffable.Atomic.Make (T)
   end
 end
 
@@ -693,10 +729,10 @@ module Alternate_sexp = struct
 end
 
 include Comparable.With_zero (struct
-    type nonrec t = t [@@deriving compare, sexp]
+  type nonrec t = t [@@deriving compare, sexp]
 
-    let zero = zero
-  end)
+  let zero = zero
+end)
 
 (* Functions required by [Robustly_comparable]: allows for [robust_comparison_tolerance]
    granularity.
@@ -715,11 +751,11 @@ let robustly_compare t u = if t <. u then -1 else if t >. u then 1 else 0
 (* We don't just convert to [Time.Span.t] and use the conversion there because our
    [to_span] conversion is limited to microsecond precision. *)
 let to_string_hum
-      ?(delimiter = '_')
-      ?(decimals = 3)
-      ?(align_decimal = false)
-      ?unit_of_time
-      t
+  ?(delimiter = '_')
+  ?(decimals = 3)
+  ?(align_decimal = false)
+  ?unit_of_time
+  t
   =
   let float, suffix =
     match Option.value unit_of_time ~default:(to_unit_of_time t) with
@@ -760,24 +796,28 @@ let gen_incl = Int63.gen_incl
 let gen_uniform_incl = Int63.gen_uniform_incl
 
 include Pretty_printer.Register (struct
-    type nonrec t = t
+  type nonrec t = t
 
-    let to_string = to_string
-    let module_name = module_name
-  end)
+  let to_string = to_string
+  let module_name = module_name
+end)
 
 include Hashable.Make_binable (struct
-    type nonrec t = t [@@deriving bin_io, compare, hash, sexp]
-  end)
+  type nonrec t = t [@@deriving bin_io, compare, hash, sexp]
+end)
 
 type comparator_witness = Stable.V2.comparator_witness
 
 include Comparable.Make_binable_using_comparator (struct
-    type nonrec t = t [@@deriving bin_io, compare, sexp]
-    type nonrec comparator_witness = comparator_witness
+  type nonrec t = t [@@deriving bin_io, compare, sexp]
+  type nonrec comparator_witness = comparator_witness
 
-    let comparator = Stable.V2.comparator
-  end)
+  let comparator = Stable.V2.comparator
+end)
+
+include Diffable.Atomic.Make (struct
+  type nonrec t = t [@@deriving bin_io, sexp, equal]
+end)
 
 (* re-include [Replace_polymorphic_compare] and its comparisons to shadow the
    un-inlineable ones from [Comparable] *)
@@ -816,7 +856,7 @@ let max_span_float_value_for_1us_rounding =
 
 let of_span_float_round_nearest_microsecond s =
   if Span_float.( > ) s max_span_float_value_for_1us_rounding
-  || Span_float.( < ) s min_span_float_value_for_1us_rounding
+     || Span_float.( < ) s min_span_float_value_for_1us_rounding
   then
     failwiths
       ~here:[%here]
@@ -833,6 +873,22 @@ let of_span_float_round_nearest_microsecond s =
 let min_value_representable = of_int63_ns Int63.min_value
 let max_value_representable = of_int63_ns Int63.max_value
 
+module O = struct
+  let ( / ) = ( / )
+  let ( // ) = ( // )
+  let ( + ) = ( + )
+  let ( - ) = ( - )
+  let ( >= ) = ( >= )
+  let ( <= ) = ( <= )
+  let ( = ) = ( = )
+  let ( > ) = ( > )
+  let ( < ) = ( < )
+  let ( <> ) = ( <> )
+  let ( ~- ) = neg
+  let ( *. ) = scale
+  let ( * ) = scale_int
+end
+
 module Private = struct
   let of_parts = of_parts
   let to_parts = to_parts
@@ -846,7 +902,7 @@ let to_span = to_span_float_round_nearest_microsecond
 
 module Option = struct
   type span = t [@@deriving sexp]
-  type t = Int63.t [@@deriving bin_io, compare, hash, typerep]
+  type t = Int63.t [@@deriving bin_io, compare, equal, hash, typerep]
   (* nanoseconds or none *)
 
   let none = Int63.min_value
@@ -921,7 +977,7 @@ module Option = struct
   module Stable = struct
     module V1 = struct
       module T = struct
-        type nonrec t = t [@@deriving compare, bin_io]
+        type nonrec t = t [@@deriving bin_io, compare, equal]
 
         let v1_some span =
           assert (some_is_representable span);
@@ -943,11 +999,12 @@ module Option = struct
 
       include T
       include Comparator.Stable.V1.Make (T)
+      include Diffable.Atomic.Make (T)
     end
 
     module V2 = struct
       module T = struct
-        type nonrec t = t [@@deriving compare, bin_io]
+        type nonrec t = t [@@deriving bin_io, compare, equal]
 
         let sexp_of_t t =
           Sexp.List
@@ -985,6 +1042,7 @@ module Option = struct
 
       include T
       include Comparator.Stable.V1.Make (T)
+      include Diffable.Atomic.Make (T)
     end
   end
 
@@ -992,14 +1050,18 @@ module Option = struct
   let t_of_sexp = Stable.V2.t_of_sexp
 
   include Identifiable.Make (struct
-      type nonrec t = t [@@deriving sexp, compare, bin_io, hash]
+    type nonrec t = t [@@deriving sexp, compare, bin_io, hash]
 
-      let module_name = "Core.Time_ns.Span.Option"
+    let module_name = "Core.Time_ns.Span.Option"
 
-      include Sexpable.To_stringable (struct
-          type nonrec t = t [@@deriving sexp]
-        end)
+    include Sexpable.To_stringable (struct
+      type nonrec t = t [@@deriving sexp]
     end)
+  end)
+
+  include Diffable.Atomic.Make (struct
+    type nonrec t = t [@@deriving bin_io, sexp, equal]
+  end)
 
   include (Int63 : Comparisons.S with type t := t)
 end
