@@ -97,7 +97,7 @@ let max_time_value_for_1us_rounding =
 
 let check_before_conversion_for_1us_rounding time =
   if Time_float.( < ) time min_time_value_for_1us_rounding
-  || Time_float.( > ) time max_time_value_for_1us_rounding
+     || Time_float.( > ) time max_time_value_for_1us_rounding
   then
     failwiths
       ~here:[%here]
@@ -106,7 +106,7 @@ let check_before_conversion_for_1us_rounding time =
       [%sexp_of: Time_float.Stable.With_utc_sexp.V2.t]
 ;;
 
-let of_time_float_round_nearest time =
+let[@inline] of_time_float_round_nearest time =
   of_span_since_epoch
     (Span.of_span_float_round_nearest (Time_float.to_span_since_epoch time))
 ;;
@@ -117,17 +117,17 @@ let of_time_float_round_nearest_microsecond time =
     (Span.of_span_float_round_nearest_microsecond (Time_float.to_span_since_epoch time))
 ;;
 
-let[@cold] raise_next_multiple_got_nonpositive_interval interval =
+let[@cold] raise_next_multiple_got_nonpositive_interval ~calling_function_name interval =
   failwiths
     ~here:[%here]
-    "Time_ns.next_multiple got nonpositive interval"
+    ("Time_ns." ^ calling_function_name ^ " got nonpositive interval")
     interval
     [%sexp_of: Span.t]
 ;;
 
-let next_multiple_internal ~can_equal_after ~base ~after ~interval =
+let next_multiple_internal ~calling_function_name ~can_equal_after ~base ~after ~interval =
   if Span.( <= ) interval Span.zero
-  then raise_next_multiple_got_nonpositive_interval interval;
+  then raise_next_multiple_got_nonpositive_interval ~calling_function_name interval;
   let base_to_after = diff after base in
   if Span.( < ) base_to_after Span.zero
   then base (* [after < base], choose [k = 0]. *)
@@ -136,18 +136,81 @@ let next_multiple_internal ~can_equal_after ~base ~after ~interval =
     if next > after || (can_equal_after && next = after) then next else add next interval)
 ;;
 
-let next_multiple ?(can_equal_after = false) ~base ~after ~interval () =
-  next_multiple_internal ~can_equal_after ~base ~after ~interval
-;;
-
-let prev_multiple ?(can_equal_before = false) ~base ~before ~interval () =
+let prev_multiple_internal
+  ~calling_function_name
+  ~can_equal_before
+  ~base
+  ~before
+  ~interval
+  =
   next_multiple_internal
+    ~calling_function_name
     ~can_equal_after:(not can_equal_before)
     ~base
     ~after:(sub before interval)
     ~interval
 ;;
 
+let next_multiple ?(can_equal_after = false) ~base ~after ~interval () =
+  next_multiple_internal
+    ~calling_function_name:"next_multiple"
+    ~can_equal_after
+    ~base
+    ~after
+    ~interval
+;;
+
+let prev_multiple ?(can_equal_before = false) ~base ~before ~interval () =
+  prev_multiple_internal
+    ~calling_function_name:"prev_multiple"
+    ~can_equal_before
+    ~base
+    ~before
+    ~interval
+;;
+
+let round_up t ~interval ~calling_function_name =
+  next_multiple_internal
+    ~calling_function_name
+    ~can_equal_after:true
+    ~base:epoch
+    ~after:t
+    ~interval
+;;
+
+let round_down t ~interval ~calling_function_name =
+  prev_multiple_internal
+    ~calling_function_name
+    ~can_equal_before:true
+    ~base:epoch
+    ~before:t
+    ~interval
+;;
+
+let round_up_to_us t =
+  round_up t ~interval:Span.microsecond ~calling_function_name:"round_up_to_us"
+;;
+
+let round_up_to_ms t =
+  round_up t ~interval:Span.millisecond ~calling_function_name:"round_up_to_ms"
+;;
+
+let round_up_to_sec t =
+  round_up t ~interval:Span.second ~calling_function_name:"round_up_to_sec"
+;;
+
+let round_down_to_us t =
+  round_down t ~interval:Span.microsecond ~calling_function_name:"round_down_to_us"
+;;
+
+let round_down_to_ms t =
+  round_down t ~interval:Span.millisecond ~calling_function_name:"round_down_to_ms"
+;;
+
+let round_down_to_sec t =
+  round_down t ~interval:Span.second ~calling_function_name:"round_down_to_sec"
+;;
+
 let random ?state () = Span.random ?state ()
 
 module Utc : sig
@@ -191,7 +254,7 @@ end
 
 module Alternate_sexp = struct
   module T = struct
-    type nonrec t = t [@@deriving compare, hash]
+    type nonrec t = t [@@deriving bin_io, compare, hash]
 
     module Ofday_as_span = struct
       open Int.O
@@ -309,11 +372,11 @@ module Alternate_sexp = struct
     ;;
 
     include Sexpable.Of_stringable (struct
-        type nonrec t = t
+      type nonrec t = t
 
-        let to_string = to_string
-        let of_string = of_string
-      end)
+      let to_string = to_string
+      let of_string = of_string
+    end)
 
     let t_sexp_grammar =
       let open Sexplib in
@@ -328,12 +391,16 @@ module Alternate_sexp = struct
   include Comparable.Make (T)
   include Replace_polymorphic_compare_efficient
 
+  include Diffable.Atomic.Make (struct
+    type nonrec t = t [@@deriving bin_io, equal, sexp]
+  end)
+
   module Stable = struct
     module V1 = struct
       module T = struct
         (* see tests in lib/core/test/src/test_time_ns that ensure stability of this
            representation *)
-        type nonrec t = t [@@deriving bin_io, compare, hash, sexp, sexp_grammar]
+        type nonrec t = t [@@deriving bin_io, compare, equal, hash, sexp, sexp_grammar]
 
         let stable_witness : t Stable_witness.t = Stable_witness.assert_stable
 
@@ -344,13 +411,121 @@ module Alternate_sexp = struct
 
       include T
       include Comparable.Stable.V1.With_stable_witness.Make (T)
+      include Diffable.Atomic.Make (T)
     end
   end
 end
 
+module Option0 = struct
+  type time = t [@@deriving compare]
+  type t = Span.Option.t [@@deriving bin_io, compare, hash, typerep, quickcheck]
+
+  let none = Span.Option.none
+  let some time = Span.Option.some (to_span_since_epoch time)
+  let is_none = Span.Option.is_none
+  let is_some = Span.Option.is_some
+
+  let some_is_representable time =
+    Span.Option.some_is_representable (to_span_since_epoch time)
+  ;;
+
+  let value t ~default =
+    of_span_since_epoch (Span.Option.value ~default:(to_span_since_epoch default) t)
+  ;;
+
+  let value_exn t =
+    if is_some t
+    then of_span_since_epoch (Span.Option.unchecked_value t)
+    else raise_s [%message [%here] "Time_ns.Option.value_exn none"]
+  ;;
+
+  let unchecked_value t = of_span_since_epoch (Span.Option.unchecked_value t)
+
+  let of_option = function
+    | None -> none
+    | Some t -> some t
+  ;;
+
+  let to_option t = if is_none t then None else Some (value_exn t)
+
+  module Optional_syntax = struct
+    module Optional_syntax = struct
+      let is_none = is_none
+      let unsafe_value = unchecked_value
+    end
+  end
+
+  module Alternate_sexp = struct
+    module T = struct
+      type nonrec t = t [@@deriving bin_io, compare, hash]
+
+      let sexp_of_t t = [%sexp_of: Alternate_sexp.t option] (to_option t)
+      let t_of_sexp s = of_option ([%of_sexp: Alternate_sexp.t option] s)
+
+      let t_sexp_grammar =
+        Sexplib.Sexp_grammar.coerce [%sexp_grammar: Alternate_sexp.t option]
+      ;;
+    end
+
+    include T
+    include Comparable.Make (T)
+
+    include Diffable.Atomic.Make (struct
+      include T
+
+      let equal = [%compare.equal: t]
+    end)
+
+    module Stable = struct
+      module V1 = struct
+        module T = struct
+          type nonrec t = t [@@deriving bin_io, compare, hash, sexp, sexp_grammar]
+
+          let stable_witness : t Stable_witness.t =
+            Stable_witness.of_serializable
+              [%stable_witness: Alternate_sexp.Stable.V1.t option]
+              of_option
+              to_option
+          ;;
+
+          type nonrec comparator_witness = comparator_witness
+
+          let comparator = comparator
+        end
+
+        include T
+        include Comparable.Stable.V1.With_stable_witness.Make (T)
+
+        include Diffable.Atomic.Make (struct
+          include T
+
+          let equal = [%compare.equal: t]
+        end)
+      end
+    end
+  end
+
+  module Stable = struct
+    module V1 = struct
+      type nonrec t = t [@@deriving compare, bin_io]
+
+      let stable_witness : t Stable_witness.t = Stable_witness.assert_stable
+      let to_int63 t = Span.Option.Stable.V1.to_int63 t
+      let of_int63_exn t = Span.Option.Stable.V1.of_int63_exn t
+    end
+
+    module Alternate_sexp = Alternate_sexp.Stable
+  end
+
+  let sexp_of_t = `Use_Time_ns_unix
+
+  (* bring back the efficient implementation of comparison operators *)
+  include (Span.Option : Comparisons.S with type t := t)
+end
+
 module Stable = struct
   module V1 = struct end
-  module Option = struct end
+  module Option = Option0.Stable
   module Alternate_sexp = Alternate_sexp.Stable
   module Span = Span.Stable
   module Ofday = Ofday.Stable
@@ -381,7 +556,7 @@ module To_and_of_string : sig
   val utc_offset : t -> zone:Zone.t -> Span.t
 
   val of_string : string -> t
-  [@@deprecated "[since 2021-04] Use [of_string_with_utc_offset]"]
+    [@@deprecated "[since 2021-04] Use [of_string_with_utc_offset]"]
 
   val of_string_with_utc_offset : string -> t
   val to_string : t -> string [@@deprecated "[since 2021-04] Use [to_string_utc]"]
@@ -864,8 +1039,8 @@ end = struct
   let ensure_colon_in_offset offset =
     let offset_length = String.length offset in
     if Int.( <= ) offset_length 2
-    && Char.is_digit offset.[0]
-    && Char.is_digit offset.[offset_length - 1]
+       && Char.is_digit offset.[0]
+       && Char.is_digit offset.[offset_length - 1]
     then offset ^ ":00"
     else if Char.( = ) offset.[1] ':' || Char.( = ) offset.[2] ':'
     then offset
@@ -955,30 +1130,30 @@ module _ = struct
 
   let () =
     Duration.format
-    := (module struct
-      let duration_of_span s = s |> Span.to_int63_ns |> Duration.of_nanoseconds
-      let span_of_duration d = d |> Duration.to_nanoseconds |> Span.of_int63_ns
-      let of_string string = string |> Span.of_string |> duration_of_span
+      := (module struct
+           let duration_of_span s = s |> Span.to_int63_ns |> Duration.of_nanoseconds
+           let span_of_duration d = d |> Duration.to_nanoseconds |> Span.of_int63_ns
+           let of_string string = string |> Span.of_string |> duration_of_span
 
-      let to_string_with_same_unit durations =
-        let spans = durations |> List.map ~f:span_of_duration in
-        let unit_of_time =
-          spans
-          |> List.max_elt ~compare:Span.compare
-          |> Option.value_map
-               ~f:Span.to_unit_of_time
-               ~default:Unit_of_time.Nanosecond
-        in
-        spans |> List.map ~f:(Span.to_string_hum ~unit_of_time ~align_decimal:true)
-      ;;
-    end)
+           let to_string_with_same_unit durations =
+             let spans = durations |> List.map ~f:span_of_duration in
+             let unit_of_time =
+               spans
+               |> List.max_elt ~compare:Span.compare
+               |> Option.value_map
+                    ~f:Span.to_unit_of_time
+                    ~default:Unit_of_time.Nanosecond
+             in
+             spans |> List.map ~f:(Span.to_string_hum ~unit_of_time ~align_decimal:true)
+           ;;
+         end)
   ;;
 end
 
+module Option = Option0
 module Hash_queue = struct end
 module Hash_set = struct end
 module Map = struct end
-module Option = struct end
 module Set = struct end
 module Table = struct end
 module Zone = struct end
@@ -1004,3 +1179,14 @@ let to_string_fix_proto = `Use_Time_ns_unix
 let validate_bound = `Use_Time_ns_unix
 let validate_lbound = `Use_Time_ns_unix
 let validate_ubound = `Use_Time_ns_unix
+
+module O = struct
+  let ( >= ) = ( >= )
+  let ( <= ) = ( <= )
+  let ( = ) = ( = )
+  let ( > ) = ( > )
+  let ( < ) = ( < )
+  let ( <> ) = ( <> )
+  let ( + ) = add
+  let ( - ) = diff
+end
