@@ -1,5 +1,14 @@
 open! Import
 
+module Rounding_direction = struct
+  type t =
+    | Down
+    | Nearest
+    | Up
+    | Zero
+  [@@deriving equal, enumerate, sexp_of]
+end
+
 module type Span = sig
   (** [t] is immediate on 64bit boxes and so plays nicely with the GC write barrier. *)
   type t = private Int63.t [@@deriving hash]
@@ -13,6 +22,15 @@ module type Span = sig
   val to_int_ms : t -> int
   val to_int_sec : t -> int
 
+  (** Approximations of float conversions using multiplication instead of division. *)
+
+  val to_us_approx : t -> float
+  val to_ms_approx : t -> float
+  val to_sec_approx : t -> float
+  val to_min_approx : t -> float
+  val to_hr_approx : t -> float
+  val to_day_approx : t -> float
+
   (** The minimum representable time span. *)
   val min_value_representable : t
 
@@ -27,15 +45,15 @@ module type Span = sig
 
   (** An alias for [min_value_for_1us_rounding]. *)
   val min_value : t
-  [@@deprecated
-    "[since 2019-02] use [min_value_representable] or [min_value_for_1us_rounding] \
-     instead"]
+    [@@deprecated
+      "[since 2019-02] use [min_value_representable] or [min_value_for_1us_rounding] \
+       instead"]
 
   (** An alias for [max_value_for_1us_rounding]. *)
   val max_value : t
-  [@@deprecated
-    "[since 2019-02] use [max_value_representable] or [max_value_for_1us_rounding] \
-     instead"]
+    [@@deprecated
+      "[since 2019-02] use [max_value_representable] or [max_value_for_1us_rounding] \
+       instead"]
 
   (** overflows silently *)
   val scale_int : t -> int -> t
@@ -64,15 +82,14 @@ module type Span = sig
       Around 135y magnitudes [to_span] and [of_span] raise.
   *)
   val to_span : t -> Span_float.t
-  [@@deprecated
-    "[since 2019-01] use [to_span_float_round_nearest] or \
-     [to_span_float_round_nearest_microsecond]"]
-
+    [@@deprecated
+      "[since 2019-01] use [to_span_float_round_nearest] or \
+       [to_span_float_round_nearest_microsecond]"]
 
   val of_span : Span_float.t -> t
-  [@@deprecated
-    "[since 2019-01] use [of_span_float_round_nearest] or \
-     [of_span_float_round_nearest_microsecond]"]
+    [@@deprecated
+      "[since 2019-01] use [of_span_float_round_nearest] or \
+       [of_span_float_round_nearest_microsecond]"]
 
   (** [*_round_nearest] vs [*_round_nearest_microsecond]: If you don't know that you need
       microsecond precision, use the [*_round_nearest] version.
@@ -83,6 +100,16 @@ module type Span = sig
   val of_span_float_round_nearest : Span_float.t -> t
   val of_span_float_round_nearest_microsecond : Span_float.t -> t
 
+  module Rounding_direction = Rounding_direction
+
+  (** These operations round the span to the nearest whole-number of the given factor. *)
+
+  val round_up : t -> to_multiple_of:t -> t
+  val round_down : t -> to_multiple_of:t -> t
+  val round_nearest : t -> to_multiple_of:t -> t
+  val round_towards_zero : t -> to_multiple_of:t -> t
+  val round : t -> dir:Rounding_direction.t -> to_multiple_of:t -> t
+
   (** Note that we expose a sexp format that is not the one exposed in [Core]. *)
   module Alternate_sexp : sig
     type nonrec t = t [@@deriving sexp, sexp_grammar]
@@ -91,25 +118,52 @@ module type Span = sig
 
   val arg_type : t Command.Arg_type.t
 
+  module O : sig
+    val ( / ) : t -> float -> t
+    val ( // ) : t -> t -> float
+    val ( + ) : t -> t -> t
+    val ( - ) : t -> t -> t
+
+    (** alias for [neg] *)
+    val ( ~- ) : t -> t
+
+    (** alias for [scale] *)
+    val ( *. ) : t -> float -> t
+
+    (** alias for [scale_int] *)
+    val ( * ) : t -> int -> t
+
+    include Comparisons.Infix with type t := t
+  end
+
   (** [Span.Option.t] is like [Span.t option], except that the value is immediate on
       architectures where [Int63.t] is immediate.  This module should mainly be used to
       avoid allocations. *)
   module Option : sig
     include Immediate_option.S_int63 with type value := t
     include Identifiable.S with type t := t
+    include Diffable.S_atomic with type t := t
     include Quickcheck.S with type t := t
 
     module Stable : sig
-      module V1 : Stable_int63able.With_stable_witness.S with type t = t
-      module V2 : Stable_int63able.With_stable_witness.S with type t = t
+      module V1 : sig
+        include Stable_int63able.With_stable_witness.S with type t = t
+        include Diffable.S_atomic with type t := t
+      end
+
+      module V2 : sig
+        include Stable_int63able.With_stable_witness.S with type t = t
+        include Diffable.S_atomic with type t := t
+      end
     end
   end
 
   module Stable : sig
     module V1 : sig
-      type nonrec t = t [@@deriving hash, equal]
+      type nonrec t = t [@@deriving hash, equal, sexp_grammar]
 
       include Stable_int63able.With_stable_witness.S with type t := t
+      include Diffable.S_atomic with type t := t
     end
 
     module V2 : sig
@@ -118,15 +172,16 @@ module type Span = sig
 
       include
         Stable_int63able.With_stable_witness.S
-        with type t := t
-        with type comparator_witness := comparator_witness
+          with type t := t
+          with type comparator_witness := comparator_witness
 
       include
         Comparable.Stable.V1.With_stable_witness.S
-        with type comparable := t
-        with type comparator_witness := comparator_witness
+          with type comparable := t
+          with type comparator_witness := comparator_witness
 
       include Stringable.S with type t := t
+      include Diffable.S_atomic with type t := t
     end
   end
 
@@ -164,7 +219,6 @@ module type Ofday = sig
       not in the same 24-hour day. Daylight savings shifts are not accounted for. *)
   val add_exn : t -> Span.t -> t
 
-
   (** [sub_exn t span] shifts the time of day [t] back by [span]. It raises if the result
       is not in the same 24-hour day. Daylight savings shifts are not accounted for. *)
   val sub_exn : t -> Span.t -> t
@@ -179,20 +233,34 @@ module type Ofday = sig
   val every : Span.t -> start:t -> stop:t -> t list Or_error.t
 
   val to_microsecond_string : t -> string
+
+  module Stable : sig
+    module V1 : sig
+      type nonrec t = t [@@deriving equal, hash, sexp_grammar]
+
+      include
+        Stable_int63able.With_stable_witness.S
+          with type t := t
+           and type comparator_witness = comparator_witness
+
+      include Diffable.S_atomic with type t := t
+    end
+  end
+
   val arg_type : [ `Use_Time_ns_unix ] [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
   val now : [ `Use_Time_ns_unix ] [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val of_ofday_float_round_nearest : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val of_ofday_float_round_nearest_microsecond : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val to_ofday_float_round_nearest : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val to_ofday_float_round_nearest_microsecond : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   module Option : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
   module Zoned : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
@@ -213,19 +281,55 @@ module type Time_ns = sig
 
   include Comparisons.S with type t := t
 
-  (** Note that we expose a sexp format that is not the one exposed in [Core]. *)
+  (** Note that we expose a sexp format that is not the one exposed in [Time_ns_unix]. The
+      sexp is a single atom rendered as with [to_string_utc], except that all trailing
+      zeros are trimmed, rather than trimming in groups of three. *)
   module Alternate_sexp : sig
-    type nonrec t = t [@@deriving compare, equal, hash, sexp, sexp_grammar]
+    type nonrec t = t [@@deriving bin_io, compare, equal, hash, sexp, sexp_grammar]
 
     include Comparable.S with type t := t
+    include Diffable.S_atomic with type t := t
+  end
+
+  (** [Option.t] is like [t option], except that the value is immediate.  This module
+      should mainly be used to avoid allocations. *)
+  module Option : sig
+    type value := t
+    type t = private Span.Option.t [@@deriving compare, bin_io]
+
+    include Immediate_option.S_int63 with type value := value with type t := t
+    include Quickcheck.S with type t := t
+
+    module Stable : sig
+      module V1 : sig
+        type nonrec t = t [@@deriving compare, bin_io, stable_witness]
+
+        val to_int63 : t -> Int63.t
+        val of_int63_exn : Int63.t -> t
+      end
+    end
+
+    val sexp_of_t : [ `Use_Time_ns_unix ]
+      [@@deprecated "[since 2023-09] Use [Time_ns_unix.Option]"]
+
+    include Comparisons.S with type t := t
+
+    (** Just like [Time_ns.Alternate_sexp], this is different from the sexp format exposed
+        in [Time_ns_unix].  See the comment above. *)
+    module Alternate_sexp : sig
+      type nonrec t = t [@@deriving bin_io, compare, equal, hash, sexp, sexp_grammar]
+
+      include Comparable.S with type t := t
+      include Diffable.S_atomic with type t := t
+    end
   end
 
   include
     Time_intf.Shared with type t := t with module Span := Span with module Ofday := Ofday
 
   val of_string : string -> t
-  [@@deprecated
-    "[since 2021-04] Use [of_string_with_utc_offset] or [Time_ns_unix.of_string]"]
+    [@@deprecated
+      "[since 2021-04] Use [of_string_with_utc_offset] or [Time_ns_unix.of_string]"]
 
   (** [of_string_with_utc_offset] requires its input to have an explicit
       UTC offset, e.g. [2000-01-01 12:34:56.789012-23], or use the UTC zone, "Z",
@@ -233,7 +337,7 @@ module type Time_ns = sig
   val of_string_with_utc_offset : string -> t
 
   val to_string : t -> string
-  [@@deprecated "[since 2021-04] Use [to_string_utc] or [Time_ns_unix.to_string]"]
+    [@@deprecated "[since 2021-04] Use [to_string_utc] or [Time_ns_unix.to_string]"]
 
   (** [to_string_utc] generates a time string with the UTC zone, "Z", e.g. [2000-01-01
       12:34:56.789012Z]. *)
@@ -256,15 +360,15 @@ module type Time_ns = sig
 
   (** An alias for [min_value_for_1us_rounding]. *)
   val min_value : t
-  [@@deprecated
-    "[since 2019-02] use [min_value_representable] or [min_value_for_1us_rounding] \
-     instead"]
+    [@@deprecated
+      "[since 2019-02] use [min_value_representable] or [min_value_for_1us_rounding] \
+       instead"]
 
   (** An alias for [max_value_for_1us_rounding]. *)
   val max_value : t
-  [@@deprecated
-    "[since 2019-02] use [max_value_representable] or [max_value_for_1us_rounding] \
-     instead"]
+    [@@deprecated
+      "[since 2019-02] use [max_value_representable] or [max_value_for_1us_rounding] \
+       instead"]
 
   (** The current time. *)
   val now : unit -> t
@@ -315,7 +419,17 @@ module type Time_ns = sig
 
       Supplying [~can_equal_after:true] allows the result to satisfy [time >= after].
 
-      Overflows silently. *)
+      This function is useful for finding linear time intervals, like every 30 minutes or
+      every 24 hours. This is different from rounding to apparent clock-face internvals,
+      like "every hour at :00 and :30" or "every day at noon", because time zone and
+      daylight savings transitions may cause linear intervals and apparent clock-face
+      intervals to differ.
+
+      Time zone offsets (in the tzdata time zone database, at least) are expressed in
+      seconds, so rounding to units of seconds or smaller is not affected by time zones.
+      The [round*] functions below provide some straightforward cases. For other small
+      units that evenly divide into a second, call with [base = epoch], [after] as the
+      time to round, and [interval] as the unit span you are rounding to. *)
   val next_multiple
     :  ?can_equal_after:bool (** default is [false] *)
     -> base:t
@@ -333,7 +447,18 @@ module type Time_ns = sig
       where [k >= 0] and [time < before].  It is an error if [interval <= 0].
 
       Supplying [~can_equal_before:true] allows the result to satisfy [time <= before].
-  *)
+
+      This function is useful for finding linear time intervals, like every 30 minutes or
+      every 24 hours. This is different from rounding to apparent clock-face internvals,
+      like "every hour at :00 and :30" or "every day at noon", because time zone and
+      daylight savings transitions may cause linear intervals and apparent clock-face
+      intervals to differ.
+
+      Time zone offsets (in the tzdata time zone database, at least) are expressed in
+      seconds, so rounding to units of seconds or smaller is not affected by time zones.
+      The [round*] functions below provide some straightforward cases. For other small
+      units that evenly divide into a second, call with [base = epoch], [after] as the
+      time to round, and [interval] as the unit span you are rounding to. *)
   val prev_multiple
     :  ?can_equal_before:bool (** default is [false] *)
     -> base:t
@@ -342,17 +467,35 @@ module type Time_ns = sig
     -> unit
     -> t
 
+  (** [round_up_to_us t] returns [t] rounded up to the next microsecond. *)
+  val round_up_to_us : t -> t
+
+  (** [round_up_to_ms t] returns [t] rounded up to the next millisecond. *)
+  val round_up_to_ms : t -> t
+
+  (** [round_up_to_sec t] returns [t] rounded up to the next second. *)
+  val round_up_to_sec : t -> t
+
+  (** [round_down_to_us t] returns [t] rounded down to the previous microsecond. *)
+  val round_down_to_us : t -> t
+
+  (** [round_down_to_ms t] returns [t] rounded down to the previous millisecond. *)
+  val round_down_to_ms : t -> t
+
+  (** [round_down_to_sec t] returns [t] rounded down to the previous second. *)
+  val round_down_to_sec : t -> t
+
   val random : ?state:Random.State.t -> unit -> t
 
   val of_time : Time_float.t -> t
-  [@@deprecated
-    "[since 2019-01] use [of_time_float_round_nearest] or \
-     [of_time_float_round_nearest_microsecond]"]
+    [@@deprecated
+      "[since 2019-01] use [of_time_float_round_nearest] or \
+       [of_time_float_round_nearest_microsecond]"]
 
   val to_time : t -> Time_float.t
-  [@@deprecated
-    "[since 2019-01] use [to_time_float_round_nearest] or \
-     [to_time_float_round_nearest_microsecond]"]
+    [@@deprecated
+      "[since 2019-01] use [to_time_float_round_nearest] or \
+       [to_time_float_round_nearest_microsecond]"]
 
   (** [*_round_nearest] vs [*_round_nearest_microsecond]: If you don't know that you need
       microsecond precision, use the [*_round_nearest] version.
@@ -373,34 +516,73 @@ module type Time_ns = sig
     val of_date_and_span_since_start_of_day : Date0.t -> Span.t -> t
   end
 
+  module O : sig
+    (** alias for [add] *)
+    val ( + ) : t -> Span.t -> t
+
+    (** alias for [diff] *)
+    val ( - ) : t -> t -> Span.t
+
+    include Comparisons.Infix with type t := t
+  end
+
   module Stable : sig
     module V1 : sig end
     [@@deprecated "[since 2021-03] Use [Time_ns_unix] or [Time_ns.Alternate_sexp]"]
 
-    module Option : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    module Option : sig
+      module V1 : sig
+        type nonrec t = Option.t [@@deriving compare, bin_io, stable_witness]
+
+        val to_int63 : t -> Int63.t
+        val of_int63_exn : Int63.t -> t
+      end
+
+      module Alternate_sexp : sig
+        module V1 : sig
+          type nonrec t = Option.Alternate_sexp.t
+          [@@deriving bin_io, compare, hash, sexp, sexp_grammar, stable_witness]
+
+          include
+            Comparator.Stable.V1.S
+              with type t := t
+               and type comparator_witness = Option.Alternate_sexp.comparator_witness
+
+          include
+            Comparable.Stable.V1.With_stable_witness.S
+              with type comparable := t
+              with type comparator_witness := comparator_witness
+
+          include Diffable.S_atomic with type t := t
+        end
+      end
+    end
 
     module Alternate_sexp : sig
       module V1 : sig
         type t = Alternate_sexp.t
-        [@@deriving bin_io, compare, hash, sexp, sexp_grammar, stable_witness]
+        [@@deriving bin_io, compare, equal, hash, sexp, sexp_grammar, stable_witness]
 
         include
           Comparator.Stable.V1.S
-          with type t := t
-           and type comparator_witness = Alternate_sexp.comparator_witness
+            with type t := t
+             and type comparator_witness = Alternate_sexp.comparator_witness
 
         include
           Comparable.Stable.V1.With_stable_witness.S
-          with type comparable := t
-          with type comparator_witness := comparator_witness
+            with type comparable := t
+            with type comparator_witness := comparator_witness
+
+        include Diffable.S_atomic with type t := t
       end
     end
 
     module Span : sig
       module V1 : sig
-        type nonrec t = Span.t [@@deriving hash, equal]
+        type nonrec t = Span.t [@@deriving hash, equal, sexp_grammar]
 
         include Stable_int63able.With_stable_witness.S with type t := t
+        include Diffable.S_atomic with type t := t
       end
 
       module Option : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
@@ -411,26 +593,29 @@ module type Time_ns = sig
 
         include
           Stable_int63able.With_stable_witness.S
-          with type t := t
-          with type comparator_witness := comparator_witness
+            with type t := t
+            with type comparator_witness := comparator_witness
 
         include
           Comparable.Stable.V1.With_stable_witness.S
-          with type comparable := t
-          with type comparator_witness := comparator_witness
+            with type comparable := t
+            with type comparator_witness := comparator_witness
 
         include Stringable.S with type t := t
+        include Diffable.S_atomic with type t := t
       end
     end
 
     module Ofday : sig
       module V1 : sig
-        type t = Ofday.t [@@deriving equal, hash]
+        type t = Ofday.t [@@deriving equal, hash, sexp_grammar]
 
         include
           Stable_int63able.With_stable_witness.S
-          with type t := t
-           and type comparator_witness = Ofday.comparator_witness
+            with type t := t
+             and type comparator_witness = Ofday.comparator_witness
+
+        include Diffable.S_atomic with type t := t
       end
 
       module Option : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
@@ -441,7 +626,6 @@ module type Time_ns = sig
   module Hash_queue : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
   module Hash_set : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
   module Map : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
-  module Option : sig end [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   module Replace_polymorphic_compare : sig end
   [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
@@ -453,60 +637,60 @@ module type Time_ns = sig
   val arg_type : [ `Use_Time_ns_unix ] [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val comparator : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val get_sexp_zone : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val interruptible_pause : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val of_date_ofday_zoned : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val of_string_abs : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val of_string_fix_proto : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val pause : [ `Use_Time_ns_unix ] [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val pause_forever : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val pp : [ `Use_Time_ns_unix ] [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val set_sexp_zone : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val sexp_of_t : [ `Use_Time_ns_unix_or_Time_ns_alternate_sexp ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix] or [Time_ns.Alternate_sexp]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix] or [Time_ns.Alternate_sexp]"]
 
   val sexp_of_t_abs : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val t_of_sexp : [ `Use_Time_ns_unix_or_Time_ns_alternate_sexp ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix] or [Time_ns.Alternate_sexp]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix] or [Time_ns.Alternate_sexp]"]
 
   val t_of_sexp_abs : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val to_date_ofday_zoned : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val to_ofday_zoned : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val to_string_fix_proto : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val validate_bound : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val validate_lbound : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 
   val validate_ubound : [ `Use_Time_ns_unix ]
-  [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
+    [@@deprecated "[since 2021-03] Use [Time_ns_unix]"]
 end
