@@ -1,12 +1,11 @@
-#include <caml/memory.h>
 #include <caml/alloc.h>
 #include <caml/fail.h>
+#include <caml/memory.h>
 #include <time.h>
 
-CAMLprim value core_time_ns_format_tm(struct tm * tm, value v_fmt)
-{
+CAMLprim value core_time_ns_format_tm(struct tm *tm, value v_fmt) {
   size_t len;
-  char* buf;
+  char *buf;
   int buf_len;
   value v_str;
   /* 100 * length should be large enough to contain the output of strftime. The
@@ -14,7 +13,8 @@ CAMLprim value core_time_ns_format_tm(struct tm * tm, value v_fmt)
      requires 151 bytes. */
   buf_len = 100 * caml_string_length(v_fmt);
   buf = malloc(buf_len);
-  if (!buf) caml_failwith("core_time_ns_format_tm: malloc failed");
+  if (!buf)
+    caml_failwith("core_time_ns_format_tm: malloc failed");
   len = strftime(buf, buf_len, String_val(v_fmt), tm);
 
   if (len == 0) {
@@ -28,21 +28,21 @@ CAMLprim value core_time_ns_format_tm(struct tm * tm, value v_fmt)
     return v_str;
   }
 
-  v_str = caml_copy_string(buf);  /* [strftime] always null terminates the string */
+  v_str =
+      caml_copy_string(buf); /* [strftime] always null terminates the string */
   free(buf);
   return v_str;
 }
 
-
-CAMLprim value core_time_ns_format(value t, value v_fmt)
-{
+CAMLprim value core_time_ns_format(value t, value v_fmt) {
   time_t clock;
-  struct tm * tm;
-  clock = (time_t) Double_val(t);
+  struct tm *tm;
+  clock = (time_t)Double_val(t);
   /* This [tm] must not be freed. It refers to statically allocated
      memory and its contents change every time [localtime] is
      called. */
   tm = localtime(&clock);
-  if (tm == NULL) caml_failwith("core_time_ns_format: localtime failed");
+  if (tm == NULL)
+    caml_failwith("core_time_ns_format: localtime failed");
   return core_time_ns_format_tm(tm, v_fmt);
 }
