@@ -2,9 +2,6 @@
    and then instantiates that functor to create unit tests for [Map], [Map.Poly], and
    [Int.Map]. *)
 
-
-
-
 module Caml_map = Map
 open! Core
 open Expect_test_helpers_core
@@ -13,28 +10,28 @@ module With_first_class_module = Map_intf.With_first_class_module
 module Without_comparator = Map_intf.Without_comparator
 
 module Unit_tests (Key : sig
-    type 'a t [@@deriving sexp, compare, hash]
+  type 'a t [@@deriving sexp, compare, hash]
 
-    val of_int : int -> int t
-    val to_int : int t -> int
-  end) (Map : sig
-          type ('a, 'b, 'c) t_
-          type ('a, 'b, 'c) tree
-          type ('a, 'b, 'c) create_options
-          type ('a, 'b, 'c) access_options
+  val of_int : int -> int t
+  val to_int : int t -> int
+end) (Map : sig
+  type ('a, 'b, 'c) t_
+  type ('a, 'b, 'c) tree
+  type ('a, 'b, 'c) create_options
+  type ('a, 'b, 'c) access_options
 
-          include
-            Map_intf.Creators_and_accessors_generic
-            with type ('a, 'b, 'c) t := ('a, 'b, 'c) t_
-            with type ('a, 'b, 'c) tree := ('a, 'b, 'c) tree
-            with type 'a key := 'a Key.t
-            with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) create_options
-            with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) access_options
+  include
+    Map_intf.Creators_and_accessors_generic
+      with type ('a, 'b, 'c) t := ('a, 'b, 'c) t_
+      with type ('a, 'b, 'c) tree := ('a, 'b, 'c) tree
+      with type 'a key := 'a Key.t
+      with type ('a, 'b, 'c) create_options := ('a, 'b, 'c) create_options
+      with type ('a, 'b, 'c) access_options := ('a, 'b, 'c) access_options
 
-          val simplify_creator : (int, Int.comparator_witness, 'c) create_options -> 'c
-          val simplify_accessor : (int, Int.comparator_witness, 'c) access_options -> 'c
-          val kind : [ `Map | `Tree ]
-        end) : Map_intf.Creators_and_accessors_generic =
+  val simplify_creator : (int, Int.comparator_witness, 'c) create_options -> 'c
+  val simplify_accessor : (int, Int.comparator_witness, 'c) access_options -> 'c
+  val kind : [ `Map | `Tree ]
+end) : Map_intf.Creators_and_accessors_generic =
 (* The result signature doesn't actually mean anything -- the values are required so
    that implementors are reminded to add a unit test for each one. *)
 struct
@@ -60,6 +57,7 @@ struct
     let symmetric_diff x = simplify_accessor symmetric_diff x
     let fold_symmetric_diff x = simplify_accessor fold_symmetric_diff x
     let merge x = simplify_accessor merge x
+    let merge_disjoint_exn x = simplify_accessor merge_disjoint_exn x
     let merge_skewed x = simplify_accessor merge_skewed x
     let split x = simplify_accessor split x
     let split_le_gt x = simplify_accessor split_le_gt x
@@ -122,6 +120,8 @@ struct
     let of_list_with_key_or_error x = simplify_creator of_list_with_key_or_error x
     let of_list_with_key_exn x = simplify_creator of_list_with_key_exn x
     let of_list_with_key_multi x = simplify_creator of_list_with_key_multi x
+    let of_list_with_key_fold x = simplify_creator of_list_with_key_fold x
+    let of_list_with_key_reduce x = simplify_creator of_list_with_key_reduce x
     let map_keys_exn x = simplify_creator map_keys_exn x
     let transpose_keys x = simplify_creator (simplify_accessor transpose_keys) x
     let quickcheck_generator x = simplify_creator quickcheck_generator x
@@ -515,7 +515,7 @@ struct
         (Map.of_hashtbl_exn
            (List.map Key.samples ~f:(fun key -> key, Key.to_int key)
             |> Hashtbl.Poly.of_alist_exn)
-         : _ Map.t_))
+          : _ Map.t_))
   ;;
 
   let%expect_test _ =
@@ -524,8 +524,8 @@ struct
         let i = ref 0 in
         { hash =
             (fun _ ->
-               incr i;
-               !i)
+              incr i;
+              !i)
         ; compare = (fun _ _ -> 1)
         ; sexp_of_t = Key.sexp_of_t
         }
@@ -606,7 +606,7 @@ struct
     let increasing_alist =
       List.sort alist ~compare:(fun a b -> Comparable.lift ~f:fst Key.compare a b)
       |> List.remove_consecutive_duplicates ~equal:(fun a b ->
-        Comparable.lift ~f:fst Key.equal a b)
+           Comparable.lift ~f:fst Key.equal a b)
     in
     let duplicates_alist =
       match increasing_alist with
@@ -723,10 +723,22 @@ struct
   ;;
 
   let of_list_with_key_multi _ = assert false
+  let of_list_with_key_fold _ = assert false
+  let of_list_with_key_reduce _ = assert false
 
   let%expect_test _ =
     let input = random_alist Key.samples in
     let list_multi = Map.of_list_with_key_multi input ~get_key:fst in
+    let list_fold =
+      Map.of_list_with_key_fold input ~get_key:fst ~init:[] ~f:(fun acc x -> x :: acc)
+      |> Map.map ~f:List.rev
+    in
+    let list_reduce =
+      Map.of_list_with_key_reduce
+        (List.map input ~f:List.return)
+        ~get_key:(fun x -> x |> List.hd_exn |> fst)
+        ~f:(fun x y -> x @ y)
+    in
     let expect =
       Map.of_alist_multi (List.map input ~f:(fun (key, data) -> key, (key, data)))
     in
@@ -737,7 +749,9 @@ struct
       let sexp_of_t = Map.sexp_of_t [%sexp_of: int] [%sexp_of: (Key.t * int) list]
     end
     in
-    Expect_test_helpers_core.require_equal [%here] (module T) list_multi expect
+    Expect_test_helpers_core.require_equal [%here] (module T) list_multi expect;
+    Expect_test_helpers_core.require_equal [%here] (module T) list_reduce expect;
+    Expect_test_helpers_core.require_equal [%here] (module T) list_fold expect
   ;;
 
   let is_empty _ = assert false
@@ -1001,6 +1015,18 @@ struct
     && Or_error.is_error err_m
   ;;
 
+  let unzip _ = assert false
+
+  let%test _ =
+    let open Some_keys in
+    let m0 =
+      Map.of_alist_exn [ k1, ("a", 2); k2, ("1", 0); k3, ("d", 7); k4, ("5", 3) ]
+    in
+    let m1, m2 = Map.unzip m0 in
+    Map.equal String.equal m1 (Map.of_alist_exn [ k1, "a"; k2, "1"; k3, "d"; k4, "5" ])
+    && Map.equal Int.equal m2 (Map.of_alist_exn [ k1, 2; k2, 0; k3, 7; k4, 3 ])
+  ;;
+
   let keys _ = assert false
   let data _ = assert false
   let to_alist ?key_order:_ _ = assert false
@@ -1249,6 +1275,35 @@ struct
       [ 1, `Right 11; 3, `Both (13, 13); 6, `Left 16 ]
   ;;
 
+  let merge_disjoint_exn _ = assert false
+
+  let%test_unit _ =
+    let to_alist list = List.map list ~f:(fun x -> Key.of_int x, x) in
+    let test_ok a b =
+      [%test_result: (Key.t * int) list]
+        (Map.to_alist
+           (Map.merge_disjoint_exn
+              (Map.of_alist_exn (to_alist a))
+              (Map.of_alist_exn (to_alist b))))
+        ~expect:(to_alist (List.sort ~compare (a @ b)))
+    in
+    test_ok [] [];
+    test_ok [ 1 ] [ 2 ];
+    test_ok [ 2 ] [ 1 ];
+    test_ok [ 1; 3 ] [ 2; 4 ];
+    test_ok [ 2; 4; 6; 8 ] [ 1; 3; 5; 7; 9 ];
+    let test_error a b =
+      assert (
+        Exn.does_raise (fun () ->
+          Map.merge_disjoint_exn
+            (Map.of_alist_exn (to_alist a))
+            (Map.of_alist_exn (to_alist b))))
+    in
+    test_error [ 1 ] [ 1 ];
+    test_error [ 1; 2 ] [ 2; 3 ];
+    test_error [ 1; 3; 5; 7; 9 ] [ 2; 5; 8 ]
+  ;;
+
   let merge_skewed _ = assert false
 
   let%test_module _ =
@@ -1339,6 +1394,8 @@ struct
   let for_all _ = assert false
   let exists _ = assert false
   let count _ = assert false
+  let sum _ = assert false
+  let sumi _ = assert false
   let for_alli _ = assert false
   let existsi _ = assert false
   let counti _ = assert false
@@ -1427,7 +1484,8 @@ struct
        (data 4))
       ((key  3)
        (data 1))
-      Unfinished |}];
+      Unfinished
+      |}];
     test [ 1; 4; 9; 16; 25; 36; 49; 64 ];
     [%expect
       {|
@@ -1447,7 +1505,8 @@ struct
        (data 49))
       ((key  7)
        (data 64))
-      Finished |}]
+      Finished
+      |}]
   ;;
 
   let fold_until _ = assert false
@@ -1477,7 +1536,8 @@ struct
        (data 4))
       ((key  3)
        (data 1))
-      3 |}];
+      3
+      |}];
     test [ 1; 4; 9; 16; 25; 36; 49; 64 ];
     [%expect
       {|
@@ -1497,7 +1557,8 @@ struct
        (data 49))
       ((key  7)
        (data 64))
-      28 |}]
+      28
+      |}]
   ;;
 
   let to_sequence ?order:_ ?keys_greater_or_equal_to:_ ?keys_less_or_equal_to:_ _ =
@@ -2284,11 +2345,13 @@ struct
     test [ 0, []; 1, [ 1, 11 ] ];
     [%expect {| ((1 ((1 11)))) |}];
     test [ 0, []; 1, [ 1, 11 ]; 2, [ 1, 21; 2, 22 ] ];
-    [%expect {|
+    [%expect
+      {|
       ((1 (
          (1 11)
          (2 21)))
-       (2 ((2 22)))) |}];
+       (2 ((2 22))))
+      |}];
     test [ 0, []; 1, [ 1, 11 ]; 2, [ 1, 21; 2, 22 ]; 3, [ 1, 31; 2, 32; 3, 33 ] ];
     [%expect
       {|
@@ -2299,7 +2362,8 @@ struct
        (2 (
          (2 22)
          (3 32)))
-       (3 ((3 33)))) |}]
+       (3 ((3 33))))
+      |}]
   ;;
 
   let quickcheck_generator _ _ = assert false
@@ -2513,115 +2577,115 @@ end
 
 let%test_module "Map" =
   (module Unit_tests
-       (Key_poly)
-       (struct
-         include Map
+            (Key_poly)
+            (struct
+              include Map
 
-         type ('a, 'b, 'c) t_ = ('a, 'b, 'c) t
-         type ('a, 'b, 'c) tree = ('a, 'b, 'c) Tree.t
-         type 'cmp cmp = 'cmp
+              type ('a, 'b, 'c) t_ = ('a, 'b, 'c) t
+              type ('a, 'b, 'c) tree = ('a, 'b, 'c) Tree.t
+              type 'cmp cmp = 'cmp
 
-         include Create_options_with_first_class_module
-         include Access_options_without_comparator
+              include Create_options_with_first_class_module
+              include Access_options_without_comparator
 
-         let kind = `Map
-       end))
+              let kind = `Map
+            end))
 ;;
 
 let%test_module "Map.Poly" =
   (module Unit_tests
-       (Key_poly)
-       (struct
-         include Map.Poly
+            (Key_poly)
+            (struct
+              include Map.Poly
 
-         type ('a, 'b, 'c) t_ = ('a, 'b) t
-         type ('a, 'b, 'c) tree = ('a, 'b) Tree.t
-         type 'cmp cmp = comparator_witness
+              type ('a, 'b, 'c) t_ = ('a, 'b) t
+              type ('a, 'b, 'c) tree = ('a, 'b) Tree.t
+              type 'cmp cmp = comparator_witness
 
-         include Create_options_without_comparator
-         include Access_options_without_comparator
+              include Create_options_without_comparator
+              include Access_options_without_comparator
 
-         let kind = `Map
-       end))
+              let kind = `Map
+            end))
 ;;
 
 let%test_module "Int.Map" =
   (module Unit_tests
-       (Key_int)
-       (struct
-         include Int.Map
-         module Tree = Map.Make_tree (Int.Map.Key)
+            (Key_int)
+            (struct
+              include Int.Map
+              module Tree = Map.Make_tree (Int.Map.Key)
 
-         type ('a, 'b, 'c) t_ = 'b t
-         type ('a, 'b, 'c) tree = 'b Tree.t
-         type 'cmp cmp = Int.comparator_witness
+              type ('a, 'b, 'c) t_ = 'b t
+              type ('a, 'b, 'c) tree = 'b Tree.t
+              type 'cmp cmp = Int.comparator_witness
 
-         include Create_options_without_comparator
-         include Access_options_without_comparator
+              include Create_options_without_comparator
+              include Access_options_without_comparator
 
-         let kind = `Map
+              let kind = `Map
 
-         include (
-           Core.Map :
-             Map_intf.Accessors_generic
-           with type ('k, 'v, 'c) t := 'v t
-           with type ('k, 'v, 'c) tree := 'v Tree.t
-           with type 'k key := int
-           with type 'c cmp := Int.comparator_witness
-           with type ('k, 'v, 'c) access_options :=
-             ('k, 'v, 'c) Without_comparator.t)
-       end))
+              include (
+                Core.Map :
+                  Map_intf.Accessors_generic
+                    with type ('k, 'v, 'c) t := 'v t
+                    with type ('k, 'v, 'c) tree := 'v Tree.t
+                    with type 'k key := int
+                    with type 'c cmp := Int.comparator_witness
+                    with type ('k, 'v, 'c) access_options :=
+                      ('k, 'v, 'c) Without_comparator.t)
+            end))
 ;;
 
 let%test_module "Map.Tree" =
   (module Unit_tests
-       (Key_poly)
-       (struct
-         include Map.Tree
+            (Key_poly)
+            (struct
+              include Map.Tree
 
-         type ('a, 'b, 'c) t_ = ('a, 'b, 'c) t
-         type ('a, 'b, 'c) tree = ('a, 'b, 'c) t
-         type 'cmp cmp = 'cmp
+              type ('a, 'b, 'c) t_ = ('a, 'b, 'c) t
+              type ('a, 'b, 'c) tree = ('a, 'b, 'c) t
+              type 'cmp cmp = 'cmp
 
-         include Create_options_with_comparator
-         include Access_options_with_comparator
+              include Create_options_with_comparator
+              include Access_options_with_comparator
 
-         let kind = `Tree
-       end))
+              let kind = `Tree
+            end))
 ;;
 
 let%test_module "Map.Poly.Tree" =
   (module Unit_tests
-       (Key_poly)
-       (struct
-         include Map.Poly.Tree
+            (Key_poly)
+            (struct
+              include Map.Poly.Tree
 
-         type ('a, 'b, 'c) t_ = ('a, 'b) t
-         type ('a, 'b, 'c) tree = ('a, 'b) t
-         type 'cmp cmp = comparator_witness
+              type ('a, 'b, 'c) t_ = ('a, 'b) t
+              type ('a, 'b, 'c) tree = ('a, 'b) t
+              type 'cmp cmp = comparator_witness
 
-         include Create_options_without_comparator
-         include Access_options_without_comparator
+              include Create_options_without_comparator
+              include Access_options_without_comparator
 
-         let kind = `Tree
-       end))
+              let kind = `Tree
+            end))
 ;;
 
 let%test_module "Int.Map.Tree" =
   (module Unit_tests
-       (Key_int)
-       (struct
-         include Map.Make_tree (Int.Map.Key)
+            (Key_int)
+            (struct
+              include Map.Make_tree (Int.Map.Key)
 
-         type ('a, 'b, 'c) t_ = 'b t
-         type ('a, 'b, 'c) tree = 'b t
-         type 'cmp cmp = Int.comparator_witness
+              type ('a, 'b, 'c) t_ = 'b t
+              type ('a, 'b, 'c) tree = 'b t
+              type 'cmp cmp = Int.comparator_witness
 
-         include Create_options_without_comparator
-         include Access_options_without_comparator
+              include Create_options_without_comparator
+              include Access_options_without_comparator
 
-         let kind = `Tree
-       end))
+              let kind = `Tree
+            end))
 ;;
 
 let%test_unit _ = Core.Map.find_or_error (Int.Map.singleton 1 ()) 1 |> Or_error.ok_exn
