@@ -27,7 +27,8 @@ let%expect_test ("Quickcheck.Let_syntax" [@tags "64-bits-only"]) =
     ((true B 14980.765357503886) (A "tq\210H7LQ"))
     ((false 4 -4.94065645841247E-324) (A ""))
     ((false X -287262765.50439453) (A "yP\000xv\134uV\197"))
-    ((true q -8.6367588215150434E-19) (A A)) |}]
+    ((true q -8.6367588215150434E-19) (A A))
+    |}]
 ;;
 
 let%expect_test "ppx_quickcheck" =
@@ -46,27 +47,27 @@ let%expect_test "ppx_quickcheck" =
   List.iter
     ~f:(fun predicate -> Quickcheck.test_can_generate M.quickcheck_generator ~f:predicate)
     [ (function
-        | M.A -> true
-        | _ -> false)
+       | M.A -> true
+       | _ -> false)
     ; (function
-        | M.B _ -> true
-        | _ -> false)
+       | M.B _ -> true
+       | _ -> false)
     ; (function
-        | M.C _ -> true
-        | _ -> false)
+       | M.C _ -> true
+       | _ -> false)
     ; (function
-        | M.D _ -> true
-        | _ -> false)
+       | M.D _ -> true
+       | _ -> false)
     ; (function
-        | M.E _ -> true
-        | _ -> false)
+       | M.E _ -> true
+       | _ -> false)
     ];
   [%expect {| |}]
 ;;
 
 module Test (S : sig
-    val default_seed : Quickcheck.seed
-  end) : sig end = struct
+  val default_seed : Quickcheck.seed
+end) : sig end = struct
   let int_middle_bits =
     match Word_size.word_size with
     | W64 -> Int.of_string "0x0000_ffff_ffff_0000"
@@ -74,9 +75,9 @@ module Test (S : sig
   ;;
 
   module Q = Quickcheck.Configure (struct
-      include Quickcheck
-      include S
-    end)
+    include Quickcheck
+    include S
+  end)
 
   open Q
   module G = Quickcheck.Generator
@@ -745,14 +746,14 @@ let%test_module _ = (module Test (Quickcheck))
 
 let%test_module _ =
   (module Test (struct
-       let default_seed = `Deterministic "foo"
-     end))
+    let default_seed = `Deterministic "foo"
+  end))
 ;;
 
 let%test_module _ =
   (module Test (struct
-       let default_seed = `Deterministic "bar"
-     end))
+    let default_seed = `Deterministic "bar"
+  end))
 ;;
 
 (* let%test_module _ = (module Test (struct let default_seed = `Deterministic "baz" end))
