@@ -17,12 +17,12 @@ let%expect_test "print_s default" =
   [%expect
     {|
     (0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28
-     29) |}]
+     29)
+    |}]
 ;;
 
 let%expect_test "print_s mach" =
   print_s ~mach:() [%sexp (List.init 30 ~f:Fn.id : int list)];
   [%expect
-    {|
-    (0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29) |}]
+    {| (0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29) |}]
 ;;
