@@ -7,25 +7,25 @@ let orelse = O.( || )
 
 let%test_module "Stable.V1" =
   (module Stable_unit_test.Make (struct
-       type t = string Stable.V1.t [@@deriving bin_io, equal, sexp]
+    type t = string Stable.V1.t [@@deriving bin_io, equal, sexp]
 
-       let test_blang =
-         if_
-           (base "foo")
-           (not_ (or_ [ base "bara"; base "barb" ]))
-           (not_ (and_ [ base "baza"; base "bazb" ]))
-       ;;
+    let test_blang =
+      if_
+        (base "foo")
+        (not_ (or_ [ base "bara"; base "barb" ]))
+        (not_ (and_ [ base "baza"; base "bazb" ]))
+    ;;
 
-       let test_sexp = "(if foo (not (or bara barb)) (not (and baza bazb)))"
+    let test_sexp = "(if foo (not (or bara barb)) (not (and baza bazb)))"
 
-       let test_bin =
-         "\005\006\003foo\004\003\006\004bara\006\004barb\004\002\006\004baza\006\004bazb"
-       ;;
+    let test_bin =
+      "\005\006\003foo\004\003\006\004bara\006\004barb\004\002\006\004baza\006\004bazb"
+    ;;
 
-       let tests =
-         [ test_blang, test_sexp, test_bin; true_, "true", "\000"; false_, "false", "\001" ]
-       ;;
-     end))
+    let tests =
+      [ test_blang, test_sexp, test_bin; true_, "true", "\000"; false_, "false", "\001" ]
+    ;;
+  end))
 ;;
 
 let%test_module "auto-simplification" =
@@ -411,10 +411,10 @@ let%expect_test "validate sexp grammar" =
              (No_tag
               ((name not)
                (clause_kind
-                (List_clause (args (Cons (Recursive blang ((Tyvar a))) Empty)))))))))))))))) |}]
+                (List_clause (args (Cons (Recursive blang ((Tyvar a))) Empty))))))))))))))))
+    |}]
 ;;
 
-
 module _ = struct
   let a, b, c, d = base "a", base "b", base "c", base "d"
 
@@ -427,47 +427,51 @@ module _ = struct
   let%expect_test _ =
     print [ a ];
     [%expect {|
-        (standard a)
-        (raw (Base a)) |}]
+      (standard a)
+      (raw (Base a))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b ];
     [%expect
       {|
-        (standard (and a b))
-        (raw (
-          And
-          (Base a)
-          (Base b))) |}]
+      (standard (and a b))
+      (raw (
+        And
+        (Base a)
+        (Base b)))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b; c ];
     [%expect
       {|
-        (standard (and a b c))
-        (raw (
-          And
-          (Base a)
-          (And
-            (Base b)
-            (Base c)))) |}]
+      (standard (and a b c))
+      (raw (
+        And
+        (Base a)
+        (And
+          (Base b)
+          (Base c))))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b; c; d ];
     [%expect
       {|
-        (standard (and a b c d))
-        (raw (
-          And
-          (Base a)
+      (standard (and a b c d))
+      (raw (
+        And
+        (Base a)
+        (And
+          (Base b)
           (And
-            (Base b)
-            (And
-              (Base c)
-              (Base d))))) |}]
+            (Base c)
+            (Base d)))))
+      |}]
   ;;
 
   let%expect_test "arbitrary nesting" =
@@ -497,11 +501,13 @@ module _ = struct
                   (Base f)
                   (And
                     (Base g)
-                    (Base h))))))))) |}];
+                    (Base h)))))))))
+      |}];
     p false_;
     [%expect {|
       (standard false)
-      (raw False) |}]
+      (raw False)
+      |}]
   ;;
 end
 
@@ -517,47 +523,51 @@ module _ = struct
   let%expect_test _ =
     print [ a ];
     [%expect {|
-        (standard a)
-        (raw (Base a)) |}]
+      (standard a)
+      (raw (Base a))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b ];
     [%expect
       {|
-        (standard (or a b))
-        (raw (
-          Or
-          (Base a)
-          (Base b))) |}]
+      (standard (or a b))
+      (raw (
+        Or
+        (Base a)
+        (Base b)))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b; c ];
     [%expect
       {|
-        (standard (or a b c))
-        (raw (
-          Or
-          (Base a)
-          (Or
-            (Base b)
-            (Base c)))) |}]
+      (standard (or a b c))
+      (raw (
+        Or
+        (Base a)
+        (Or
+          (Base b)
+          (Base c))))
+      |}]
   ;;
 
   let%expect_test _ =
     print [ a; b; c; d ];
     [%expect
       {|
-        (standard (or a b c d))
-        (raw (
-          Or
-          (Base a)
+      (standard (or a b c d))
+      (raw (
+        Or
+        (Base a)
+        (Or
+          (Base b)
           (Or
-            (Base b)
-            (Or
-              (Base c)
-              (Base d))))) |}]
+            (Base c)
+            (Base d)))))
+      |}]
   ;;
 
   let%expect_test "arbitrary nesting" =
@@ -571,7 +581,8 @@ module _ = struct
     p true_;
     [%expect {|
       (standard true)
-      (raw True) |}];
+      (raw True)
+      |}];
     p false_;
     [%expect
       {|
@@ -591,7 +602,8 @@ module _ = struct
                   (Base f)
                   (Or
                     (Base g)
-                    (Base h))))))))) |}]
+                    (Base h)))))))))
+      |}]
   ;;
 end
 
