@@ -25,6 +25,5 @@ end
 let%expect_test (_ [@tags "64-bits-only"]) =
   let s = "foo" in
   print_s [%sexp (String.hash s = M2.hash (T s) : bool)];
-  [%expect {|
-    true |}]
+  [%expect {| true |}]
 ;;
