@@ -22,7 +22,8 @@ let%expect_test "empty" =
      ("is_empty t" true)
      ("first t"   ())
      ("last t"    ())
-     ("to_list t" ())) |}];
+     ("to_list t" ()))
+    |}];
   require_none [%here] [%sexp_of: int] (remove_first t);
   require_none [%here] [%sexp_of: int] (remove_last t)
 ;;
@@ -37,7 +38,8 @@ let%expect_test "singleton" =
      ("is_empty t" false)
      ("first t"   (13))
      ("last t"    (13))
-     ("to_list t" (13))) |}];
+     ("to_list t" (13)))
+    |}];
   require [%here] (is_first t elt);
   require [%here] (is_last t elt)
 ;;
@@ -53,7 +55,8 @@ let%expect_test "pair" =
      ("is_empty t" false)
      ("first t" (13))
      ("last t"  (14))
-     ("to_list t" (13 14))) |}];
+     ("to_list t" (13 14)))
+    |}];
   require [%here] (is_first t elt1);
   require [%here] (is_last t elt2)
 ;;
@@ -168,7 +171,7 @@ let%expect_test "insert and remove" =
          (List.fold elts ~init:elt ~f:(fun prev_elt elt ->
             require_equal [%here] (module Elt_option) (prev t elt) (Some prev_elt);
             elt)
-          : Elt.t));
+           : Elt.t));
     match List.rev elts with
     | [] -> ()
     | elt :: elts ->
@@ -181,7 +184,7 @@ let%expect_test "insert and remove" =
         (List.fold elts ~init:elt ~f:(fun next_elt elt ->
            assert (Option.equal Elt.equal (next t elt) (Some next_elt));
            elt)
-         : Elt.t)
+          : Elt.t)
   in
   let elt1 = insert_first t () in
   is_elts [ elt1 ];
@@ -252,7 +255,8 @@ let%expect_test "length" =
   print_s [%message (length l1 : int) (length l2 : int)];
   [%expect {|
     (("length l1" 0)
-     ("length l2" 8)) |}]
+     ("length l2" 8))
+    |}]
 ;;
 
 let%test_unit "iter_elt" =
@@ -339,9 +343,9 @@ let%test_module "move/set functions" =
     let%test_unit _ =
       test
         (fun _ a ->
-           Elt.set a.(0) 5;
-           Elt.set a.(4) 6;
-           Elt.set a.(0) 7)
+          Elt.set a.(0) 5;
+          Elt.set a.(4) 6;
+          Elt.set a.(0) 7)
         [ 7; 1; 2; 3; 6 ]
     ;;
   end)
@@ -434,13 +438,13 @@ let%test_module "inplace functions" =
 let%test_module "partition functions" =
   (module struct
     let test
-          (type a b)
-          (module M1 : Testable with type t = a)
-          (module M2 : Testable with type t = b)
-          ~n
-          k
-          (expected1 : a list)
-          (expected2 : b list)
+      (type a b)
+      (module M1 : Testable with type t = a)
+      (module M2 : Testable with type t = b)
+      ~n
+      k
+      (expected1 : a list)
+      (expected2 : b list)
       =
       let t = create () in
       for i = 0 to n - 1 do
@@ -521,7 +525,8 @@ let%expect_test "iteri" =
     f 1 10
     f 2 20
     f 3 30
-    f 4 40 |}]
+    f 4 40
+    |}]
 ;;
 
 let%expect_test "iteri_elt" =
@@ -531,7 +536,8 @@ let%expect_test "iteri_elt" =
     f 1 10
     f 2 20
     f 3 30
-    f 4 40 |}]
+    f 4 40
+    |}]
 ;;
 
 let%expect_test "foldi" =
@@ -546,7 +552,8 @@ let%expect_test "foldi" =
     f 2 1 20
     f 3 3 30
     f 4 6 40
-    result: 10 |}]
+    result: 10
+    |}]
 ;;
 
 let%expect_test "foldi_elt" =
@@ -561,7 +568,8 @@ let%expect_test "foldi_elt" =
     f 2 1 20
     f 3 3 30
     f 4 6 40
-    result: 10 |}]
+    result: 10
+    |}]
 ;;
 
 let%expect_test "fold_right_elt" =
@@ -575,7 +583,8 @@ let%expect_test "fold_right_elt" =
     f 20 2
     f 10 3
     f 0 4
-    result: 5 |}]
+    result: 5
+    |}]
 ;;
 
 let%test _ = compare Int.compare (create ()) (create ()) = 0
