@@ -1,7 +1,6 @@
 (* Test Doubly_linked by bisimulating it with a list and zipper-based implementation of
    the same interface. *)
 
-
 open Core
 open Poly
 
@@ -236,9 +235,9 @@ module Foil : S = struct
     assert_no_pending_readers t;
     e.root <- create ();
     t.elts
-    <- (match z.before with
-      | [] -> z.after
-      | hd :: tl -> elts_of_zipper { z with before = tl; cursor = hd })
+      <- (match z.before with
+          | [] -> z.after
+          | hd :: tl -> elts_of_zipper { z with before = tl; cursor = hd })
   ;;
 
   let remove_first t =
@@ -272,11 +271,7 @@ module Both : S = struct
     val pair : 'a -> 'b -> ('a, 'b) m
     val opt_obs : ('a option, 'b option) m -> ('a, 'b) m option (* observe option *)
     val obs : ('a, 'a) m -> 'a (* observe *)
-
-    val obs_f
-      :  (f:('f[@local]) -> 'a, f:('f[@local]) -> 'a) m
-      -> f:('f[@local])
-      -> 'a (* observe with local closure *)
+    val obs_f : (f:'f -> 'a, f:'f -> 'a) m -> f:'f -> 'a (* observe with local closure *)
   end = struct
     type ('a, 'b) m = ('a, exn) Result.t * ('b, exn) Result.t
 
