@@ -8,6 +8,5 @@ let%expect_test "validate sexp grammar" =
        (module struct
          type t = Host_and_port.Stable.V1.t [@@deriving quickcheck, sexp, sexp_grammar]
        end));
-  [%expect {|
-    (Union (String (List (Cons String (Cons Integer Empty))))) |}]
+  [%expect {| (Union (String (List (Cons String (Cons Integer Empty))))) |}]
 ;;
