@@ -7,7 +7,8 @@ let%expect_test "t_of_sexp" =
     {|
     (Of_sexp_error
      "Base.Nothing.t_of_sexp: trying to convert an empty type"
-     (invalid_sexp ())) |}]
+     (invalid_sexp ()))
+    |}]
 ;;
 
 let%test_module "Stable.V1" =
@@ -20,7 +21,13 @@ let%test_module "Stable.V1" =
         {|
         (Of_sexp_error
          "lib/core/src/nothing.ml.Stable.V1.t_of_sexp: trying to convert an empty type"
-         (invalid_sexp ())) |}]
+         (invalid_sexp ()))
+        |}]
+    ;;
+
+    let%expect_test _ =
+      print_endline [%bin_and_sexp_digest: Nothing.t];
+      [%expect {| 4c263abcdcee45b5eb6ba02681664ded |}]
     ;;
   end)
 ;;
