@@ -3,59 +3,59 @@ open! Expect_test_helpers_core
 open! Percent
 
 module Stable_unit_test (T : sig
-    type t = Percent.t
+  type t = Percent.t
 
-    include Binable with type t := t
-    include Sexpable with type t := t
-  end) (Version : sig
-          val v : int
-        end) =
-  Stable_unit_test.Make (struct
-    include T
+  include Binable with type t := t
+  include Sexpable with type t := t
+end) (Version : sig
+  val v : int
+end) =
+Stable_unit_test.Make (struct
+  include T
 
-    let equal = equal
+  let equal = equal
 
-    let tests =
-      [ of_mult 0.375, "37.5%", "\000\000\000\000\000\000\216?"
-      ; of_mult 4.5, "4.5x", "\000\000\000\000\000\000\018@"
-      ; of_mult 0.0002, "2bp", "-C\028\235\2266*?"
-      ; ( of_mult 0.000075
-        , (if Int.(Version.v < 3) then "0.75bp" else "7.5E-1bp")
-        , "a2U0*\169\019?" )
-      ]
-    ;;
-  end)
+  let tests =
+    [ of_mult 0.375, "37.5%", "\000\000\000\000\000\000\216?"
+    ; of_mult 4.5, "4.5x", "\000\000\000\000\000\000\018@"
+    ; of_mult 0.0002, "2bp", "-C\028\235\2266*?"
+    ; ( of_mult 0.000075
+      , (if Int.(Version.v < 3) then "0.75bp" else "7.5E-1bp")
+      , "a2U0*\169\019?" )
+    ]
+  ;;
+end)
 
 let%test_module "Percent.V1.Bin_shape_same_as_float" =
   (module Stable_unit_test
-       (Stable.V1.Bin_shape_same_as_float)
-       (struct
-         let v = 1
-       end))
+            (Stable.V1.Bin_shape_same_as_float)
+            (struct
+              let v = 1
+            end))
 ;;
 
 let%test_module "Percent.V3" =
   (module Stable_unit_test
-       (Stable.V3)
-       (struct
-         let v = 3
-       end))
+            (Stable.V3)
+            (struct
+              let v = 3
+            end))
 ;;
 
 let%test_module "Percent.V2" =
   (module Stable_unit_test
-       (Stable.V2)
-       (struct
-         let v = 2
-       end))
+            (Stable.V2)
+            (struct
+              let v = 2
+            end))
 ;;
 
 let%test_module "Percent" =
   (module Stable_unit_test
-       (Percent)
-       (struct
-         let v = 2
-       end))
+            (Percent)
+            (struct
+              let v = 2
+            end))
 ;;
 
 let%expect_test "bin_digests" =
@@ -80,7 +80,8 @@ let%expect_test "bin_digests" =
            v2 608ef16f40e15a75b1942a12465f47df
     option_v2 7d0312ebcdefb728502ea27a959a389b
            v3 320416d3338cb49f5c3ce6b8632f7717
-    option_v3 21451618c9bda19b005e0ba1e4abbd2a |}]
+    option_v3 21451618c9bda19b005e0ba1e4abbd2a
+    |}]
 ;;
 
 let%expect_test "rounding" =
@@ -198,7 +199,8 @@ let%expect_test _ =
       (0x   0)
       (15bp 1)
       (15%  2)
-      (15x  3))) |}]
+      (15x  3)))
+    |}]
 ;;
 
 let%expect_test "accept float in set and map sexps" =
@@ -223,7 +225,8 @@ let%expect_test "accept float in set and map sexps" =
     ((0x  "arbitrary value")
      (1bp "arbitrary value")
      (1%  "arbitrary value")
-     (1x  "arbitrary value")) |}]
+     (1x  "arbitrary value"))
+    |}]
 ;;
 
 let%expect_test "generator" =
@@ -259,7 +262,8 @@ let%expect_test "always-percentage format" =
     0x -> 0%
     3.2bp -> 0.032%
     5x -> 500%
-    75% -> 75% |}];
+    75% -> 75%
+    |}];
   let f x =
     let p = Percent.of_string x in
     printf
@@ -273,7 +277,8 @@ let%expect_test "always-percentage format" =
     0x -> 0.00000000%
     3.2bp -> 0.03200000%
     5x -> 500.00000000%
-    75% -> 75.00000000% |}]
+    75% -> 75.00000000%
+    |}]
 ;;
 
 let%expect_test "round-trippable sexp format" =
@@ -342,7 +347,8 @@ let%expect_test "round-trippable sexp format" =
        1.2E+09x |             1200000000x |              120000000000% |                1200000000x |              120000000000%
            7.3% |                    7.3% |                       7.3% |                       7.3% |                       7.3%
      1.39E-08bp |               1.39E-8bp |                  1.39E-10% |                  1.39E-8bp |                  1.39E-10%
-           15bp |                    15bp |                      0.15% |                       15bp |                      0.15% |}];
+           15bp |                    15bp |                      0.15% |                       15bp |                      0.15%
+    |}];
   Quickcheck.test Float.gen_finite ~trials:13 ~sexp_of:Float.sexp_of_t ~f:(fun x ->
     f (Percent.of_percentage x));
   [%expect
@@ -359,7 +365,8 @@ let%expect_test "round-trippable sexp format" =
            7.44064x |        7.4406372011417x |           744.06372011417% |        7.4406372011416533x |        744.06372011416533%
      1.96589E-316bp |  1.9658872048023E-316bp |      1.9658872048023E-318% |    1.96588720480232E-316bp |     1.96588720480232E-318%
             3.125bp |       3.1249999999773bp |         0.031249999999773% |       3.1249999999772627bp |      0.031249999999772627%
-          -2.18305x |       -2.1830518341064x |          -218.30518341064% |       -2.1830518341064451x |       -218.30518341064451% |}];
+          -2.18305x |       -2.1830518341064x |          -218.30518341064% |       -2.1830518341064451x |       -218.30518341064451%
+    |}];
   Quickcheck.test Float.gen_finite ~trials:1_000 ~sexp_of:Float.sexp_of_t ~f:(fun x ->
     (* check for accurate round trip *)
     let assert_rt x ~f ~g =
@@ -427,23 +434,25 @@ let%expect_test "Percent.Map serialization" =
   [%expect
     {|
     ((12.3457bp 3) (3.638% 2) (3.14159x 4) (3.1501x 1))
-    ((12.3456789bp 3) (3.638% 2) (3.1415926535897931x 4) (3.1501x 1)) |}]
+    ((12.3456789bp 3) (3.638% 2) (3.1415926535897931x 4) (3.1501x 1))
+    |}]
 ;;
 
 let%expect_test "nans and infs" =
   [ Float.nan; Float.infinity; Float.neg_infinity ]
   |> List.iter ~f:(fun p ->
-    let p = Percent.of_mult p in
-    let s1 = Percent.to_string p in
-    let s2 = Percent.Stable.V3.to_string p in
-    printf "%s | %s\n" s1 s2;
-    let p1 = Percent.of_string_allow_nan_and_inf s1 in
-    let p2 = Percent.Stable.V3.of_string_allow_nan_and_inf s2 in
-    assert (Percent.((is_nan p1 && is_nan p2) || p1 = p2)));
+       let p = Percent.of_mult p in
+       let s1 = Percent.to_string p in
+       let s2 = Percent.Stable.V3.to_string p in
+       printf "%s | %s\n" s1 s2;
+       let p1 = Percent.of_string_allow_nan_and_inf s1 in
+       let p2 = Percent.Stable.V3.of_string_allow_nan_and_inf s2 in
+       assert (Percent.((is_nan p1 && is_nan p2) || p1 = p2)));
   [%expect {|
     NANbp | NANx
     INFx | INFx
-    -INFx | -INFx |}];
+    -INFx | -INFx
+    |}];
   [ "nanx"
   ; "NANbp"
   ; "NaN%"
@@ -459,9 +468,9 @@ let%expect_test "nans and infs" =
   ; "-Inf%"
   ]
   |> List.iter ~f:(fun s ->
-    let p1 = Percent.of_string_allow_nan_and_inf s in
-    let p2 = Percent.Stable.V3.of_string_allow_nan_and_inf s in
-    assert (Percent.((is_nan p1 && is_nan p2) || p1 = p2)))
+       let p1 = Percent.of_string_allow_nan_and_inf s in
+       let p2 = Percent.Stable.V3.of_string_allow_nan_and_inf s in
+       assert (Percent.((is_nan p1 && is_nan p2) || p1 = p2)))
 ;;
 
 let%expect_test "slow_more_accurate" =
@@ -474,11 +483,13 @@ let%expect_test "slow_more_accurate" =
   ; Percent.of_bp_slow_more_accurate
   ]
   |> List.iter ~f:(fun f -> printf !"%{Percent#round_trippable}\n" (f x));
-  [%expect {|
+  [%expect
+    {|
     70.180000000000009%
     70.180000000000008bp
     70.18%
-    70.18bp |}];
+    70.18bp
+    |}];
   (* 57.2%: An example where [to_percentage] and [to_bp] both introduce ugly-looking
      rounding errors. *)
   let p = Percent.of_mult 0.572 in
@@ -492,12 +503,13 @@ let%expect_test "slow_more_accurate" =
     57.199999999999996
     5719.9999999999991
     57.2
-    5720. |}];
+    5720.
+    |}];
   (* Find some more examples where [to_percentage] and [to_bp] introduce errors. *)
   for i = 0 to 100 do
     let p = Percent.of_mult (float i /. 100.) in
     if Float.( <> ) (Percent.to_percentage p) (Percent.to_percentage_slow_more_accurate p)
-    && Float.( <> ) (Percent.to_bp p) (Percent.to_bp_slow_more_accurate p)
+       && Float.( <> ) (Percent.to_bp p) (Percent.to_bp_slow_more_accurate p)
     then printf !"%{Float} %{Float}\n" (Percent.to_percentage p) (Percent.to_bp p)
   done;
   [%expect
@@ -506,7 +518,8 @@ let%expect_test "slow_more_accurate" =
     14.000000000000002 1400.0000000000002
     28.000000000000004 2800.0000000000005
     56.000000000000007 5600.0000000000009
-    56.999999999999993 5699.9999999999991 |}]
+    56.999999999999993 5699.9999999999991
+    |}]
 ;;
 
 let%expect_test "parse errors" =
@@ -529,11 +542,11 @@ let%expect_test "parse errors" =
     ; "-infinity%"
     ]
     ~f:(fun s ->
-      let s1 =
-        try Percent.of_string s |> Percent.to_string_round_trippable with
-        | exn -> Exn.to_string_mach exn
-      in
-      printf "%s\n====\n" s1);
+    let s1 =
+      try Percent.of_string s |> Percent.to_string_round_trippable with
+      | exn -> Exn.to_string_mach exn
+    in
+    printf "%s\n====\n" s1);
   [%expect
     {|
     (Failure"Percent.of_string: must end in x, %, or bp: +34.27")
@@ -567,5 +580,6 @@ let%expect_test "parse errors" =
     (Failure"Unexpected character when parsing Percent.t: 'i' in '+inf'")
     ====
     (Failure"Unexpected character when parsing Percent.t: 'i' in '-infinity'")
-    ==== |}]
+    ====
+    |}]
 ;;
