@@ -27,7 +27,8 @@ let%expect_test "Time.Stable.With_utc_sexp.V2" =
     ((sexp (2001-01-01 00:00:00.000000Z)) (bin_io "\000\000\000@\228'\205A"))
     ((sexp (2013-10-07 09:30:00.000000Z))
      (bin_io "\000\000\000\198\159\148\212A"))
-    ((sexp (2017-07-28 11:57:00.000123Z)) (bin_io "\004\002\000\163\201^\214A")) |}]
+    ((sexp (2017-07-28 11:57:00.000123Z)) (bin_io "\004\002\000\163\201^\214A"))
+    |}]
 ;;
 
 let span_examples =
@@ -123,7 +124,8 @@ let%expect_test "Time.Stable.Span.V1" =
     ((sexp   -3.14159h)
      (bin_io "\162\235\015\229\221\022\198\192"))
     ((sexp   -3.14159d)
-     (bin_io "\186\240\203k&\145\016\193")) |}]
+     (bin_io "\186\240\203k&\145\016\193"))
+    |}]
 ;;
 
 let%expect_test "Time.Stable.Span.V2" =
@@ -202,7 +204,8 @@ let%expect_test "Time.Stable.Span.V2" =
     ((sexp   -3.1415926535897931h)
      (bin_io "\162\235\015\229\221\022\198\192"))
     ((sexp   -3.1415926535897936d)
-     (bin_io "\186\240\203k&\145\016\193")) |}]
+     (bin_io "\186\240\203k&\145\016\193"))
+    |}]
 ;;
 
 let span_gen = Quickcheck.Generator.map Float.gen_finite ~f:Time_float.Span.of_sec
@@ -342,7 +345,8 @@ let%test_module "Time.Stable.Span.V3" =
         ((sexp   INFs)
          (bin_io "\000\000\000\000\000\000\240\127"))
         ((sexp   -INFs)
-         (bin_io "\000\000\000\000\000\000\240\255")) |}]
+         (bin_io "\000\000\000\000\000\000\240\255"))
+        |}]
     ;;
 
     let%expect_test ("serialization tests for NaNs" [@tags "64-bits-only"]) =
@@ -358,7 +362,8 @@ let%test_module "Time.Stable.Span.V3" =
         ((sexp   NANs)
          (bin_io "\001\000\000\000\000\000\248\127"))
         ((sexp   NANs)
-         (bin_io "\001\000\000\000\000\000\248\255")) |}]
+         (bin_io "\001\000\000\000\000\000\248\255"))
+        |}]
     ;;
 
     let%expect_test "V3 accepts V1 and V2 sexp outputs" =
@@ -415,7 +420,8 @@ let%test_module "Span.to_string/of_string" =
         864000000.00000012
         864000000.00000012
         864000000.
-        8640001.000001 |}]
+        8640001.000001
+        |}]
     ;;
 
     let near_powers_of_10 =
@@ -448,18 +454,18 @@ let%test_module "Span.to_string/of_string" =
         ~sexp_of:Time_float.Span.sexp_of_t
         ~examples:near_powers_of_10
         ~f:(fun span ->
-          let string = Time_float.Span.to_string span in
-          let round_trip = Time_float.Span.of_string string in
-          require
-            [%here]
-            (Time_float.Span.equal round_trip span)
-            ~if_false_then_print_s:
-              (lazy
-                [%message
-                  "string round-trip is not precise"
-                    (span : Time_float.Span.t)
-                    (string : string)
-                    (round_trip : Time_float.Span.t)]));
+        let string = Time_float.Span.to_string span in
+        let round_trip = Time_float.Span.of_string string in
+        require
+          [%here]
+          (Time_float.Span.equal round_trip span)
+          ~if_false_then_print_s:
+            (lazy
+              [%message
+                "string round-trip is not precise"
+                  (span : Time_float.Span.t)
+                  (string : string)
+                  (round_trip : Time_float.Span.t)]));
       [%expect {| |}]
     ;;
 
@@ -488,27 +494,27 @@ let%test_module "Span.to_string/of_string" =
         string_with_underscores_gen
         ~sexp_of:String.sexp_of_t
         ~f:(fun string_with_underscores ->
-          require_does_not_raise [%here] (fun () ->
-            let span = Time_float.Span.of_string string_with_underscores in
-            let string_without_underscores = Time_float.Span.to_string span in
-            let round_trip = Time_float.Span.of_string string_without_underscores in
-            require_equal
-              [%here]
-              (module Time_float.Span)
-              span
-              round_trip
-              ~if_false_then_print_s:(lazy [%message string_without_underscores]);
-            let string_with_underscores_removed =
-              String.filter string_with_underscores ~f:(function
-                | '_' -> false
-                | _ -> true)
-            in
-            require_equal
-              [%here]
-              (module String)
-              string_without_underscores
-              string_with_underscores_removed
-              ~if_false_then_print_s:(lazy [%sexp (span : Time_float.Span.t)])));
+        require_does_not_raise [%here] (fun () ->
+          let span = Time_float.Span.of_string string_with_underscores in
+          let string_without_underscores = Time_float.Span.to_string span in
+          let round_trip = Time_float.Span.of_string string_without_underscores in
+          require_equal
+            [%here]
+            (module Time_float.Span)
+            span
+            round_trip
+            ~if_false_then_print_s:(lazy [%message string_without_underscores]);
+          let string_with_underscores_removed =
+            String.filter string_with_underscores ~f:(function
+              | '_' -> false
+              | _ -> true)
+          in
+          require_equal
+            [%here]
+            (module String)
+            string_without_underscores
+            string_with_underscores_removed
+            ~if_false_then_print_s:(lazy [%sexp (span : Time_float.Span.t)])));
       [%expect {| |}]
     ;;
 
@@ -542,9 +548,9 @@ let%test_module "Span.to_string/of_string" =
       float_gen_uniform_exponent ~min_exponent ~max_exponent
       |> Quickcheck.Generator.map ~f:Time_float.Span.of_sec
       |> Quickcheck.Generator.filter ~f:(fun span ->
-        let magnitude = Time_float.Span.abs span in
-        Time_float.Span.( > ) magnitude magnitude_low
-        && Time_float.Span.( < ) magnitude magnitude_high)
+           let magnitude = Time_float.Span.abs span in
+           Time_float.Span.( > ) magnitude magnitude_low
+           && Time_float.Span.( < ) magnitude magnitude_high)
     ;;
 
     let test_part_magnitudes ~magnitude_low ~magnitude_high ~allow_abnormal_frac =
@@ -574,7 +580,7 @@ let%test_module "Span.to_string/of_string" =
         let magnitudes_and_units =
           String.to_list string
           |> List.group ~break:(fun a b ->
-            Bool.( <> ) (is_float_char a) (is_float_char b))
+               Bool.( <> ) (is_float_char a) (is_float_char b))
           |> List.map ~f:String.of_char_list
         in
         parts_of_list magnitudes_and_units
@@ -597,21 +603,21 @@ let%test_module "Span.to_string/of_string" =
         quickcheck_generator
         ~sexp_of:Time_float.Span.sexp_of_t
         ~f:(fun span ->
-          let seconds = Time_float.Span.to_sec span in
-          let ulp = Float.one_ulp `Up seconds -. seconds in
-          let string = Time_float.Span.to_string span in
-          require
-            [%here]
-            (Time_float.Span.of_string string = span)
-            ~if_false_then_print_s:
-              (lazy
-                [%message
-                  "span failed to round-trip string conversion"
-                    (string : string)
-                    (seconds : float)]);
-          let parts = parts_of_string string in
-          let is_abnormal =
-            (* Spans with a ULP over half a minute start to have abnormal parts like
+        let seconds = Time_float.Span.to_sec span in
+        let ulp = Float.one_ulp `Up seconds -. seconds in
+        let string = Time_float.Span.to_string span in
+        require
+          [%here]
+          (Time_float.Span.of_string string = span)
+          ~if_false_then_print_s:
+            (lazy
+              [%message
+                "span failed to round-trip string conversion"
+                  (string : string)
+                  (seconds : float)]);
+        let parts = parts_of_string string in
+        let is_abnormal =
+          (* Spans with a ULP over half a minute start to have abnormal parts like
                "60s".  This is an artifact of our [to_string] algorithm and how it uses
                smaller units of time to correct for rounding error in the larger ones;
                once the rounding error is over half the size of the previous unit, the
@@ -621,49 +627,49 @@ let%test_module "Span.to_string/of_string" =
                rarely used, we tolerate the abnormality, but only in the very last
                part. Additionally, we very occasionally have remainders that are >900us,
                but we print 1 decimal place and end up printing 1000us instead of 1ms *)
-            List.fold parts ~init:false ~f:(fun has_abnormal (magnitude, unit_of_time) ->
-              let open Float.O in
-              require
-                [%here]
-                (not has_abnormal)
-                ~if_false_then_print_s:
-                  (lazy [%message "abnormal span part not last" (string : string)]);
-              require
-                [%here]
-                (magnitude > 0.)
-                ~if_false_then_print_s:
-                  (lazy
-                    [%message
-                      "magnitude is negative"
-                        (string : string)
-                        (magnitude : float)
-                        (unit_of_time : Unit_of_time.t)]);
-              Option.value_map
-                ~default:false
-                (upper_bound unit_of_time)
-                ~f:(fun upper_bound ->
-                  (* we tolerate one abnormality where the very last part is exactly at
+          List.fold parts ~init:false ~f:(fun has_abnormal (magnitude, unit_of_time) ->
+            let open Float.O in
+            require
+              [%here]
+              (not has_abnormal)
+              ~if_false_then_print_s:
+                (lazy [%message "abnormal span part not last" (string : string)]);
+            require
+              [%here]
+              (magnitude > 0.)
+              ~if_false_then_print_s:
+                (lazy
+                  [%message
+                    "magnitude is negative"
+                      (string : string)
+                      (magnitude : float)
+                      (unit_of_time : Unit_of_time.t)]);
+            Option.value_map
+              ~default:false
+              (upper_bound unit_of_time)
+              ~f:(fun upper_bound ->
+              (* we tolerate one abnormality where the very last part is exactly at
                      the upper bound *)
-                  if magnitude = upper_bound
-                  then true
-                  else (
-                    require
-                      [%here]
-                      (magnitude < upper_bound)
-                      ~if_false_then_print_s:
-                        (lazy
-                          [%message
-                            "magnitude out of bounds"
-                              (string : string)
-                              (seconds : float)
-                              (ulp : float)
-                              (magnitude : float)
-                              (upper_bound : float)
-                              (unit_of_time : Unit_of_time.t)]);
-                    false)))
-          in
-          incr test_count;
-          if is_abnormal then incr abnormal_count);
+              if magnitude = upper_bound
+              then true
+              else (
+                require
+                  [%here]
+                  (magnitude < upper_bound)
+                  ~if_false_then_print_s:
+                    (lazy
+                      [%message
+                        "magnitude out of bounds"
+                          (string : string)
+                          (seconds : float)
+                          (ulp : float)
+                          (magnitude : float)
+                          (upper_bound : float)
+                          (unit_of_time : Unit_of_time.t)]);
+                false)))
+        in
+        incr test_count;
+        if is_abnormal then incr abnormal_count);
       let abnormal_frac = Float.of_int !abnormal_count /. Float.of_int !test_count in
       if Float.(abnormal_frac > allow_abnormal_frac)
       then
@@ -691,42 +697,48 @@ let%test_module "Span.to_string/of_string" =
         {|
         span    : 6362914d12h18m8s
         ulp up  : 122.0703125us
-        ulp down: 61.03515625us |}];
+        ulp down: 61.03515625us
+        |}];
       let ms_ulp = Time_float.Span.of_sec (Float.ldexp 1. (53 - 10)) in
       check_ulps ms_ulp;
       [%expect
         {|
         span    : 101806632d4h50m8s
         ulp up  : 1.953125ms
-        ulp down: 976.5625us |}];
+        ulp down: 976.5625us
+        |}];
       let half_min_ulp = Time_float.Span.of_sec (Float.ldexp 1. (53 + 4)) in
       check_ulps half_min_ulp;
       [%expect
         {|
         span    : 1667999861989d1h44m32s
         ulp up  : 32s
-        ulp down: 16s |}];
+        ulp down: 16s
+        |}];
       let two_min_ulp = Time_float.Span.of_sec (Float.ldexp 1. (53 + 6)) in
       check_ulps two_min_ulp;
       [%expect
         {|
         span    : 6671999447956d6h58m
         ulp up  : 2m8s
-        ulp down: 1m4s |}];
+        ulp down: 1m4s
+        |}];
       let quarter_hr_ulp = Time_float.Span.of_sec (Float.ldexp 1. (53 + 9)) in
       check_ulps quarter_hr_ulp;
       [%expect
         {|
         span    : 53375995583650d7h42m
         ulp up  : 17m4s
-        ulp down: 8m32s |}];
+        ulp down: 8m32s
+        |}];
       let two_hr_ulp = Time_float.Span.of_sec (Float.ldexp 1. (53 + 12)) in
       check_ulps two_hr_ulp;
       [%expect
         {|
         span    : 427007964669202d14h
         ulp up  : 2h16m32s
-        ulp down: 1h8m16s |}];
+        ulp down: 1h8m16s
+        |}];
       let infinity = Time_float.Span.of_sec Float.infinity in
       (* Test magnitudes of span parts, allowing abnormal magnitudes (like 24h or 60s) in
          the ranges where we expect them. The allowed fractions of values with abnormal
@@ -772,7 +784,8 @@ let%test_module "Span.to_string/of_string" =
         {|
         34771412d23h36m1e+03us
         5267882376633d10h60m
-        218326395376058d24h |}]
+        218326395376058d24h
+        |}]
     ;;
 
     let%expect_test "unit appearing twice" =
@@ -794,7 +807,8 @@ let%test_module "Span.to_string/of_string" =
       [%expect
         {|
         ("quickcheck: test failed" (input -2.1695734240829744e+44d3e+28d))
-        (* require-failed: lib/core/test/test_time.ml:LINE:COL. *) |}];
+        (* require-failed: lib/core/test/test_time.ml:LINE:COL. *)
+        |}];
       test "h";
       [%expect {| |}];
       test "m";
@@ -812,7 +826,8 @@ let%test_module "Span.to_string/of_string" =
       [%expect
         {|
         ("quickcheck: test failed" (input -3.70807784925899e-59ns4e-75ns))
-        (* require-failed: lib/core/test/test_time.ml:LINE:COL. *) |}]
+        (* require-failed: lib/core/test/test_time.ml:LINE:COL. *)
+        |}]
     ;;
   end)
 ;;
@@ -879,13 +894,14 @@ let%expect_test "Span.to_parts + Span.create" =
     (-3h8m29.733552923255s
      ((sign Neg) (hr 3) (min 8) (sec 29) (ms 733) (us 552) (ns 923)))
     (-3d3h23m53.60527015815s
-     ((sign Neg) (hr 75) (min 23) (sec 53) (ms 605) (us 270) (ns 158))) |}]
+     ((sign Neg) (hr 75) (min 23) (sec 53) (ms 605) (us 270) (ns 158)))
+    |}]
 ;;
 
 let ofday_examples =
   List.filter_map span_examples ~f:(fun span ->
     if Time_float.Span.( >= ) span Time_float.Span.zero
-    && Time_float.Span.( < ) span Time_float.Span.day
+       && Time_float.Span.( < ) span Time_float.Span.day
     then Some (Time_float.Ofday.of_span_since_start_of_day_exn span)
     else None)
 ;;
@@ -926,7 +942,8 @@ let%expect_test "Ofday.to_parts + Ofday.create" =
     (00:03:08.495559
      ((sign Pos) (hr 0) (min 3) (sec 8) (ms 495) (us 559) (ns 215)))
     (03:08:29.733553
-     ((sign Pos) (hr 3) (min 8) (sec 29) (ms 733) (us 552) (ns 923))) |}]
+     ((sign Pos) (hr 3) (min 8) (sec 29) (ms 733) (us 552) (ns 923)))
+    |}]
 ;;
 
 let%expect_test "time zone offset parsing" =
@@ -942,7 +959,8 @@ let%expect_test "time zone offset parsing" =
     2000-01-01 12:34:56.789012Z
     2000-01-01 12:34:56.789012Z
     2000-01-01 12:34:56.789012Z
-    2000-01-01 12:34:56.789012Z |}];
+    2000-01-01 12:34:56.789012Z
+    |}];
   test "2000-01-01 12:34:56.789012-05:00";
   test "2000-01-01 12:34:56.789012-5:00";
   test "2000-01-01 12:34:56.789012-05";
@@ -952,17 +970,20 @@ let%expect_test "time zone offset parsing" =
     2000-01-01 17:34:56.789012Z
     2000-01-01 17:34:56.789012Z
     2000-01-01 17:34:56.789012Z
-    2000-01-01 17:34:56.789012Z |}];
+    2000-01-01 17:34:56.789012Z
+    |}];
   test "2000-01-01 12:34:56.789012-23:00";
   test "2000-01-01 12:34:56.789012-23";
   [%expect {|
     2000-01-02 11:34:56.789012Z
-    2000-01-02 11:34:56.789012Z |}];
+    2000-01-02 11:34:56.789012Z
+    |}];
   test "2000-01-01 12:34:56.789012-24:00";
   test "2000-01-01 12:34:56.789012-24";
   [%expect {|
     2000-01-02 12:34:56.789012Z
-    2000-01-02 12:34:56.789012Z |}]
+    2000-01-02 12:34:56.789012Z
+    |}]
 ;;
 
 let%expect_test "time zone invalid offset parsing" =
@@ -1006,7 +1027,8 @@ let%expect_test "time zone invalid offset parsing" =
      (Failure "Char.get_digit_exn ':': not a digit"))
     (time.ml.Make.Time_of_string
      "2000-01-01 12:34:56.789012-"
-     (Invalid_argument "index out of bounds")) |}];
+     (Invalid_argument "index out of bounds"))
+    |}];
   test [%here] "2000-01-01 12:34:56.789012-25:00";
   test [%here] "2000-01-01 12:34:56.789012-25";
   [%expect
@@ -1016,7 +1038,8 @@ let%expect_test "time zone invalid offset parsing" =
      ("Time.Ofday: invalid string" 25:00 "hours out of bounds"))
     (time.ml.Make.Time_of_string
      "2000-01-01 12:34:56.789012-25"
-     ("Time.Ofday: invalid string" 25:00 "hours out of bounds")) |}];
+     ("Time.Ofday: invalid string" 25:00 "hours out of bounds"))
+    |}];
   test [%here] "2000-01-01 12:34:56.789012--1:00";
   test [%here] "2000-01-01 12:34:56.789012--1";
   [%expect
@@ -1026,7 +1049,8 @@ let%expect_test "time zone invalid offset parsing" =
      (Failure "Char.get_digit_exn '-': not a digit"))
     (time.ml.Make.Time_of_string
      "2000-01-01 12:34:56.789012--1"
-     (Invalid_argument "index out of bounds")) |}]
+     (Invalid_argument "index out of bounds"))
+    |}]
 ;;
 
 let%expect_test "of_string_iso8601_extended" =
@@ -1046,28 +1070,28 @@ let%expect_test "of_string_iso8601_extended" =
     ; "12:34:56.789"
     ; "12:34:56.789123"
     ; "12:34:56.789123456"
-      ; (* lower boundary case *)
+    ; (* lower boundary case *)
       "00"
     ; "00:00"
     ; "00:00:00"
     ; "00:00:00.000"
     ; "00:00:00.000000"
     ; "00:00:00.000000000"
-      ; (* upper boundary case *)
+    ; (* upper boundary case *)
       "23"
     ; "23:59"
     ; "23:59:59"
     ; "23:59:59.999"
     ; "23:59:59.999999"
     ; "23:59:59.999999999"
-      ; (* midnight tomorrow *)
+    ; (* midnight tomorrow *)
       "24"
     ; "24:00"
     ; "24:00:00"
     ; "24:00:00.000"
     ; "24:00:00.000000"
     ; "24:00:00.000000000"
-      ; (* leap second *)
+    ; (* leap second *)
       "12:59:60"
     ; "12:59:60.789"
     ; "12:59:60.789123"
@@ -1102,7 +1126,8 @@ let%expect_test "of_string_iso8601_extended" =
     13:00:00.000000 <-- 12:59:60
     13:00:00.000000 <-- 12:59:60.789
     13:00:00.000000 <-- 12:59:60.789123
-    13:00:00.000000 <-- 12:59:60.789123456 |}];
+    13:00:00.000000 <-- 12:59:60.789123456
+    |}];
   let failure string =
     match Time_float.Ofday.of_string_iso8601_extended string with
     | exception Invalid_argument message -> print_endline message
@@ -1127,7 +1152,7 @@ let%expect_test "of_string_iso8601_extended" =
     ; "12:345"
     ; "12:34:"
     ; "12:34:5"
-      ; (* numerical bounds *)
+    ; (* numerical bounds *)
       "25:00"
     ; "00:60"
     ; "00:59:61"
@@ -1146,7 +1171,8 @@ let%expect_test "of_string_iso8601_extended" =
     Ofday.of_string_iso8601_extended(12:34:5): (Failure "5 < len < 8")
     Ofday.of_string_iso8601_extended(25:00): (Failure "hour > 24")
     Ofday.of_string_iso8601_extended(00:60): (Failure "minute > 60")
-    Ofday.of_string_iso8601_extended(00:59:61): (Failure "invalid second: 61") |}]
+    Ofday.of_string_iso8601_extended(00:59:61): (Failure "invalid second: 61")
+    |}]
 ;;
 
 module _ = struct
@@ -1193,8 +1219,8 @@ module _ = struct
     printf "%s\n" (String.concat ~sep:" " (Lazy.force Ofday_helpers.pm_suffixes));
     [%expect
       {|
-        a A am AM a.m A.M a.m. A.M.
-        p P pm PM p.m P.M p.m. P.M.
+      a A am AM a.m A.M a.m. A.M.
+      p P pm PM p.m P.M p.m. P.M.
       |}]
   ;;
 
@@ -1283,44 +1309,44 @@ module _ = struct
 
     let%test_module "Span.V1" =
       (module Stable_unit_test.Make (struct
-           include V1
+        include V1
 
-           let equal t1 t2 = Int.( = ) 0 (compare t1 t2)
+        let equal t1 t2 = Int.( = ) 0 (compare t1 t2)
 
-           let tests =
-             let span = of_sec in
-             [ span 99e-12, "9.9e-08ms", "\018\006\211\115\129\054\219\061"
-             ; span 1.2e-9, "1.2e-06ms", "\076\206\097\227\167\157\020\062"
-             ; span 0.000001, "0.001ms", "\141\237\181\160\247\198\176\062"
-             ; span 0.707, "707ms", "\057\180\200\118\190\159\230\063"
-             ; span 42., "42s", "\000\000\000\000\000\000\069\064"
-             ; span 1234.56, "20.576m", "\010\215\163\112\061\074\147\064"
-             ; span 39_996., "11.11h", "\000\000\000\000\128\135\227\064"
-             ; span 80000006.4, "925.926d", "\154\153\153\025\208\018\147\065"
-             ]
-           ;;
-         end))
+        let tests =
+          let span = of_sec in
+          [ span 99e-12, "9.9e-08ms", "\018\006\211\115\129\054\219\061"
+          ; span 1.2e-9, "1.2e-06ms", "\076\206\097\227\167\157\020\062"
+          ; span 0.000001, "0.001ms", "\141\237\181\160\247\198\176\062"
+          ; span 0.707, "707ms", "\057\180\200\118\190\159\230\063"
+          ; span 42., "42s", "\000\000\000\000\000\000\069\064"
+          ; span 1234.56, "20.576m", "\010\215\163\112\061\074\147\064"
+          ; span 39_996., "11.11h", "\000\000\000\000\128\135\227\064"
+          ; span 80000006.4, "925.926d", "\154\153\153\025\208\018\147\065"
+          ]
+        ;;
+      end))
     ;;
 
     let%test_module "Span.V2" =
       (module Stable_unit_test.Make (struct
-           include V2
+        include V2
 
-           let equal t1 t2 = Int.( = ) 0 (compare t1 t2)
+        let equal t1 t2 = Int.( = ) 0 (compare t1 t2)
 
-           let tests =
-             let span = of_sec in
-             [ span 99e-12, "0.098999999999999991ns", "\018\006\211\115\129\054\219\061"
-             ; span 1.2e-9, "1.2ns", "\076\206\097\227\167\157\020\062"
-             ; span 0.000001, "1us", "\141\237\181\160\247\198\176\062"
-             ; span 0.707, "707ms", "\057\180\200\118\190\159\230\063"
-             ; span 42., "42s", "\000\000\000\000\000\000\069\064"
-             ; span 1234.56, "20.576m", "\010\215\163\112\061\074\147\064"
-             ; span 39_996., "11.11h", "\000\000\000\000\128\135\227\064"
-             ; span 80000006.4, "925.926d", "\154\153\153\025\208\018\147\065"
-             ]
-           ;;
-         end))
+        let tests =
+          let span = of_sec in
+          [ span 99e-12, "0.098999999999999991ns", "\018\006\211\115\129\054\219\061"
+          ; span 1.2e-9, "1.2ns", "\076\206\097\227\167\157\020\062"
+          ; span 0.000001, "1us", "\141\237\181\160\247\198\176\062"
+          ; span 0.707, "707ms", "\057\180\200\118\190\159\230\063"
+          ; span 42., "42s", "\000\000\000\000\000\000\069\064"
+          ; span 1234.56, "20.576m", "\010\215\163\112\061\074\147\064"
+          ; span 39_996., "11.11h", "\000\000\000\000\128\135\227\064"
+          ; span 80000006.4, "925.926d", "\154\153\153\025\208\018\147\065"
+          ]
+        ;;
+      end))
     ;;
   end
 
@@ -1393,14 +1419,16 @@ let%expect_test "times with implicit zones" =
     Time_float.Stable.With_utc_sexp.V2.t_of_sexp (Sexp.of_string "(2013-10-07 09:30)"));
   [%expect {|
     2013-10-07 09:30:00.000000Z
-    "did not raise" |}];
+    "did not raise"
+    |}];
   require_does_raise [%here] (fun () ->
     Time_float.of_string_with_utc_offset "2013-10-07 09:30");
   [%expect
     {|
     (time.ml.Make.Time_of_string
      "2013-10-07 09:30"
-     ("time has no time zone or UTC offset" "2013-10-07 09:30")) |}]
+     ("time has no time zone or UTC offset" "2013-10-07 09:30"))
+    |}]
 ;;
 
 let%expect_test "quickcheck should generate serializable times" =
