@@ -88,7 +88,8 @@ let%expect_test "Time_ns.Span.Stable.V1" =
      (int63  80_000_006_400_000_000))
     ((sexp   1e-06ms)
      (bin_io "\001")
-     (int63  1)) |}];
+     (int63  1))
+    |}];
   (* stable checks for values that do not precisely round-trip *)
   print_and_check_stable_int63able_type
     [%here]
@@ -105,7 +106,8 @@ let%expect_test "Time_ns.Span.Stable.V1" =
     ("sexp serialization failed to round-trip"
       (original       11.2754s)
       (sexp           11.2754s)
-      (sexp_roundtrip 11.2754s)) |}];
+      (sexp_roundtrip 11.2754s))
+    |}];
   (* make sure [of_int63_exn] allows all values *)
   show_raise ~hide_positions:true (fun () -> V.of_int63_exn (Int63.succ Int63.min_value));
   [%expect {| "did not raise" |}]
@@ -145,10 +147,10 @@ let%test_module "Time_ns.Span.Stable.V2" =
         ~examples:span_examples
         span_gen
         ~f:(fun span ->
-          let rt = V.t_of_sexp (V.sexp_of_t span) in
-          require_equal [%here] (module Time_ns.Span) span rt;
-          let rt = V.of_int63_exn (V.to_int63 span) in
-          require_equal [%here] (module Time_ns.Span) span rt);
+        let rt = V.t_of_sexp (V.sexp_of_t span) in
+        require_equal [%here] (module Time_ns.Span) span rt;
+        let rt = V.of_int63_exn (V.to_int63 span) in
+        require_equal [%here] (module Time_ns.Span) span rt);
       [%expect {| |}]
     ;;
 
@@ -224,12 +226,13 @@ let%test_module "Time_ns.Span.Stable.V2" =
          (int63  4_611_686_018_427_387_903))
         ((sexp   -53375d23h53m38.427387904s)
          (bin_io "\252\000\000\000\000\000\000\000\192")
-         (int63  -4_611_686_018_427_387_904)) |}]
+         (int63  -4_611_686_018_427_387_904))
+        |}]
     ;;
   end)
 ;;
 
-let%test_module "Time_ns.Alternate_sexp" =
+let%test_module "Time_ns.Alternate_sexp and Time_ns.Option.Alternate_sexp" =
   (module struct
     module Span = Time_ns.Span
 
@@ -286,7 +289,38 @@ let%test_module "Time_ns.Alternate_sexp" =
         "2001-01-01 16:23:42Z"
         "2013-10-07 09:14:47.999749999Z"
         "2013-10-07 09:14:47.99975Z"
-        "2013-10-07 09:14:47.999750001Z" |}]
+        "2013-10-07 09:14:47.999750001Z"
+        |}];
+      let option_examples =
+        Time_ns.Option.none :: List.map examples ~f:Time_ns.Option.some
+      in
+      List.iter option_examples ~f:(fun time_ns_opt ->
+        print_s [%sexp (time_ns_opt : Time_ns.Option.Alternate_sexp.t)];
+        let round_trip =
+          Time_ns.Option.Alternate_sexp.t_of_sexp
+            (Time_ns.Option.Alternate_sexp.sexp_of_t time_ns_opt)
+        in
+        require
+          [%here]
+          (Time_ns.Option.equal time_ns_opt round_trip)
+          ~if_false_then_print_s:
+            (lazy
+              [%message
+                "Time_ns.Option.Alternate_sexp round-trip failed"
+                  (time_ns_opt : Time_ns.Option.Alternate_sexp.t)
+                  (round_trip : Time_ns.Option.Alternate_sexp.t)]));
+      [%expect
+        {|
+        ()
+        ("1835-02-03 00:00:00Z")
+        ("2104-11-29 00:00:00Z")
+        ("1970-01-01 00:00:00Z")
+        ("2001-01-01 00:00:00Z")
+        ("2001-01-01 16:23:42Z")
+        ("2013-10-07 09:14:47.999749999Z")
+        ("2013-10-07 09:14:47.99975Z")
+        ("2013-10-07 09:14:47.999750001Z")
+        |}]
     ;;
 
     let%expect_test "round-trip" =
@@ -314,7 +348,8 @@ let%test_module "Time_ns.Alternate_sexp" =
         (Tagged
          ((key sexp_grammar.type_name)
           (value Core.Time_ns.Alternate_sexp.t)
-          (grammar String))) |}]
+          (grammar String)))
+        |}]
     ;;
   end)
 ;;
@@ -327,7 +362,7 @@ let%test_module "Time_ns.Utc.to_date_and_span_since_start_of_day" =
           Core.Time_ns.Utc.to_date_and_span_since_start_of_day time_ns
         in
         if Time_ns.Span.( < ) span_since_start_of_day Time_ns.Span.zero
-        || Time_ns.Span.( >= ) span_since_start_of_day Time_ns.Span.day
+           || Time_ns.Span.( >= ) span_since_start_of_day Time_ns.Span.day
         then
           raise_s
             [%message
@@ -352,6 +387,102 @@ let%test_module "Time_ns.Utc.to_date_and_span_since_start_of_day" =
   end)
 ;;
 
+let%test_module "Time_ns.Span rounding" =
+  (module struct
+    open Time_ns.Span
+
+    let%test_unit "Span.round_down" =
+      [%test_result: t]
+        (round_down ~to_multiple_of:nanosecond nanosecond)
+        ~expect:nanosecond;
+      [%test_result: t] (round_down ~to_multiple_of:second nanosecond) ~expect:zero;
+      [%test_result: t] (round_down ~to_multiple_of:second second) ~expect:second;
+      [%test_result: t] (round_down ~to_multiple_of:second hour) ~expect:hour;
+      [%test_result: t] (round_down ~to_multiple_of:second (of_sec 1.6)) ~expect:second;
+      [%test_result: t] (round_down ~to_multiple_of:minute (of_sec 30.)) ~expect:zero;
+      [%test_result: t] (round_down ~to_multiple_of:hour (of_day 1.1)) ~expect:(of_hr 26.)
+    ;;
+
+    let%test_unit "Span.round_up" =
+      [%test_result: t]
+        (round_up ~to_multiple_of:nanosecond nanosecond)
+        ~expect:nanosecond;
+      [%test_result: t] (round_up ~to_multiple_of:second nanosecond) ~expect:second;
+      [%test_result: t] (round_up ~to_multiple_of:second second) ~expect:second;
+      [%test_result: t] (round_up ~to_multiple_of:second hour) ~expect:hour;
+      [%test_result: t] (round_up ~to_multiple_of:second (of_sec 1.6)) ~expect:(of_sec 2.);
+      [%test_result: t] (round_up ~to_multiple_of:minute (of_sec 30.)) ~expect:minute;
+      [%test_result: t] (round_up ~to_multiple_of:hour (of_day 1.1)) ~expect:(of_hr 27.)
+    ;;
+
+    let%test_unit "Span.round_nearest" =
+      [%test_result: t]
+        (round_nearest ~to_multiple_of:nanosecond nanosecond)
+        ~expect:nanosecond;
+      [%test_result: t] (round_nearest ~to_multiple_of:second nanosecond) ~expect:zero;
+      [%test_result: t] (round_nearest ~to_multiple_of:second second) ~expect:second;
+      [%test_result: t] (round_nearest ~to_multiple_of:second hour) ~expect:hour;
+      [%test_result: t]
+        (round_nearest ~to_multiple_of:second (of_sec 1.6))
+        ~expect:(of_sec 2.);
+      [%test_result: t] (round_nearest ~to_multiple_of:minute (of_sec 30.)) ~expect:minute;
+      [%test_result: t]
+        (round_nearest ~to_multiple_of:hour (of_day 1.1))
+        ~expect:(of_hr 26.)
+    ;;
+
+    let%expect_test "quickcheck rounding" =
+      quickcheck_m
+        [%here]
+        (module struct
+          type t = Time_ns.Span.t * Unit_of_time.t * Rounding_direction.t
+          [@@deriving sexp_of]
+
+          let quickcheck_shrinker = Quickcheck.Shrinker.empty ()
+
+          let quickcheck_generator =
+            let decade = Time_ns.Span.of_int_day 36525 in
+            Quickcheck.Generator.tuple3
+              (Time_ns.Span.gen_uniform_incl (Time_ns.Span.neg decade) decade)
+              (Quickcheck.Generator.of_list Unit_of_time.all)
+              (Quickcheck.Generator.of_list Rounding_direction.all)
+          ;;
+        end)
+        ~f:(fun (span, unit_of_time, dir) ->
+          let to_multiple_of = of_unit_of_time unit_of_time in
+          let rounded = round span ~dir ~to_multiple_of in
+          let expect =
+            match dir with
+            | Up -> round_up span ~to_multiple_of
+            | Down -> round_down span ~to_multiple_of
+            | Zero -> round_towards_zero span ~to_multiple_of
+            | Nearest -> round_nearest span ~to_multiple_of
+          in
+          let remainder_ns =
+            Int63.rem (to_int63_ns rounded) (to_int63_ns to_multiple_of)
+          in
+          let if_false_then_print_s =
+            [%lazy_message
+              "" (to_multiple_of : t) (rounded : t) (expect : t) (remainder_ns : Int63.t)]
+          in
+          require_equal
+            [%here]
+            (module Time_ns.Span)
+            rounded
+            expect
+            ~if_false_then_print_s;
+          require [%here] (abs (span - rounded) < to_multiple_of) ~if_false_then_print_s;
+          require [%here] (Int63.equal remainder_ns Int63.zero) ~if_false_then_print_s;
+          match dir with
+          | Up -> require [%here] (rounded >= span) ~if_false_then_print_s
+          | Down -> require [%here] (rounded <= span) ~if_false_then_print_s
+          | Zero -> require [%here] (abs rounded <= abs span) ~if_false_then_print_s
+          | Nearest -> ());
+      [%expect {| |}]
+    ;;
+  end)
+;;
+
 let succ time_ns =
   time_ns
   |> Time_ns.to_int63_ns_since_epoch
@@ -366,10 +497,8 @@ let pred time_ns =
   |> Time_ns.of_int63_ns_since_epoch
 ;;
 
-let%expect_test "Stable.Alternate_sexp.V1" =
-  print_and_check_stable_type
-    [%here]
-    (module Time_ns.Stable.Alternate_sexp.V1)
+let%expect_test "Stable.Alternate_sexp.V1 and Stable.Option.Alternate_sexp.V1" =
+  let times =
     [ Time_ns.min_value_for_1us_rounding
     ; Time_ns.min_value_for_1us_rounding |> succ
     ; Time_ns.min_value_for_1us_rounding |> succ |> succ
@@ -382,7 +511,9 @@ let%expect_test "Stable.Alternate_sexp.V1" =
     ; Time_ns.max_value_for_1us_rounding |> pred |> pred
     ; Time_ns.max_value_for_1us_rounding |> pred
     ; Time_ns.max_value_for_1us_rounding
-    ];
+    ]
+  in
+  print_and_check_stable_type [%here] (module Time_ns.Stable.Alternate_sexp.V1) times;
   [%expect
     {|
     (bin_shape_digest 2b528f4b22f08e28876ffe0239315ac2)
@@ -409,7 +540,37 @@ let%expect_test "Stable.Alternate_sexp.V1" =
     ((sexp   "2104-11-28 23:59:59.999999999Z")
      (bin_io "\252\255\255\244\016].\021;"))
     ((sexp   "2104-11-29 00:00:00Z")
-     (bin_io "\252\000\000\245\016].\021;")) |}]
+     (bin_io "\252\000\000\245\016].\021;"))
+    |}];
+  let option_times = Time_ns.Option.none :: List.map times ~f:Time_ns.Option.some in
+  print_and_check_stable_type
+    [%here]
+    (module Time_ns.Stable.Option.Alternate_sexp.V1)
+    option_times;
+  [%expect
+    {|
+    (bin_shape_digest 2b528f4b22f08e28876ffe0239315ac2)
+    ((sexp ()) (bin_io "\252\000\000\000\000\000\000\000\192"))
+    ((sexp ("1835-02-03 00:00:00Z"))
+     (bin_io "\252\000\000\011\239\162\209\234\196"))
+    ((sexp ("1835-02-03 00:00:00.000000001Z"))
+     (bin_io "\252\001\000\011\239\162\209\234\196"))
+    ((sexp ("1835-02-03 00:00:00.000000002Z"))
+     (bin_io "\252\002\000\011\239\162\209\234\196"))
+    ((sexp ("1969-12-31 23:59:59.999999999Z")) (bin_io "\255\255"))
+    ((sexp ("1970-01-01 00:00:00Z")) (bin_io "\000"))
+    ((sexp ("1970-01-01 00:00:00.000000001Z")) (bin_io "\001"))
+    ((sexp ("2001-09-09 01:46:39.999999999Z"))
+     (bin_io "\252\255\255c\167\179\182\224\r"))
+    ((sexp ("2001-09-09 01:46:40Z")) (bin_io "\252\000\000d\167\179\182\224\r"))
+    ((sexp ("2001-09-09 01:46:40.000000001Z"))
+     (bin_io "\252\001\000d\167\179\182\224\r"))
+    ((sexp ("2104-11-28 23:59:59.999999998Z"))
+     (bin_io "\252\254\255\244\016].\021;"))
+    ((sexp ("2104-11-28 23:59:59.999999999Z"))
+     (bin_io "\252\255\255\244\016].\021;"))
+    ((sexp ("2104-11-29 00:00:00Z")) (bin_io "\252\000\000\245\016].\021;"))
+    |}]
 ;;
 
 let%test_module "Ofday" =
@@ -431,28 +592,28 @@ let%test_module "Ofday" =
         ; "12:34:56.789"
         ; "12:34:56.789123"
         ; "12:34:56.789123456"
-          ; (* lower boundary case *)
+        ; (* lower boundary case *)
           "00"
         ; "00:00"
         ; "00:00:00"
         ; "00:00:00.000"
         ; "00:00:00.000000"
         ; "00:00:00.000000000"
-          ; (* upper boundary case *)
+        ; (* upper boundary case *)
           "23"
         ; "23:59"
         ; "23:59:59"
         ; "23:59:59.999"
         ; "23:59:59.999999"
         ; "23:59:59.999999999"
-          ; (* midnight tomorrow *)
+        ; (* midnight tomorrow *)
           "24"
         ; "24:00"
         ; "24:00:00"
         ; "24:00:00.000"
         ; "24:00:00.000000"
         ; "24:00:00.000000000"
-          ; (* leap second *)
+        ; (* leap second *)
           "12:59:60"
         ; "12:59:60.789"
         ; "12:59:60.789123"
@@ -460,34 +621,35 @@ let%test_module "Ofday" =
         ];
       [%expect
         {|
-    12:00:00.000000000 <-- 12
-    12:34:00.000000000 <-- 12:34
-    12:34:56.000000000 <-- 12:34:56
-    12:34:56.789000000 <-- 12:34:56.789
-    12:34:56.789123000 <-- 12:34:56.789123
-    12:34:56.789123456 <-- 12:34:56.789123456
-    00:00:00.000000000 <-- 00
-    00:00:00.000000000 <-- 00:00
-    00:00:00.000000000 <-- 00:00:00
-    00:00:00.000000000 <-- 00:00:00.000
-    00:00:00.000000000 <-- 00:00:00.000000
-    00:00:00.000000000 <-- 00:00:00.000000000
-    23:00:00.000000000 <-- 23
-    23:59:00.000000000 <-- 23:59
-    23:59:59.000000000 <-- 23:59:59
-    23:59:59.999000000 <-- 23:59:59.999
-    23:59:59.999999000 <-- 23:59:59.999999
-    23:59:59.999999999 <-- 23:59:59.999999999
-    24:00:00.000000000 <-- 24
-    24:00:00.000000000 <-- 24:00
-    24:00:00.000000000 <-- 24:00:00
-    24:00:00.000000000 <-- 24:00:00.000
-    24:00:00.000000000 <-- 24:00:00.000000
-    24:00:00.000000000 <-- 24:00:00.000000000
-    13:00:00.000000000 <-- 12:59:60
-    13:00:00.000000000 <-- 12:59:60.789
-    13:00:00.000000000 <-- 12:59:60.789123
-    13:00:00.000000000 <-- 12:59:60.789123456 |}];
+        12:00:00.000000000 <-- 12
+        12:34:00.000000000 <-- 12:34
+        12:34:56.000000000 <-- 12:34:56
+        12:34:56.789000000 <-- 12:34:56.789
+        12:34:56.789123000 <-- 12:34:56.789123
+        12:34:56.789123456 <-- 12:34:56.789123456
+        00:00:00.000000000 <-- 00
+        00:00:00.000000000 <-- 00:00
+        00:00:00.000000000 <-- 00:00:00
+        00:00:00.000000000 <-- 00:00:00.000
+        00:00:00.000000000 <-- 00:00:00.000000
+        00:00:00.000000000 <-- 00:00:00.000000000
+        23:00:00.000000000 <-- 23
+        23:59:00.000000000 <-- 23:59
+        23:59:59.000000000 <-- 23:59:59
+        23:59:59.999000000 <-- 23:59:59.999
+        23:59:59.999999000 <-- 23:59:59.999999
+        23:59:59.999999999 <-- 23:59:59.999999999
+        24:00:00.000000000 <-- 24
+        24:00:00.000000000 <-- 24:00
+        24:00:00.000000000 <-- 24:00:00
+        24:00:00.000000000 <-- 24:00:00.000
+        24:00:00.000000000 <-- 24:00:00.000000
+        24:00:00.000000000 <-- 24:00:00.000000000
+        13:00:00.000000000 <-- 12:59:60
+        13:00:00.000000000 <-- 12:59:60.789
+        13:00:00.000000000 <-- 12:59:60.789123
+        13:00:00.000000000 <-- 12:59:60.789123456
+        |}];
       let failure string =
         match Time_ns.Ofday.of_string_iso8601_extended string with
         | exception exn -> print_endline (Exn.to_string exn)
@@ -509,39 +671,40 @@ let%test_module "Ofday" =
         ; "12:345"
         ; "12:34:"
         ; "12:34:5"
-          ; (* numerical bounds *)
+        ; (* numerical bounds *)
           "25:00"
         ; "00:60"
         ; "00:59:61"
         ];
       [%expect
         {|
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" ""
-      (Failure "len < 2"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 1
-      (Failure "len < 2"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 123
-      (Failure "2 < len < 5"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" :
-      (Failure "len < 2"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:
-      (Failure "2 < len < 5"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 1:23
-      (Failure "Char.get_digit_exn ':': not a digit"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:3
-      (Failure "2 < len < 5"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:345
-      (Failure "5 < len < 8"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:34:
-      (Failure "5 < len < 8"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:34:5
-      (Failure "5 < len < 8"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 25:00
-      (Failure "hour > 24"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 00:60
-      (Failure "minute > 60"))
-    ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 00:59:61
-      (Failure "invalid second: 61")) |}]
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" ""
+          (Failure "len < 2"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 1
+          (Failure "len < 2"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 123
+          (Failure "2 < len < 5"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" :
+          (Failure "len < 2"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:
+          (Failure "2 < len < 5"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 1:23
+          (Failure "Char.get_digit_exn ':': not a digit"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:3
+          (Failure "2 < len < 5"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:345
+          (Failure "5 < len < 8"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:34:
+          (Failure "5 < len < 8"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 12:34:5
+          (Failure "5 < len < 8"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 25:00
+          (Failure "hour > 24"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 00:60
+          (Failure "minute > 60"))
+        ("Time_ns.Ofday.of_string_iso8601_extended: cannot parse string" 00:59:61
+          (Failure "invalid second: 61"))
+        |}]
     ;;
 
     let%expect_test "every" =
@@ -593,7 +756,8 @@ let%test_module "Ofday" =
         (Error (
           "[Time_ns.Ofday.every] called with [start] > [stop]"
           (start 23:59:59.999999999)
-          (stop  00:00:00.000000000))) |}];
+          (stop  00:00:00.000000000)))
+        |}];
       test hour sod eod;
       [%expect
         {|
@@ -621,7 +785,8 @@ let%test_module "Ofday" =
           20:00:00.000000000
           21:00:00.000000000
           22:00:00.000000000
-          23:00:00.000000000)) |}];
+          23:00:00.000000000))
+        |}];
       test ten_min sod (Ofday.of_string "00:20");
       [%expect {| (Ok (00:00:00.000000000 00:10:00.000000000 00:20:00.000000000)) |}];
       test ten_min sod (Ofday.of_string "00:25");
@@ -639,7 +804,8 @@ let%test_module "Ofday" =
         {|
         (Error (
           "[Time_ns.Ofday.every] called with negative span"
-          -53375d23h53m38.427387904s)) |}];
+          -53375d23h53m38.427387904s))
+        |}];
       let span_gen =
         (* avoid intervals so small we generate, e.g., millions of values *)
         Quickcheck.Generator.filter Span.quickcheck_generator ~f:(fun span ->
@@ -781,16 +947,17 @@ module _ = struct
         print_s
           [%sexp
             (to_parts (create ~sign:Neg ~hr:2 ~min:3 ~sec:4 ~ms:5 ~us:6 ~ns:7 ())
-             : Parts.t)];
+              : Parts.t)];
         [%expect
           {|
-        ((sign Neg)
-         (hr   2)
-         (min  3)
-         (sec  4)
-         (ms   5)
-         (us   6)
-         (ns   7)) |}]
+          ((sign Neg)
+           (hr   2)
+           (min  3)
+           (sec  4)
+           (ms   5)
+           (us   6)
+           (ns   7))
+          |}]
       ;;
 
       let%test_unit _ = round_trip (to_parts (create ~hr:25 ()))
@@ -1012,14 +1179,16 @@ let%expect_test "times with implicit zones" =
     {|
     (Of_sexp_error
       (Invalid_argument "String.chop_suffix_exn \"09:30:00\" \"Z\"")
-      (invalid_sexp "2013-10-07 09:30:00")) |}];
+      (invalid_sexp "2013-10-07 09:30:00"))
+    |}];
   require_does_raise [%here] (fun () ->
     Time_ns.Alternate_sexp.t_of_sexp (Sexp.Atom "2013-10-07 09:30:00"));
   [%expect
     {|
     (Of_sexp_error
       (Invalid_argument "String.chop_suffix_exn \"09:30:00\" \"Z\"")
-      (invalid_sexp "2013-10-07 09:30:00")) |}]
+      (invalid_sexp "2013-10-07 09:30:00"))
+    |}]
 ;;
 
 let%expect_test "to_string" =
@@ -1044,19 +1213,20 @@ let%expect_test "Ofday.to_microsecond_string" =
   ; Time_ns.Ofday.start_of_next_day
   ]
   |> List.iter ~f:(fun ofday ->
-    let string = Time_ns.Ofday.to_microsecond_string ofday in
-    print_endline string;
-    require_equal
-      [%here]
-      (module Time_ns.Ofday)
-      (Time_ns.Ofday.of_string string)
-      (round ofday));
+       let string = Time_ns.Ofday.to_microsecond_string ofday in
+       print_endline string;
+       require_equal
+         [%here]
+         (module Time_ns.Ofday)
+         (Time_ns.Ofday.of_string string)
+         (round ofday));
   [%expect
     {|
     00:00:00.000000
     00:00:00.000000
     23:59:59.999999
-    24:00:00.000000 |}]
+    24:00:00.000000
+    |}]
 ;;
 
 let%expect_test "to_sec_string[_with_zone]" =
@@ -1072,7 +1242,8 @@ let%expect_test "to_sec_string[_with_zone]" =
     1969-12-31 23:00:01
     1970-01-01 00:00:01
     1970-01-01 01:00:01
-    1970-01-01 08:00:01 |}];
+    1970-01-01 08:00:01
+    |}];
   List.iter zones ~f:(fun zone -> to_sec_string_with_zone time ~zone |> print_endline);
   [%expect
     {|
@@ -1080,7 +1251,8 @@ let%expect_test "to_sec_string[_with_zone]" =
     1969-12-31 23:00:01-01:00
     1970-01-01 00:00:01Z
     1970-01-01 01:00:01+01:00
-    1970-01-01 08:00:01+08:00 |}]
+    1970-01-01 08:00:01+08:00
+    |}]
 ;;
 
 let%expect_test "time zone offset parsing" =
@@ -1096,7 +1268,8 @@ let%expect_test "time zone offset parsing" =
     2000-01-01 12:34:56.789012345Z
     2000-01-01 12:34:56.789012345Z
     2000-01-01 12:34:56.789012345Z
-    2000-01-01 12:34:56.789012345Z |}];
+    2000-01-01 12:34:56.789012345Z
+    |}];
   test "2000-01-01 12:34:56.789012345-05:00";
   test "2000-01-01 12:34:56.789012345-5:00";
   test "2000-01-01 12:34:56.789012345-05";
@@ -1106,17 +1279,22 @@ let%expect_test "time zone offset parsing" =
     2000-01-01 17:34:56.789012345Z
     2000-01-01 17:34:56.789012345Z
     2000-01-01 17:34:56.789012345Z
-    2000-01-01 17:34:56.789012345Z |}];
+    2000-01-01 17:34:56.789012345Z
+    |}];
   test "2000-01-01 12:34:56.789012345-23:00";
   test "2000-01-01 12:34:56.789012345-23";
-  [%expect {|
+  [%expect
+    {|
     2000-01-02 11:34:56.789012345Z
-    2000-01-02 11:34:56.789012345Z |}];
+    2000-01-02 11:34:56.789012345Z
+    |}];
   test "2000-01-01 12:34:56.789012345-24:00";
   test "2000-01-01 12:34:56.789012345-24";
-  [%expect {|
+  [%expect
+    {|
     2000-01-02 12:34:56.789012345Z
-    2000-01-02 12:34:56.789012345Z |}]
+    2000-01-02 12:34:56.789012345Z
+    |}]
 ;;
 
 let%expect_test "time zone invalid offset parsing" =
@@ -1162,7 +1340,8 @@ let%expect_test "time zone invalid offset parsing" =
      (Failure "Char.get_digit_exn ':': not a digit"))
     (time_ns.ml.To_and_of_string.Time_ns_of_string
      "2000-01-01 12:34:56.789012345-"
-     (Invalid_argument "index out of bounds")) |}];
+     (Invalid_argument "index out of bounds"))
+    |}];
   test [%here] "2000-01-01 12:34:56.789012-25:00";
   test [%here] "2000-01-01 12:34:56.789012-25";
   [%expect
@@ -1172,7 +1351,8 @@ let%expect_test "time zone invalid offset parsing" =
      ("Time.Ofday: invalid string" 25:00 "hours out of bounds"))
     (time_ns.ml.To_and_of_string.Time_ns_of_string
      "2000-01-01 12:34:56.789012-25"
-     ("Time.Ofday: invalid string" 25:00 "hours out of bounds")) |}];
+     ("Time.Ofday: invalid string" 25:00 "hours out of bounds"))
+    |}];
   test [%here] "2000-01-01 12:34:56.789012--1:00";
   test [%here] "2000-01-01 12:34:56.789012--1";
   [%expect
@@ -1182,7 +1362,8 @@ let%expect_test "time zone invalid offset parsing" =
      (Failure "Char.get_digit_exn '-': not a digit"))
     (time_ns.ml.To_and_of_string.Time_ns_of_string
      "2000-01-01 12:34:56.789012--1"
-     (Invalid_argument "index out of bounds")) |}]
+     (Invalid_argument "index out of bounds"))
+    |}]
 ;;
 
 let%expect_test "test human comparisons" =
@@ -1219,7 +1400,8 @@ let%expect_test "test human comparisons" =
     ((is_later   false)
      (is_earlier true)
      (first_time "1969-07-20 20:17:40Z")
-     (last_time  "2000-01-01 00:00:00Z")) |}]
+     (last_time  "2000-01-01 00:00:00Z"))
+    |}]
 ;;
 
 let%expect_test "add_saturating" =
@@ -1247,7 +1429,8 @@ let%expect_test "add_saturating" =
     {|
     (overflow
       (sum            "1823-11-12 00:07:21.572612095Z")
-      (saturating_sum "2116-02-20 23:53:38.427387903Z")) |}];
+      (saturating_sum "2116-02-20 23:53:38.427387903Z"))
+    |}];
   test
     (Time_ns.of_string_with_utc_offset "2018-01-01 00:00:00Z")
     (Time_ns.Span.of_sec 4_000_000_000.);
@@ -1255,14 +1438,16 @@ let%expect_test "add_saturating" =
     {|
     (overflow
       (sum            "1852-06-24 07:19:23.145224192Z")
-      (saturating_sum "2116-02-20 23:53:38.427387903Z")) |}];
+      (saturating_sum "2116-02-20 23:53:38.427387903Z"))
+    |}];
   (* and negative overflows *)
   test Time_ns.min_value_representable Time_ns.Span.(neg minute);
   [%expect
     {|
     (underflow
       (sum            "2116-02-20 23:52:38.427387904Z")
-      (saturating_sum "1823-11-12 00:06:21.572612096Z")) |}];
+      (saturating_sum "1823-11-12 00:06:21.572612096Z"))
+    |}];
   test
     (Time_ns.of_string_with_utc_offset "1918-01-01 00:00:00Z")
     (Time_ns.Span.of_sec (-4_000_000_000.));
@@ -1270,7 +1455,8 @@ let%expect_test "add_saturating" =
     {|
     (underflow
       (sum            "2083-07-09 16:40:36.854775808Z")
-      (saturating_sum "1823-11-12 00:06:21.572612096Z")) |}]
+      (saturating_sum "1823-11-12 00:06:21.572612096Z"))
+    |}]
 ;;
 
 let%expect_test "sub_saturating" =
@@ -1298,7 +1484,8 @@ let%expect_test "sub_saturating" =
     {|
     (underflow
       (diff            "2116-02-20 23:52:38.427387904Z")
-      (saturating_diff "1823-11-12 00:06:21.572612096Z")) |}];
+      (saturating_diff "1823-11-12 00:06:21.572612096Z"))
+    |}];
   test
     (Time_ns.of_string_with_utc_offset "1918-01-01 00:00:00Z")
     (Time_ns.Span.of_sec 4_000_000_000.);
@@ -1306,14 +1493,16 @@ let%expect_test "sub_saturating" =
     {|
     (underflow
       (diff            "2083-07-09 16:40:36.854775808Z")
-      (saturating_diff "1823-11-12 00:06:21.572612096Z")) |}];
+      (saturating_diff "1823-11-12 00:06:21.572612096Z"))
+    |}];
   (* and positive overflows *)
   test Time_ns.max_value_representable Time_ns.Span.(neg minute);
   [%expect
     {|
     (overflow
       (diff            "1823-11-12 00:07:21.572612095Z")
-      (saturating_diff "2116-02-20 23:53:38.427387903Z")) |}];
+      (saturating_diff "2116-02-20 23:53:38.427387903Z"))
+    |}];
   test
     (Time_ns.of_string_with_utc_offset "2018-01-01 00:00:00Z")
     (Time_ns.Span.of_sec (-4_000_000_000.));
@@ -1321,7 +1510,8 @@ let%expect_test "sub_saturating" =
     {|
     (overflow
       (diff            "1852-06-24 07:19:23.145224192Z")
-      (saturating_diff "2116-02-20 23:53:38.427387903Z")) |}]
+      (saturating_diff "2116-02-20 23:53:38.427387903Z"))
+    |}]
 ;;
 
 let%expect_test "[to_ofday] never returns 24:00" =
@@ -1340,3 +1530,114 @@ let%expect_test "[to_ofday] never returns 24:00" =
         (fun ofday -> Time_ns.Ofday.( < ) ofday Time_ns.Ofday.start_of_next_day)
         ofday)
 ;;
+
+let%expect_test "approximate conversions" =
+  let open Time_ns.Span in
+  let test to_precise to_approx =
+    (* show that conversion can be imprecise *)
+    quickcheck_m
+      [%here]
+      ~cr:Comment
+      (module Time_ns.Span)
+      ~f:(fun span ->
+        let precise = to_precise span in
+        let approx = to_approx span in
+        if Float.( <> ) precise approx
+        then (
+          let diff = approx -. precise in
+          print_cr
+            [%here]
+            ~cr:Comment
+            [%message
+              "result can be imprecise"
+                (span : Time_ns.Span.t)
+                (precise : float)
+                (approx : float)
+                (diff : float)]));
+    (* check that imprecision is at most 1 ULP *)
+    quickcheck_m
+      [%here]
+      (module Time_ns.Span)
+      ~f:(fun span ->
+        let precise = to_precise span in
+        let approx = to_approx span in
+        if Float.( > ) approx (Float.one_ulp `Up precise)
+           || Float.( < ) approx (Float.one_ulp `Down precise)
+        then (
+          let diff = approx -. precise in
+          print_cr
+            [%here]
+            [%message
+              "imprecision can exceed 1 ULP"
+                (span : Time_ns.Span.t)
+                (precise : float)
+                (approx : float)
+                (diff : float)]))
+  in
+  test to_us to_us_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input -225.617us))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    -225.617us)
+      (precise -225.617)
+      (approx  -225.61700000000002)
+      (diff    -2.8421709430404007E-14))
+    |}];
+  test to_ms to_ms_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input -627d5h39m8.208643064s))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    -627d5h39m8.208643064s)
+      (precise -54193148208.643066)
+      (approx  -54193148208.643059)
+      (diff    7.62939453125E-06))
+    |}];
+  test to_sec to_sec_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input -15.508265059s))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    -15.508265059s)
+      (precise -15.508265059)
+      (approx  -15.508265059000001)
+      (diff    -1.7763568394002505E-15))
+    |}];
+  test to_min to_min_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input 44.923us))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    44.923us)
+      (precise 7.4871666666666662E-07)
+      (approx  7.4871666666666673E-07)
+      (diff    1.0587911840678754E-22))
+    |}];
+  test to_hr to_hr_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input 76.753us))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    76.753us)
+      (precise 2.1320277777777777E-08)
+      (approx  2.132027777777778E-08)
+      (diff    3.3087224502121107E-24))
+    |}];
+  test to_day to_day_approx;
+  [%expect
+    {|
+    ("quickcheck: test failed" (input -225.617us))
+    (* require-failed: lib/core/test/test_time_ns.ml:LINE:COL. *)
+    ("result can be imprecise"
+      (span    -225.617us)
+      (precise -2.6113078703703705E-09)
+      (approx  -2.61130787037037E-09)
+      (diff    4.1359030627651384E-25))
+    |}]
+;;
