@@ -91,8 +91,8 @@ let%test_module _ =
       && i = conv.value_as_int_exn v
       && phys_equal v (conv.int_as_value_exn i)
       && (match conv.value_as_int v with
-        | Some i' -> i = i'
-        | None -> false)
+          | Some i' -> i = i'
+          | None -> false)
       &&
       match conv.int_as_value i with
       | Some v' -> phys_equal v v'
@@ -108,8 +108,8 @@ let%test_module _ =
         (not (is_immediate v))
         && (not (conv.value_is_int v))
         && (match conv.value_as_int v with
-          | Some _ -> false
-          | None -> true)
+            | Some _ -> false
+            | None -> true)
         && Exn.does_raise (fun () -> conv.value_as_int_exn v))
     ;;
 
@@ -117,8 +117,8 @@ let%test_module _ =
       List.for_all test_cases ~f:(fun i ->
         (not (conv.int_is_value i))
         && (match conv.int_as_value i with
-          | Some _ -> false
-          | None -> true)
+            | Some _ -> false
+            | None -> true)
         && Exn.does_raise (fun () -> conv.int_as_value_exn i))
     ;;
 
@@ -372,9 +372,9 @@ let%test_module _ =
         [%here]
         (test_inconvertible_ints conv no_int_but_zero_converts)
         ~if_false_then_print_s:(lazy [%message "non-zero should not convert"]);
-      [%expect
-        {|
-        "zero should convert" |}]
+      [%expect {|
+        "zero should convert"
+        |}]
     ;;
 
     let%test _ =
@@ -444,9 +444,9 @@ let%test_module _ =
         [%here]
         (test_inconvertible_ints conv no_int_but_zero_converts)
         ~if_false_then_print_s:(lazy [%message "non-zero should not convert"]);
-      [%expect
-        {|
-        "zero should convert" |}]
+      [%expect {|
+        "zero should convert"
+        |}]
     ;;
 
     let%test _ =
@@ -619,5 +619,23 @@ let%test_module _ =
       && test_inconvertible_values conv [ M.B (M.A, M.A); M.C () ]
       && test_inconvertible_ints conv no_int_but_zero_converts
     ;;
+
+    let%test _ =
+      let module M = struct
+        type t = | [@@deriving typerep]
+      end
+      in
+      let conv = get_conv M.typerep_of_t in
+      test_inconvertible_ints conv no_int_converts
+    ;;
+
+    let%test _ =
+      let module M = struct
+        type 'a t = | [@@deriving typerep]
+      end
+      in
+      let conv = get_conv (M.typerep_of_t typerep_of_unit) in
+      test_inconvertible_ints conv no_int_converts
+    ;;
   end)
 ;;
